@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -48,11 +47,14 @@ gboolean na_core_utils_boolean_from_string( const gchar *string );
 
 /* string manipulation
  */
+#ifdef NA_ENABLE_DEPRECATED
 gchar   *na_core_utils_str_add_prefix( const gchar *prefix, const gchar *str );
+#endif
 int      na_core_utils_str_collate( const gchar *str1, const gchar *str2 );
 gchar   *na_core_utils_str_remove_char( const gchar *string, const gchar *to_remove );
 gchar   *na_core_utils_str_remove_suffix( const gchar *string, const gchar *suffix );
 void     na_core_utils_str_split_first_word( const gchar *string, gchar **first, gchar **other );
+gchar   *na_core_utils_str_subst( const gchar *pattern, const gchar *key, const gchar *subst );
 
 /* some functions to get or set GSList list of strings
  */
@@ -82,14 +84,16 @@ void     na_core_utils_selcount_get_ope_int( const gchar *selection_count, gchar
 
 /* directory management
  */
+void     na_core_utils_dir_list_perms      ( const gchar *path, const gchar *message );
 gboolean na_core_utils_dir_is_writable_path( const gchar *path );
-gboolean na_core_utils_dir_is_writable_uri( const gchar *uri );
-void     na_core_utils_dir_split_ext( const gchar *string, gchar **first, gchar **ext );
+gboolean na_core_utils_dir_is_writable_uri ( const gchar *uri );
+void     na_core_utils_dir_split_ext       ( const gchar *string, gchar **first, gchar **ext );
 
 /* file management
  */
 gboolean na_core_utils_file_delete       ( const gchar *path );
 gboolean na_core_utils_file_exists       ( const gchar *uri );
+gboolean na_core_utils_file_is_loadable  ( const gchar *uri );
 gchar   *na_core_utils_file_load_from_uri( const gchar *uri, gsize *length );
 
 /* miscellaneous
