@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -69,7 +68,7 @@
  *    <para>
  *     Check for edition status, which positions modification and validity
  *     status, is not recursive ; it is the responsability of the
- *     implementation to check for edition status of childs of object..
+ *     implementation to check for edition status of children of object..
  *    </para>
  *   </listitem>
  *  </itemizedlist>
@@ -106,14 +105,13 @@
 
 G_BEGIN_DECLS
 
-#define NA_IDUPLICABLE_TYPE                        ( na_iduplicable_get_type())
-#define NA_IDUPLICABLE( instance )                 ( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_IDUPLICABLE_TYPE, NAIDuplicable ))
-#define NA_IS_IDUPLICABLE( instance )              ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_IDUPLICABLE_TYPE ))
-#define NA_IDUPLICABLE_GET_INTERFACE( instance )   ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_IDUPLICABLE_TYPE, NAIDuplicableInterface ))
+#define NA_TYPE_IDUPLICABLE                      ( na_iduplicable_get_type())
+#define NA_IDUPLICABLE( instance )               ( G_TYPE_CHECK_INSTANCE_CAST( instance, NA_TYPE_IDUPLICABLE, NAIDuplicable ))
+#define NA_IS_IDUPLICABLE( instance )            ( G_TYPE_CHECK_INSTANCE_TYPE( instance, NA_TYPE_IDUPLICABLE ))
+#define NA_IDUPLICABLE_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ), NA_TYPE_IDUPLICABLE, NAIDuplicableInterface ))
 
-typedef struct _NAIDuplicable                 NAIDuplicable;
-
-typedef struct _NAIDuplicableInterfacePrivate NAIDuplicableInterfacePrivate;
+typedef struct _NAIDuplicable                    NAIDuplicable;
+typedef struct _NAIDuplicableInterfacePrivate    NAIDuplicableInterfacePrivate;
 
 /**
  * NAIDuplicableInterface:
@@ -133,7 +131,8 @@ typedef struct {
 	/**
 	 * copy:
 	 * @target: the #NAIDuplicable target of the copy.
-	 * @source: the #NAIDuplicable source of the copy
+	 * @source: the #NAIDuplicable source of the copy.
+	 * @mode: the duplication mode.
 	 *
 	 * Copies data from @source to @ŧarget, so that @target becomes an
 	 * exact copy of @source.
@@ -145,7 +144,7 @@ typedef struct {
 	 *
 	 * Since: 2.30
 	 */
-	void     ( *copy )     ( NAIDuplicable *target, const NAIDuplicable *source );
+	void     ( *copy )      ( NAIDuplicable *target, const NAIDuplicable *source, guint mode );
 
 	/**
 	 * are_equal:
@@ -160,11 +159,14 @@ typedef struct {
 	 * care itself of calling each function in the class hierarchy,
 	 * from topmost base class to most-derived one.
 	 *
+	 * When testing for the modification status of an object, @a stands for
+	 * the original object, while @b stands for the duplicated one.
+	 *
 	 * Returns: TRUE if @a and @b are identical, FALSE else.
 	 *
 	 * Since: 2.30
 	 */
-	gboolean ( *are_equal )( const NAIDuplicable *a, const NAIDuplicable *b );
+	gboolean ( *are_equal ) ( const NAIDuplicable *a, const NAIDuplicable *b );
 
 	/**
 	 * is_valid:
@@ -181,28 +183,46 @@ typedef struct {
 	 *
 	 * Since: 2.30
 	 */
-	gboolean ( *is_valid )   ( const NAIDuplicable *object );
+	gboolean ( *is_valid )  ( const NAIDuplicable *object );
 }
 	NAIDuplicableInterface;
 
-#define NA_IDUPLICABLE_SIGNAL_STATUS_CHANGED	"status-changed"
+#define IDUPLICABLE_SIGNAL_MODIFIED_CHANGED		"iduplicable-modified-changed"
+#define IDUPLICABLE_SIGNAL_VALID_CHANGED		"iduplicable-valid-changed"
 
-GType          na_iduplicable_get_type( void );
+/**
+ * DuplicateMode:
+ * @DUPLICATE_ONLY:   only duplicates the provided object.
+ * @DUPLICATE_OBJECT: only duplicate a menu
+ *                    (a menu with some subitems is duplicated to an empty menu)
+ * @DUPLICATE_REC:    recursively duplicates all the provided hierarchy.
+ */
+typedef enum {
+	DUPLICATE_ONLY = 1,
+	DUPLICATE_OBJECT,
+	DUPLICATE_REC
+}
+	DuplicableMode;
 
-void           na_iduplicable_dispose     ( const NAIDuplicable *object );
-void           na_iduplicable_dump        ( const NAIDuplicable *object );
-NAIDuplicable *na_iduplicable_duplicate   ( const NAIDuplicable *object );
-void           na_iduplicable_check_status( const NAIDuplicable *object );
+GType          na_iduplicable_get_type         ( void );
 
-NAIDuplicable *na_iduplicable_get_origin  ( const NAIDuplicable *object );
-gboolean       na_iduplicable_is_valid    ( const NAIDuplicable *object );
-gboolean       na_iduplicable_is_modified ( const NAIDuplicable *object );
+void           na_iduplicable_dispose          ( const NAIDuplicable *object );
+void           na_iduplicable_dump             ( const NAIDuplicable *object );
+NAIDuplicable *na_iduplicable_duplicate        ( const NAIDuplicable *object, guint mode );
+void           na_iduplicable_check_status     ( const NAIDuplicable *object );
 
-void           na_iduplicable_set_origin  ( NAIDuplicable *object, const NAIDuplicable *origin );
-void           na_iduplicable_set_modified( NAIDuplicable *object, gboolean modified );
+NAIDuplicable *na_iduplicable_get_origin       ( const NAIDuplicable *object );
+gboolean       na_iduplicable_is_valid         ( const NAIDuplicable *object );
+gboolean       na_iduplicable_is_modified      ( const NAIDuplicable *object );
+
+void           na_iduplicable_set_origin       ( NAIDuplicable *object, const NAIDuplicable *origin );
 
 void           na_iduplicable_register_consumer( GObject *consumer );
 
+#ifdef NA_ENABLE_DEPRECATED
+void           na_iduplicable_set_modified( NAIDuplicable *object, gboolean modified );
+#endif
+
 G_END_DECLS
 
 #endif /* __NAUTILUS_ACTIONS_API_NA_IDUPLICABLE_H__ */
