@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -419,7 +418,7 @@ boxed_new( const BoxedDef *def )
 {
 	NABoxed *boxed;
 
-	boxed = g_object_new( NA_BOXED_TYPE, NULL );
+	boxed = g_object_new( NA_TYPE_BOXED, NULL );
 	boxed->private->def = def;
 
 	return( boxed );
@@ -442,8 +441,11 @@ get_boxed_def( guint type )
 }
 
 /*
- * converts a string to an array of string
- * the last separator, if any, is not counted
+ * converts a string to an array of strings
+ * accepts both:
+ * - a semi-comma-separated list of strings (the last separator, if any, is not counted)
+ * - a comma-separated list of strings between square brackets (à la GConf)
+ *
  */
 static gchar **
 string_to_array( const gchar *string )
@@ -454,12 +456,25 @@ string_to_array( const gchar *string )
 	array = NULL;
 
 	if( string && strlen( string )){
-		sdup = g_strdup( string );
-		if( g_str_has_suffix( string, LIST_SEPARATOR )){
-			sdup[strlen(sdup)-1] = '\0';
+		sdup = g_strstrip( g_strdup( string ));
+
+		/* GConf-style string list [value,value]
+		 */
+		if( sdup[0] == '[' && sdup[strlen(sdup)-1] == ']' ){
+			sdup[0] = ' ';
+			sdup[strlen(sdup)-1] = ' ';
 			sdup = g_strstrip( sdup );
+			array = g_strsplit( sdup, ",", -1 );
+
+		/* semi-comma-separated list of strings
+		 */
+		} else {
+			if( g_str_has_suffix( string, LIST_SEPARATOR )){
+				sdup[strlen(sdup)-1] = ' ';
+				sdup = g_strstrip( sdup );
+			}
+			array = g_strsplit( sdup, LIST_SEPARATOR, -1 );
 		}
-		array = g_strsplit( sdup, LIST_SEPARATOR, -1 );
 		g_free( sdup );
 	}
 
@@ -473,7 +488,7 @@ string_to_array( const gchar *string )
  *
  * Set the type of the just-allocated @boxed object.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_boxed_set_type( NABoxed *boxed, guint type )
@@ -492,7 +507,7 @@ na_boxed_set_type( NABoxed *boxed, guint type )
  *
  * Returns: %TRUE if @a and @b are equal, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_boxed_are_equal( const NABoxed *a, const NABoxed *b )
@@ -526,7 +541,7 @@ na_boxed_are_equal( const NABoxed *a, const NABoxed *b )
  * Returns: a copy of @boxed, as a newly allocated #NABoxed which should
  * be g_object_unref() by the caller.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 NABoxed *
 na_boxed_copy( const NABoxed *boxed )
@@ -553,7 +568,7 @@ na_boxed_copy( const NABoxed *boxed )
  *
  * Dumps the @boxed box.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_boxed_dump( const NABoxed *boxed )
@@ -587,7 +602,7 @@ na_boxed_dump( const NABoxed *boxed )
  * by the caller, or %NULL if the type is unknowned, or does not provide
  * the 'from_string' function.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 NABoxed *
 na_boxed_new_from_string( guint type, const gchar *string )
@@ -614,7 +629,7 @@ na_boxed_new_from_string( guint type, const gchar *string )
  * Returns: the boolean value if @boxed is of %NA_DATA_TYPE_BOOLEAN type,
  * %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_boxed_get_boolean( const NABoxed *boxed )
@@ -639,7 +654,7 @@ na_boxed_get_boolean( const NABoxed *boxed )
  * Returns: a const pointer to the data if @boxed is of %NA_DATA_TYPE_POINTER
  * type, %NULL else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gconstpointer
 na_boxed_get_pointer( const NABoxed *boxed )
@@ -663,7 +678,7 @@ na_boxed_get_pointer( const NABoxed *boxed )
  * Returns: a newly allocated string if @boxed is of %NA_DATA_TYPE_STRING
  * type, which should be g_free() by the caller, %NULL else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gchar *
 na_boxed_get_string( const NABoxed *boxed )
@@ -687,7 +702,7 @@ na_boxed_get_string( const NABoxed *boxed )
  * Returns: a newly allocated string list if @boxed is of %NA_DATA_TYPE_STRING_LIST
  * type, which should be na_core_utils_slist_free() by the caller, %NULL else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 GSList *
 na_boxed_get_string_list( const NABoxed *boxed )
@@ -712,7 +727,7 @@ na_boxed_get_string_list( const NABoxed *boxed )
  * Returns: an unsigned integer if @boxed is of %NA_DATA_TYPE_UINT type,
  * zero else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 guint
 na_boxed_get_uint( const NABoxed *boxed )
@@ -737,7 +752,7 @@ na_boxed_get_uint( const NABoxed *boxed )
  * Returns: a newly allocated list if @boxed is of %NA_DATA_TYPE_UINT_LIST
  * type, which should be g_list_free() by the caller, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 GList *
 na_boxed_get_uint_list( const NABoxed *boxed )
@@ -762,7 +777,7 @@ na_boxed_get_uint_list( const NABoxed *boxed )
  *
  * Setup @value with the content of the @boxed.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_boxed_get_as_value( const NABoxed *boxed, GValue *value )
@@ -786,7 +801,7 @@ na_boxed_get_as_value( const NABoxed *boxed, GValue *value )
  * is returned in a newly allocated value, which should be g_free() (resp.
  * g_free(), na_core_utils_slist_free(), g_list_free()) by the caller.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void *
 na_boxed_get_as_void( const NABoxed *boxed )
@@ -806,7 +821,7 @@ na_boxed_get_as_void( const NABoxed *boxed )
  *
  * Copy value from @value to @boxed.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_boxed_set_from_boxed( NABoxed *boxed, const NABoxed *value )
@@ -832,7 +847,7 @@ na_boxed_set_from_boxed( NABoxed *boxed, const NABoxed *value )
  *
  * Evaluates the @value and set it to the @boxed.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_boxed_set_from_string( NABoxed *boxed, const gchar *value )
@@ -855,7 +870,7 @@ na_boxed_set_from_string( NABoxed *boxed, const gchar *value )
  *
  * Evaluates the @value and set it to the @boxed.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_boxed_set_from_value( NABoxed *boxed, const GValue *value )
@@ -878,7 +893,7 @@ na_boxed_set_from_value( NABoxed *boxed, const GValue *value )
  *
  * Evaluates the @value and set it to the @boxed.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_boxed_set_from_void( NABoxed *boxed, const void *value )
@@ -1142,6 +1157,11 @@ string_list_free( NABoxed *boxed )
 	boxed->private->is_set = FALSE;
 }
 
+/*
+ * accept string list both:
+ * - as a semi-comma-separated list of strings
+ * - as a comma-separated list of string, between two square brackets (à la GConf)
+ */
 static void
 string_list_from_string( NABoxed *boxed, const gchar *string )
 {
@@ -1182,6 +1202,7 @@ string_list_from_void( NABoxed *boxed, const void *value )
 			boxed->private->u.string_list = g_slist_prepend( boxed->private->u.string_list, g_strdup(( const gchar * ) it->data ));
 		}
 	}
+	boxed->private->u.string_list = g_slist_reverse( boxed->private->u.string_list );
 }
 
 static gconstpointer
