@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -43,8 +42,17 @@
 
 #include "na-about.h"
 
+/* minimal and maximal size for loading the content of a file in memory
+ * used by na_core_utils_file_is_size_ok()
+ */
+#define SIZE_MIN		  1
+#define SIZE_MAX	1048576		/* 1 MB */
+
+#ifdef NA_ENABLE_DEPRECATED
 static GSList  *text_to_string_list( const gchar *text, const gchar *separator, const gchar *default_value );
+#endif
 static gboolean info_dir_is_writable( GFile *file, const gchar *path );
+static gboolean file_is_loadable( GFile *file );
 
 /**
  * na_core_utils_boolean_from_string
@@ -63,6 +71,7 @@ na_core_utils_boolean_from_string( const gchar *string )
 	return( g_ascii_strcasecmp( string, "true" ) == 0 || atoi( string ) != 0 );
 }
 
+#ifdef NA_ENABLE_DEPRECATED
 /**
  * na_core_utils_str_add_prefix:
  * @prefix: the prefix to be prepended.
@@ -73,6 +82,7 @@ na_core_utils_boolean_from_string( const gchar *string )
  * Returns: a new string which should be g_free() by the caller.
  *
  * Since: 2.30
+ * Deprecated: 3.2
  */
 gchar *
 na_core_utils_str_add_prefix( const gchar *prefix, const gchar *str )
@@ -92,6 +102,32 @@ na_core_utils_str_add_prefix( const gchar *prefix, const gchar *str )
 	return( g_string_free( result, FALSE ));
 }
 
+/*
+ * split a text buffer in lines
+ */
+static GSList *
+text_to_string_list( const gchar *text, const gchar *separator, const gchar *default_value )
+{
+	GSList *strlist = NULL;
+	gchar **tokens;
+	gchar *tmp;
+	gchar *source = g_strdup( text );
+
+	tmp = g_strstrip( source );
+	if( !strlen( tmp ) && default_value ){
+		strlist = g_slist_append( strlist, g_strdup( default_value ));
+
+	} else {
+		tokens = g_strsplit( source, separator, -1 );
+		strlist = na_core_utils_slist_from_array(( const gchar ** ) tokens );
+		g_strfreev( tokens );
+	}
+
+	g_free( source );
+	return( strlist );
+}
+#endif /* NA_ENABLE_DEPRECATED */
+
 /**
  * na_core_utils_str_collate:
  * @str1: an UTF-8 encoded string.
@@ -258,11 +294,11 @@ na_core_utils_str_split_first_word( const gchar *string, gchar **first, gchar **
  * @key: the key string to be substituted.
  * @subst: the string which will replace @key.
  *
- * Returns: a copy of @pattern where the first occurrence of @key has been
+ * Returns:
+ * a copy of @pattern where the first occurrence of @key has been
  * substituted with @subst, as a newly allocated string which should be
- * g_free() by the caller.
- *
- * Returns: a copy of @pattern if @key is not found in @pattern.
+ * g_free() by the caller,
+ * or a copy of @pattern if @key is not found in @pattern.
  */
 gchar *
 na_core_utils_str_subst( const gchar *pattern, const gchar *key, const gchar *subst )
@@ -738,31 +774,6 @@ na_core_utils_gstring_joinv( const gchar *start, const gchar *separator, gchar *
 	return( g_string_free( tmp_string, FALSE ));
 }
 
-/*
- * split a text buffer in lines
- */
-static GSList *
-text_to_string_list( const gchar *text, const gchar *separator, const gchar *default_value )
-{
-	GSList *strlist = NULL;
-	gchar **tokens;
-	gchar *tmp;
-	gchar *source = g_strdup( text );
-
-	tmp = g_strstrip( source );
-	if( !strlen( tmp ) && default_value ){
-		strlist = g_slist_append( strlist, g_strdup( default_value ));
-
-	} else {
-		tokens = g_strsplit( source, separator, -1 );
-		strlist = na_core_utils_slist_from_array(( const gchar ** ) tokens );
-		g_strfreev( tokens );
-	}
-
-	g_free( source );
-	return( strlist );
-}
-
 /***
  * na_core_utils_selcount_get_ope:
  * @selcount: the selection count condition string.
@@ -801,6 +812,40 @@ na_core_utils_selcount_get_ope_int( const gchar *selcount, gchar **ope, gchar **
 	g_free( dup );
 }
 
+/**
+ * na_core_utils_dir_list_perms:
+ * @path: the path of the directory to be tested.
+ * @message: a message to be printed if not %NULL.
+ *
+ * Displays the permissions of the directory on debug output.
+ *
+ * Since: 3.1
+ */
+void
+na_core_utils_dir_list_perms( const gchar *path, const gchar *message )
+{
+	static const gchar *thisfn = "na_core_utils_dir_list_perms";
+	gchar *cmd;
+	gchar *out, *err;
+	GError *error;
+
+	error = NULL;
+	cmd = g_strdup_printf( "ls -ld %s", path );
+
+	if( !g_spawn_command_line_sync( cmd, &out, &err, NULL, &error )){
+		g_warning( "%s: %s", thisfn, error->message );
+		g_error_free( error );
+
+	} else {
+		g_debug( "%s: dir=%s, message=%s, out=%s", thisfn, path, message, out );
+		g_debug( "%s: dir=%s, message=%s, err=%s", thisfn, path, message, err );
+		g_free( out );
+		g_free( err );
+	}
+
+	g_free( cmd );
+}
+
 /**
  * na_core_utils_dir_is_writable_path:
  * @path: the path of the directory to be tested.
@@ -1001,6 +1046,92 @@ na_core_utils_file_exists( const gchar *uri )
 	return( exists );
 }
 
+/**
+ * na_core_utils_file_is_loadable:
+ * @uri: the URI to be checked.
+ *
+ * Checks that the file is suitable to be loaded in memory, because
+ * it is not empty, and its size is reasonable (less than 1MB).
+ * Also checks that a file is a regular file (or a symlink to a
+ * regular file).
+ *
+ * Returns: whether the file is suitable to be loaded in memory.
+ *
+ * Since: 3.1
+ */
+gboolean
+na_core_utils_file_is_loadable( const gchar *uri )
+{
+	static const gchar *thisfn = "na_core_utils_file_is_loadable";
+	GFile *file;
+	gboolean isok;
+
+	g_debug( "%s: uri=%s", thisfn, uri );
+
+	isok = FALSE;
+	file = g_file_new_for_uri( uri );
+
+	isok = file_is_loadable( file );
+
+	g_object_unref( file );
+
+	return( isok );
+}
+
+static gboolean
+file_is_loadable( GFile *file )
+{
+	static const gchar *thisfn = "na_core_utils_file_is_loadable";
+	GError *error;
+	GFileInfo *info;
+	guint64 size;
+	GFileType type;
+	gboolean isok;
+	GFile *target_file;
+
+	error = NULL;
+	isok = FALSE;
+	info = g_file_query_info( file,
+			G_FILE_ATTRIBUTE_STANDARD_SIZE "," G_FILE_ATTRIBUTE_STANDARD_TYPE,
+			G_FILE_QUERY_INFO_NONE, NULL, &error );
+
+	if( !info ){
+		if( error ){
+			g_debug( "%s: %s", thisfn, error->message );
+			g_error_free( error );
+		}
+
+	} else {
+		size = g_file_info_get_attribute_uint64( info, G_FILE_ATTRIBUTE_STANDARD_SIZE );
+		g_debug( "%s: size=%lu", thisfn, ( unsigned long ) size );
+		isok = ( size >= SIZE_MIN && size <= SIZE_MAX );
+	}
+
+	if( isok ){
+		type = g_file_info_get_file_type( info );
+		g_debug( "%s: type=%u", thisfn, ( unsigned ) type );
+
+		if( type != G_FILE_TYPE_REGULAR ){
+			isok = FALSE;
+
+			if( type == G_FILE_TYPE_SYMBOLIC_LINK ){
+				const char *target = g_file_info_get_symlink_target( info );
+				if( target && strlen( target )){
+					target_file = g_file_resolve_relative_path( file, target );
+					if( target_file ){
+						isok = file_is_loadable( target_file );
+						g_object_unref( target_file );
+					}
+				}
+			}
+		}
+	}
+
+	g_object_unref( info );
+
+	return( isok );
+}
+
 /**
  * na_core_utils_file_load_from_uri:
  * @uri: the URI the file must be loaded from.
@@ -1017,17 +1148,31 @@ na_core_utils_file_exists( const gchar *uri )
 gchar *
 na_core_utils_file_load_from_uri( const gchar *uri, gsize *length )
 {
+	static const gchar *thisfn = "na_core_utils_file_load_from_uri";
 	gchar *data;
 	GFile *file;
+	GError *error;
+
+	g_debug( "%s: uri=%s, length=%p", thisfn, uri, ( void * ) length );
+
+	error = NULL;
+	data = NULL;
+	if( length ){
+		*length = 0;
+	}
 
 	file = g_file_new_for_uri( uri );
 
-	if( !g_file_load_contents( file, NULL, &data, length, NULL, NULL )){
+	if( !g_file_load_contents( file, NULL, &data, length, NULL, &error )){
 		g_free( data );
 		data = NULL;
 		if( length ){
 			*length = 0;
 		}
+		if( error ){
+			g_debug( "%s: %s", thisfn, error->message );
+			g_error_free( error );
+		}
 	}
 
 	g_object_unref( file );
@@ -1043,7 +1188,7 @@ na_core_utils_file_load_from_uri( const gchar *uri, gsize *length )
  * <programlisting>
  *   nautilus-actions-new (Nautilus-Actions) v 2.29.1
  *   Copyright (C) 2005-2007 Frederic Ruaudel
- *   Copyright (C) 2009, 2010, 2011 Pierre Wieser
+ *   Copyright (C) 2009, 2010, 2011, 2012 Pierre Wieser
  *   Nautilus-Actions is free software, licensed under GPLv2 or later.
  * </programlisting>
  *
