@@ -1,25 +1,24 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -34,6 +33,9 @@
 
 #include <api/na-gconf-monitor.h>
 
+#ifdef HAVE_GCONF
+#ifdef NA_ENABLE_DEPRECATED
+
 /* private class data
  */
 struct _NAGConfMonitorClassPrivate {
@@ -167,9 +169,13 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
+	static const gchar *thisfn = "na_gconf_monitor_instance_finalize";
 	NAGConfMonitor *self;
 
 	g_return_if_fail( NA_IS_GCONF_MONITOR( object ));
+
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 	self = NA_GCONF_MONITOR( object );
 
 	g_free( self->private->path );
@@ -196,6 +202,7 @@ instance_finalize( GObject *object )
  * triggeering the @handler in case of modifications.
  *
  * Since: 2.30
+ * Deprecated: 3.1
  */
 NAGConfMonitor *
 na_gconf_monitor_new( const gchar *path, GConfClientNotifyFunc handler, gpointer user_data )
@@ -263,6 +270,7 @@ install_monitor( NAGConfMonitor *monitor )
  * Release allocated monitors.
  *
  * Since: 2.30
+ * Deprecated: 3.1
  */
 void
 na_gconf_monitor_release_monitors( GList *monitors )
@@ -298,3 +306,6 @@ release_monitor( NAGConfMonitor *monitor )
 		}
 	}
 }
+
+#endif /* NA_ENABLE_DEPRECATED */
+#endif /* HAVE_GCONF */
