@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -42,9 +41,9 @@
 static void        dump_entry( GConfEntry *entry, void *user_data );
 static GConfValue *read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type );
 
-#ifndef NA_DISABLE_DEPRECATED
+#ifdef NA_ENABLE_DEPRECATED
 static gboolean    sync_gconf( GConfClient *gconf, gchar **message );
-#endif /* NA_DISABLE_DEPRECATED */
+#endif /* NA_ENABLE_DEPRECATED */
 
 /**
  * na_gconf_utils_get_subdirs:
@@ -319,6 +318,9 @@ dump_entry( GConfEntry *entry, void *user_data )
 	static const gchar *thisfn = "na_gconf_utils_dump_entry";
 	gchar *str = NULL;
 	gboolean str_free = FALSE;
+	GSList *value_list, *it;
+	GConfValueType type_list;
+	GString *string;
 
 	gchar *key = g_path_get_basename( gconf_entry_get_key( entry ));
 	GConfValue *value = gconf_entry_get_value( entry );
@@ -344,6 +346,27 @@ dump_entry( GConfEntry *entry, void *user_data )
 				str_free = TRUE;
 				break;
 
+			case GCONF_VALUE_LIST:
+				type_list = gconf_value_get_list_type( value );
+				value_list = gconf_value_get_list( value );
+				switch( type_list ){
+					case GCONF_VALUE_STRING:
+						string = g_string_new( "[" );
+						for( it = value_list ; it ; it = it->next ){
+							if( g_utf8_strlen( string->str, -1 ) > 1 ){
+								string = g_string_append( string, "," );
+							}
+							string = g_string_append( string, ( const gchar * ) gconf_value_get_string( it->data ));
+						}
+						string = g_string_append( string, "]" );
+						str = g_string_free( string, FALSE );
+						break;
+					default:
+						str = g_strdup( "(undetermined value)" );
+				}
+				str_free = TRUE;
+				break;
+
 			default:
 				str = g_strdup( "(undetermined value)" );
 				str_free = TRUE;
@@ -503,7 +526,7 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
 	return( list_strings );
 }
 
-#ifndef NA_DISABLE_DEPRECATED
+#ifdef NA_ENABLE_DEPRECATED
 /**
  * na_gconf_utils_write_bool:
  * @gconf: a GConfClient instance.
@@ -519,7 +542,7 @@ na_gconf_utils_read_string_list( GConfClient *gconf, const gchar *path )
  * It should be g_free() by the caller.
  *
  * Since: 2.30
- * Deprecated: 3.1.0
+ * Deprecated: 3.1
  */
 gboolean
 na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value, gchar **message )
@@ -557,7 +580,7 @@ na_gconf_utils_write_bool( GConfClient *gconf, const gchar *path, gboolean value
  * It should be g_free() by the caller.
  *
  * Since: 2.30
- * Deprecated: 3.1.0
+ * Deprecated: 3.1
  */
 gboolean
 na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gchar **message )
@@ -595,7 +618,7 @@ na_gconf_utils_write_int( GConfClient *gconf, const gchar *path, gint value, gch
  * It should be g_free() by the caller.
  *
  * Since: 2.30
- * Deprecated: 3.1.0
+ * Deprecated: 3.1
  */
 gboolean
 na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar *value, gchar **message )
@@ -633,7 +656,7 @@ na_gconf_utils_write_string( GConfClient *gconf, const gchar *path, const gchar
  * It should be g_free() by the caller.
  *
  * Since: 2.30
- * Deprecated: 3.1.0
+ * Deprecated: 3.1
  */
 gboolean
 na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList *value, gchar **message )
@@ -672,7 +695,7 @@ na_gconf_utils_write_string_list( GConfClient *gconf, const gchar *path, GSList
  * Returns: %TRUE if the operation was successful, %FALSE else.
  *
  * Since: 2.30
- * Deprecated: 3.1.0
+ * Deprecated: 3.1
  */
 gboolean
 na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **message )
@@ -711,7 +734,7 @@ na_gconf_utils_remove_entry( GConfClient *gconf, const gchar *path, gchar **mess
  * string was not of the GConf form.
  *
  * Since: 2.30
- * Deprecated: 3.1.0
+ * Deprecated: 3.1
  */
 GSList *
 na_gconf_utils_slist_from_string( const gchar *value )
@@ -747,7 +770,7 @@ na_gconf_utils_slist_from_string( const gchar *value )
  * allocated string which should be g_free() by the caller.
  *
  * Since: 2.30
- * Deprecated: 3.1.0
+ * Deprecated: 3.1
  */
 gchar *
 na_gconf_utils_slist_to_string( GSList *slist )
@@ -769,7 +792,7 @@ na_gconf_utils_slist_to_string( GSList *slist )
 
 	return( g_string_free( str, FALSE ));
 }
-#endif /* NA_DISABLE_DEPRECATED */
+#endif /* NA_ENABLE_DEPRECATED */
 
 static GConfValue *
 read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfValueType type )
@@ -804,7 +827,7 @@ read_value( GConfClient *gconf, const gchar *path, gboolean use_schema, GConfVal
 	return( value );
 }
 
-#ifndef NA_DISABLE_DEPRECATED
+#ifdef NA_ENABLE_DEPRECATED
 static gboolean
 sync_gconf( GConfClient *gconf, gchar **message )
 {
@@ -824,6 +847,6 @@ sync_gconf( GConfClient *gconf, gchar **message )
 
 	return( ret );
 }
-#endif /* NA_DISABLE_DEPRECATED */
+#endif /* NA_ENABLE_DEPRECATED */
 
 #endif /* HAVE_GCONF */
