@@ -1,25 +1,24 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -32,7 +31,13 @@
 #include <config.h>
 #endif
 
+#ifdef HAVE_GDBUS
+#include <gio/gio.h>
+#else
+# ifdef HAVE_DBUS_GLIB
 #include <dbus/dbus-glib.h>
+# endif
+#endif
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
@@ -45,8 +50,10 @@
 #include <api/na-core-utils.h>
 #include <api/na-object-api.h>
 
+#include "na-desktop-environment.h"
 #include "na-gnome-vfs-uri.h"
 #include "na-selected-info.h"
+#include "na-settings.h"
 
 /* private interface data
  */
@@ -54,40 +61,37 @@ struct _NAIContextInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
-static gboolean st_initialized = FALSE;
-static gboolean st_finalized   = FALSE;
+static guint st_initializations = 0;	/* interface initialization count */
 
-static GType    register_type( void );
-static void     interface_base_init( NAIContextInterface *klass );
-static void     interface_base_finalize( NAIContextInterface *klass );
+static GType        register_type( void );
+static void         interface_base_init( NAIContextInterface *klass );
+static void         interface_base_finalize( NAIContextInterface *klass );
 
-static void     convert_allfiles_mimetype( NAIContext *context );
+static gboolean     v_is_candidate( NAIContext *object, guint target, GList *selection );
 
-static gboolean v_is_candidate( NAIContext *object, guint target, GList *selection );
+static gboolean     is_candidate_for_target( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_show_in( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_try_exec( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_show_if_registered( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_show_if_true( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_show_if_running( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_mimetypes( const NAIContext *object, guint target, GList *files );
+static gboolean     is_all_mimetype( const gchar *mimetype );
+static gboolean     is_file_mimetype( const gchar *mimetype );
+static gboolean     is_mimetype_of( const gchar *file_type, const gchar *ftype, gboolean is_regular );
+static gboolean     is_candidate_for_basenames( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_selection_count( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_schemes( const NAIContext *object, guint target, GList *files );
+static gboolean     is_compatible_scheme( const gchar *pattern, const gchar *scheme );
+static gboolean     is_candidate_for_folders( const NAIContext *object, guint target, GList *files );
+static gboolean     is_candidate_for_capabilities( const NAIContext *object, guint target, GList *files );
 
-static gboolean is_candidate_for_target( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_show_in( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_try_exec( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_show_if_registered( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_show_if_true( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_show_if_running( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_mimetypes( const NAIContext *object, guint target, GList *files );
-static gboolean is_mimetype_of( const gchar *file_type, const gchar *group, const gchar *subgroup );
-static void     split_mimetype( const gchar *mimetype, gchar **group, gchar **subgroup );
-static gboolean is_candidate_for_basenames( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_selection_count( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_schemes( const NAIContext *object, guint target, GList *files );
-static gboolean is_compatible_scheme( const gchar *pattern, const gchar *scheme );
-static gboolean is_candidate_for_folders( const NAIContext *object, guint target, GList *files );
-static gboolean is_candidate_for_capabilities( const NAIContext *object, guint target, GList *files );
+static gboolean     is_valid_basenames( const NAIContext *object );
+static gboolean     is_valid_mimetypes( const NAIContext *object );
+static gboolean     is_valid_schemes( const NAIContext *object );
+static gboolean     is_valid_folders( const NAIContext *object );
 
-static gboolean is_valid_basenames( const NAIContext *object );
-static gboolean is_valid_mimetypes( const NAIContext *object );
-static gboolean is_valid_isfiledir( const NAIContext *object );
-static gboolean is_valid_schemes( const NAIContext *object );
-static gboolean is_valid_folders( const NAIContext *object );
-
-static gboolean is_positive_assertion( const gchar *assertion );
+static gboolean     is_positive_assertion( const gchar *assertion );
 
 /**
  * na_icontext_get_type:
@@ -143,14 +147,14 @@ interface_base_init( NAIContextInterface *klass )
 {
 	static const gchar *thisfn = "na_icontext_interface_base_init";
 
-	if( !st_initialized ){
+	if( !st_initializations ){
 
 		g_debug( "%s: klass%p (%s)", thisfn, ( void * ) klass, G_OBJECT_CLASS_NAME( klass ));
 
 		klass->private = g_new0( NAIContextInterfacePrivate, 1 );
-
-		st_initialized = TRUE;
 	}
+
+	st_initializations += 1;
 }
 
 static void
@@ -158,16 +162,41 @@ interface_base_finalize( NAIContextInterface *klass )
 {
 	static const gchar *thisfn = "na_icontext_interface_base_finalize";
 
-	if( st_initialized && !st_finalized ){
+	st_initializations -= 1;
+
+	if( !st_initializations ){
 
 		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
-		st_finalized = TRUE;
-
 		g_free( klass->private );
 	}
 }
 
+/**
+ * na_icontext_are_equal:
+ * @a: the (original) #NAIContext context.
+ * @b: the (duplicated) #NAIContext context to be checked.
+ *
+ * Returns: %TRUE if this @a and @b are equal, %FALSE else.
+ *
+ * Since: 3.1
+ */
+gboolean
+na_icontext_are_equal( const NAIContext *a, const NAIContext *b )
+{
+	static const gchar *thisfn = "na_icontext_are_equal";
+	gboolean are_equal;
+
+	g_return_val_if_fail( NA_IS_ICONTEXT( a ), FALSE );
+	g_return_val_if_fail( NA_IS_ICONTEXT( b ), FALSE );
+
+	g_debug( "%s: a=%p, b=%p", thisfn, ( void * ) a, ( void * ) b );
+
+	are_equal = TRUE;
+
+	return( are_equal );
+}
+
 /**
  * na_icontext_is_candidate:
  * @context: a #NAIContext to be checked.
@@ -222,7 +251,7 @@ na_icontext_is_candidate( const NAIContext *context, guint target, GList *select
 
 /**
  * na_icontext_is_valid:
- * @context: the #NAObjectProfile to be checked.
+ * @context: the #NAIContext to be checked.
  *
  * Returns: %TRUE if this @context is valid, %FALSE else.
  *
@@ -237,14 +266,16 @@ na_icontext_is_candidate( const NAIContext *context, guint target, GList *select
 gboolean
 na_icontext_is_valid( const NAIContext *context )
 {
+	static const gchar *thisfn = "na_icontext_is_valid";
 	gboolean is_valid;
 
 	g_return_val_if_fail( NA_IS_ICONTEXT( context ), FALSE );
 
+	g_debug( "%s: context=%p (%s)", thisfn, ( void * ) context, G_OBJECT_TYPE_NAME( context ));
+
 	is_valid =
 		is_valid_basenames( context ) &&
 		is_valid_mimetypes( context ) &&
-		is_valid_isfiledir( context ) &&
 		is_valid_schemes( context ) &&
 		is_valid_folders( context );
 
@@ -252,59 +283,68 @@ na_icontext_is_valid( const NAIContext *context )
 }
 
 /**
- * na_icontext_is_all_mimetypes:
+ * na_icontext_check_mimetypes:
  * @context: the #NAIContext object to be checked.
  *
- * Returns: %TRUE if this @context is valid for all mimetypes, %FALSE else.
+ * Check the current list of mimetypes to see if it covers all mimetypes,
+ * or all regular files, or something else.
  *
  * Since: 2.30
  */
-gboolean
-na_icontext_is_all_mimetypes( const NAIContext *context )
+void
+na_icontext_check_mimetypes( const NAIContext *context )
 {
+	static const gchar *thisfn = "na_icontext_check_mimetypes";
 	gboolean is_all;
 	GSList *mimetypes, *im;
 
-	g_return_val_if_fail( NA_IS_ICONTEXT( context ), FALSE );
+	g_return_if_fail( NA_IS_ICONTEXT( context ));
 
 	is_all = TRUE;
 	mimetypes = na_object_get_mimetypes( context );
 
 	for( im = mimetypes ; im ; im = im->next ){
 		if( !im->data || !strlen( im->data )){
+			g_debug( "%s: empty mimetype for context=%p", thisfn, ( void * ) context );
 			continue;
 		}
 		const gchar *imtype = ( const gchar * ) im->data;
-		if( !strcmp( imtype, "*" ) ||
-			!strcmp( imtype, "*/*" ) ||
-			!strcmp( imtype, "all" ) ||
-			!strcmp( imtype, "all/*" ) ||
-			!strcmp( imtype, "all/all" )){
-				continue;
+		if( is_all_mimetype( imtype )){
+			continue;
 		}
 		is_all = FALSE;
-		break;
+		/* do not break here so that we are able to check all mimetypes */
 	}
 
-	na_core_utils_slist_free( mimetypes );
+	na_object_set_all_mimetypes( context, is_all );
 
-	return( is_all );
+	na_core_utils_slist_free( mimetypes );
+}
+
+/**
+ * na_icontext_copy:
+ * @context: the target #NAIContext context.
+ * @source: the source #NAIContext context.
+ *
+ * Copy specific data from @source to @context.
+ *
+ * Since: 3.1
+ */
+void
+na_icontext_copy( NAIContext *context, const NAIContext *source )
+{
+	/* nothing to do for now */
 }
 
 /**
  * na_icontext_read_done:
  * @context: the #NAIContext to be prepared.
  *
- * Prepares the specified #NAIContext just after it has been readen.
+ * Prepares the specified #NAIContext just after it has been read.
  *
  * <itemizedlist>
  *   <listitem>
  *     <para>
- *       This converts a 'all/allfiles' mimetype to 'all/all' + 'file' scheme.
- *     </para>
- *   </listitem>
- *   <listitem>
- *     <para>
  *       This setup an internal flag when mimetypes is like 'all/all'
  *       in order to optimize computation time;
  *     </para>
@@ -316,9 +356,7 @@ na_icontext_is_all_mimetypes( const NAIContext *context )
 void
 na_icontext_read_done( NAIContext *context )
 {
-	convert_allfiles_mimetype( context );
-
-	na_object_set_all_mimetypes( context, na_icontext_is_all_mimetypes( context ));
+	na_object_check_mimetypes( context );
 }
 
 /**
@@ -414,55 +452,6 @@ na_icontext_replace_folder( NAIContext *context, const gchar *old, const gchar *
 	na_core_utils_slist_free( folders );
 }
 
-/*
- * Convert 'all/allfiles' mimetype to 'all/all' + 'file' scheme.
- * This takes into account
- * - all/allfiles, allfiles, allfiles/ * and allfiles/all
- * - negated assertions.
- */
-static void
-convert_allfiles_mimetype( NAIContext *context )
-{
-	GSList *mimetypes, *im;
-	GSList *schemes;
-	gchar *tmp;
-	gboolean modified;
-
-	modified = FALSE;
-	mimetypes = na_object_get_mimetypes( context );
-	schemes = na_object_get_schemes( context );
-
-	for( im = mimetypes ; im ; im = im->next ){
-		if( !im->data || !strlen( im->data )){
-			continue;
-		}
-
-		gchar *imtype = ( gchar * ) im->data;
-		gboolean positive = is_positive_assertion( imtype );
-		guint i = ( positive ? 0 : 1 );
-
-		if( !strcmp( imtype+i, "allfiles" ) ||
-			!strcmp( imtype+i, "allfiles/*" ) ||
-			!strcmp( imtype+i, "allfiles/all" ) ||
-			!strcmp( imtype+i, "all/allfiles" )){
-
-				g_free( im->data );
-				im->data = g_strdup( "all/all" );
-				tmp = g_strdup_printf( "%sfile", positive ? "" : "!" );
-				schemes = g_slist_prepend( schemes, tmp );
-				modified = TRUE;
-		}
-	}
-
-	if( modified ){
-		na_object_set_mimetypes( context, mimetypes );
-		na_object_set_schemes( context, schemes );
-	}
-
-	na_core_utils_slist_free( mimetypes );
-	na_core_utils_slist_free( schemes );
-}
-
 static gboolean
 v_is_candidate( NAIContext *context, guint target, GList *selection )
 {
@@ -531,17 +520,24 @@ is_candidate_for_show_in( const NAIContext *object, guint target, GList *files )
 	gboolean ok = TRUE;
 	GSList *only_in = na_object_get_only_show_in( object );
 	GSList *not_in = na_object_get_not_show_in( object );
-	gchar *environment;
+	static gchar *environment = NULL;
 
-	/* TODO: how-to get current running environment ? */
-	environment = g_strdup( "GNOME" );
-
-	if( environment && strlen( environment )){
-		if( only_in && g_slist_length( only_in )){
-			ok = ( na_core_utils_slist_count( only_in, environment ) > 0 );
-		} else if( not_in && g_slist_length( not_in )){
-			ok = ( na_core_utils_slist_count( not_in, environment ) == 0 );
+	/* there is a memory leak here when desktop comes from user preferences
+	 * because it is never freed (because it may come from runtime detection)
+	 * but this occurs only once..
+	 */
+	if( !environment ){
+		environment = na_settings_get_string( NA_IPREFS_DESKTOP_ENVIRONMENT, NULL, NULL );
+		if( !environment || !strlen( environment )){
+			environment = ( gchar * ) na_desktop_environment_detect_running_desktop();
 		}
+		g_debug( "%s: found %s desktop", thisfn, environment );
+	}
+
+	if( only_in && g_slist_length( only_in )){
+		ok = ( na_core_utils_slist_count( only_in, environment ) > 0 );
+	} else if( not_in && g_slist_length( not_in )){
+		ok = ( na_core_utils_slist_count( not_in, environment ) == 0 );
 	}
 
 	if( !ok ){
@@ -552,7 +548,6 @@ is_candidate_for_show_in( const NAIContext *object, guint target, GList *files )
 		g_free( only_str );
 	}
 
-	g_free( environment );
 	na_core_utils_slist_free( not_in );
 	na_core_utils_slist_free( only_in );
 
@@ -607,6 +602,9 @@ is_candidate_for_show_if_registered( const NAIContext *object, guint target, GLi
 
 	if( name && strlen( name )){
 		ok = FALSE;
+#ifdef HAVE_GDBUS
+#else
+# ifdef HAVE_DBUS_GLIB
 		GError *error = NULL;
 		DBusGConnection *connection = dbus_g_bus_get( DBUS_BUS_SESSION, &error );
 
@@ -621,6 +619,8 @@ is_candidate_for_show_if_registered( const NAIContext *object, guint target, GLi
 			ok = ( proxy != NULL );
 			dbus_g_connection_unref( connection );
 		}
+# endif
+#endif
 	}
 
 	if( !ok ){
@@ -735,23 +735,22 @@ is_candidate_for_mimetypes( const NAIContext *object, guint target, GList *files
 		GList *it;
 
 		for( it = files ; it && ok ; it = it->next ){
-			gchar *ftype, *fgroup, *fsubgroup;
-			gboolean match, positive;
+			gchar *ftype;
+			gboolean regular, match, positive;
 
 			match = FALSE;
 			ftype = na_selected_info_get_mime_type( NA_SELECTED_INFO( it->data ));
+			regular = na_selected_info_is_regular( NA_SELECTED_INFO( it->data ));
 
 			if( ftype ){
-				split_mimetype( ftype, &fgroup, &fsubgroup );
-
 				for( im = mimetypes ; im && ok ; im = im->next ){
 					const gchar *imtype = ( const gchar * ) im->data;
 					positive = is_positive_assertion( imtype );
 
 					if( !positive || !match ){
-						if( is_mimetype_of( positive ? imtype : imtype+1, fgroup, fsubgroup )){
-							g_debug( "%s: condition=%s, positive=%s, ftype=%s, fgroup=%s, fsubgroup=%s, matched",
-									thisfn, imtype, positive ? "True":"False", ftype, fgroup, fsubgroup );
+						if( is_mimetype_of( positive ? imtype : imtype+1, ftype, regular )){
+							g_debug( "%s: condition=%s, positive=%s, ftype=%s, matched",
+									thisfn, imtype, positive ? "True":"False", ftype );
 							if( positive ){
 								match = TRUE;
 							} else {
@@ -770,13 +769,11 @@ is_candidate_for_mimetypes( const NAIContext *object, guint target, GList *files
 
 			} else {
 				gchar *uri = na_selected_info_get_uri( NA_SELECTED_INFO( it->data ));
-				g_debug( "%s: null mimetype found for %s", thisfn, uri );
+				g_warning( "%s: null mimetype found for %s", thisfn, uri );
 				g_free( uri );
 				ok = FALSE;
 			}
 
-			g_free( fsubgroup );
-			g_free( fgroup );
 			g_free( ftype );
 		}
 
@@ -786,49 +783,65 @@ is_candidate_for_mimetypes( const NAIContext *object, guint target, GList *files
 	return( ok );
 }
 
-/*
- * does the file fgroup/fsubgrop have a mimetype which is 'a sort of'
- *  mimetype specified one ?
- * for example, "image/jpeg" is clearly a sort of "image/ *"
- * but how to check to see if "msword/xml" is a sort of "application/xml" ??
- */
 static gboolean
-is_mimetype_of( const gchar *mimetype, const gchar *fgroup, const gchar *fsubgroup )
+is_all_mimetype( const gchar *mimetype )
 {
-	gboolean is_type_of;
-	gchar *mgroup, *msubgroup;
+	return( !strcmp( mimetype, "*" ) ||
+			!strcmp( mimetype, "*/*" ) ||
+			!strcmp( mimetype, "*/all" ) ||	/* should be considered as invalid */
+			!strcmp( mimetype, "all" ) ||
+			!strcmp( mimetype, "all/*" ) ||
+			!strcmp( mimetype, "all/all" ));
+}
 
-	if( !strcmp( mimetype, "*" ) || !strcmp( mimetype, "*/*" )){
-		return( TRUE );
-	}
-
-	split_mimetype( mimetype, &mgroup, &msubgroup );
-
-	is_type_of = ( strcmp( fgroup, mgroup ) == 0 );
-	if( is_type_of ){
-		if( strcmp( msubgroup, "*" ) != 0 ){
-			is_type_of = ( strcmp( fsubgroup, msubgroup ) == 0 );
-		}
-	}
-
-	g_free( mgroup );
-	g_free( msubgroup );
-
-	return( is_type_of );
+static gboolean
+is_file_mimetype( const gchar *mimetype )
+{
+	return( !strcmp( mimetype, "allfiles" ) ||
+			!strcmp( mimetype, "*/allfiles" ) ||	/* should be considered as invalid */
+			!strcmp( mimetype, "allfiles/*" ) ||
+			!strcmp( mimetype, "allfiles/all" ) ||
+			!strcmp( mimetype, "all/allfiles" ));
 }
 
 /*
- * split the given mimetype to its group and subgroup components
+ * does the file fgroup/fsubgroup have a mimetype which is 'a sort of'
+ *  mimetype specified one ?
+ * for example, "image/jpeg" is clearly a sort of "image/ *"
+ *
+ * content type if the same as the mime type in *nix;
+ * this is not true on Win32 platforms
  */
-static void
-split_mimetype( const gchar *mimetype, gchar **group, gchar **subgroup )
+static gboolean
+is_mimetype_of( const gchar *mimetype, const gchar *ftype, gboolean is_regular )
 {
-	GSList *slist = na_core_utils_slist_from_split( mimetype, "/" );
-	GSList *is = slist;
-	*group = g_strdup(( const gchar * ) is->data );
-	is = is->next;
-	*subgroup = g_strdup(( const gchar * ) is->data );
-	na_core_utils_slist_free( slist );
+	static const gchar *thisfn = "na_icontext_is_mimetype_of";
+	gboolean is_type_of;
+	gchar *file_content_type, *def_content_type;
+
+	if( is_all_mimetype( mimetype )){
+		return( TRUE );
+	}
+
+	if( is_file_mimetype( mimetype ) && is_regular ){
+		return( TRUE );
+	}
+
+	is_type_of = FALSE;
+	file_content_type = g_content_type_from_mime_type( ftype );
+	def_content_type = g_content_type_from_mime_type( mimetype );
+
+	if( file_content_type && def_content_type ){
+		is_type_of = g_content_type_is_a( file_content_type, def_content_type );
+		g_debug( "%s: def_mimetype=%s content_type=%s file_mimetype=%s content_type=%s is_a=%s",
+				thisfn, mimetype, def_content_type, ftype, file_content_type,
+				is_type_of ? "True":"False" );
+	}
+
+	g_free( file_content_type );
+	g_free( def_content_type );
+
+	return( is_type_of );
 }
 
 static gboolean
@@ -853,7 +866,7 @@ is_candidate_for_basenames( const NAIContext *object, guint target, GList *files
 				bname = na_selected_info_get_basename( NA_SELECTED_INFO( it->data ));
 				bname_utf8 = g_filename_to_utf8( bname, -1, NULL, NULL, NULL );
 				if( !matchcase ){
-					tmp = g_ascii_strdown( bname_utf8, g_utf8_strlen( bname_utf8, -1 ));
+					tmp = g_utf8_strdown( bname_utf8, -1 );
 					g_free( bname_utf8 );
 					bname_utf8 = tmp;
 				}
@@ -862,7 +875,7 @@ is_candidate_for_basenames( const NAIContext *object, guint target, GList *files
 				for( ib = basenames ; ib && ok ; ib = ib->next ){
 					pattern = matchcase ?
 						g_strdup(( gchar * ) ib->data ) :
-						g_ascii_strdown(( gchar * ) ib->data, strlen(( gchar * ) ib->data ));
+						g_utf8_strdown(( gchar * ) ib->data, -1 );
 					positive = is_positive_assertion( pattern );
 					pattern_utf8 = g_filename_to_utf8( positive ? pattern : pattern+1, -1, NULL, NULL, NULL );
 
@@ -1004,6 +1017,7 @@ is_candidate_for_schemes( const NAIContext *object, guint target, GList *files )
 		na_core_utils_slist_free( schemes );
 	}
 
+	g_debug( "%s: ok=%s", thisfn, ok ? "True":"False" );
 	return( ok );
 }
 
@@ -1014,7 +1028,7 @@ is_compatible_scheme( const gchar *pattern, const gchar *scheme )
 
 	compatible = FALSE;
 
-	if( strcmp( pattern, "*" )){
+	if( strcmp( pattern, "*" ) == 0 ){
 		compatible = TRUE;
 	} else {
 		compatible = ( strcmp( pattern, scheme ) == 0 );
@@ -1024,8 +1038,8 @@ is_compatible_scheme( const gchar *pattern, const gchar *scheme )
 }
 
 /*
- * assumuing here the same sort of optimization than for schemes
- * i.e. we assume that all selected items are must probably located
+ * assuming here the same sort of optimization than for schemes
+ * i.e. we assume that all selected items are most probably located
  * in the same dirname
  * so we take care of only checking _distinct_ dirnames against folder
  * conditions
@@ -1046,7 +1060,7 @@ is_candidate_for_folders( const NAIContext *object, guint target, GList *files )
 				gchar *dirname = na_selected_info_get_dirname( NA_SELECTED_INFO( it->data ));
 
 				if( na_core_utils_slist_count( distincts, dirname ) == 0 ){
-					g_debug( "%s: distinct dirname=%s", thisfn, dirname );
+					g_debug( "%s: examining new distinct selected dirname=%s", thisfn, dirname );
 
 					GSList *id;
 					gchar *dirname_utf8, *pattern_utf8;
@@ -1056,34 +1070,22 @@ is_candidate_for_folders( const NAIContext *object, guint target, GList *files )
 
 					distincts = g_slist_prepend( distincts, g_strdup( dirname ));
 					dirname_utf8 = g_filename_to_utf8( dirname, -1, NULL, NULL, NULL );
-					match = FALSE;
 
 					for( id = folders ; id && ok ; id = id->next ){
 						pattern = ( const gchar * ) id->data;
+						g_debug( "%s: examining new condition pattern=%s", thisfn, pattern );
 						positive = is_positive_assertion( pattern );
 						pattern_utf8 = g_filename_to_utf8( positive ? pattern : pattern+1, -1, NULL, NULL, NULL );
 						has_pattern = ( g_strstr_len( pattern_utf8, -1, "*" ) != NULL );
 
-						if( !positive || !match ){
-							if(( has_pattern && g_pattern_match_simple( pattern_utf8, dirname_utf8 )) || g_str_has_prefix( dirname_utf8, pattern_utf8 )){
-								g_debug( "%s: condition=%s, positive=%s: matched",
-										thisfn, pattern, positive ? "True":"False" );
-								if( positive ){
-									match = TRUE;
-								} else {
-									ok = FALSE;
-								}
-							/*} else {
-								g_debug( "%s: condition=%s, positive=%s: not matched",
-										thisfn, pattern_utf8, positive ? "True":"False" );*/
-							}
-						}
+						match = ( has_pattern && g_pattern_match_simple( pattern_utf8, dirname_utf8 )) ||
+								g_str_has_prefix( dirname_utf8, pattern_utf8 );
+
+						ok &= ( match && positive ) || ( !match && !positive );
 
 						g_free( pattern_utf8 );
 					}
 
-					ok &= match;
-
 					g_free( dirname_utf8 );
 				}
 
@@ -1176,37 +1178,58 @@ is_valid_basenames( const NAIContext *object )
 	return( valid );
 }
 
+/*
+ * check
+ *  that the list is not empty
+ *  that there is not empty item
+ *  that no mimetype is coded as '* / something'
+ */
 static gboolean
 is_valid_mimetypes( const NAIContext *object )
 {
+	static const gchar *thisfn = "na_icontext_is_valid_mimetypes";
 	gboolean valid;
-	GSList *mimetypes;
+	GSList *mimetypes, *it;
+	guint count_ok, count_errs;
+	const gchar *imtype;
 
 	mimetypes = na_object_get_mimetypes( object );
-	valid = mimetypes && g_slist_length( mimetypes ) > 0;
-	na_core_utils_slist_free( mimetypes );
+	count_ok = 0;
+	count_errs = 0;
+
+	for( it = mimetypes ; it ; it = it->next ){
+		imtype = ( const gchar * ) it->data;
+
+		if( !imtype || !strlen( imtype )){
+			g_debug( "%s: null or empty mimetype", thisfn );
+			count_errs +=1;
+			continue;
+		}
+
+		if( imtype[0] == '*' ){
+			if( imtype[1] ){
+				if( imtype[1] != '/' ){
+					g_debug( "%s: invalid mimetype: %s", thisfn, imtype );
+					count_errs +=1;
+					continue;
+				}
+				if( imtype[2] && imtype[2] != '*' ){
+					g_debug( "%s: invalid mimetype: %s", thisfn, imtype );
+					count_errs +=1;
+					continue;
+				}
+			}
+		}
+		count_ok += 1;
+	}
+
+	valid = ( count_ok > 0 && count_errs == 0 );
 
 	if( !valid ){
 		na_object_debug_invalid( object, "mimetypes" );
 	}
 
-	return( valid );
-}
-
-static gboolean
-is_valid_isfiledir( const NAIContext *object )
-{
-	gboolean valid;
-	gboolean isfile, isdir;
-
-	isfile = na_object_is_file( object );
-	isdir = na_object_is_dir( object );
-
-	valid = isfile || isdir;
-
-	if( !valid ){
-		na_object_debug_invalid( object, "isfiledir" );
-	}
+	na_core_utils_slist_free( mimetypes );
 
 	return( valid );
 }
