@@ -1,25 +1,24 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -44,8 +43,7 @@ struct _NAIFactoryProviderInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
-gboolean ifactory_provider_initialized = FALSE;
-gboolean ifactory_provider_finalized   = FALSE;
+static guint st_initializations = 0;	/* interface initialization count */
 
 static GType register_type( void );
 static void  interface_base_init( NAIFactoryProviderInterface *klass );
@@ -109,7 +107,7 @@ interface_base_init( NAIFactoryProviderInterface *klass )
 {
 	static const gchar *thisfn = "na_ifactory_provider_interface_base_init";
 
-	if( !ifactory_provider_initialized ){
+	if( !st_initializations ){
 
 		g_debug( "%s: klass=%p (%s)", thisfn, ( void * ) klass, G_OBJECT_CLASS_NAME( klass ));
 
@@ -122,9 +120,9 @@ interface_base_init( NAIFactoryProviderInterface *klass )
 		klass->write_start = NULL;
 		klass->write_data = NULL;
 		klass->write_done = NULL;
-
-		ifactory_provider_initialized = TRUE;
 	}
+
+	st_initializations += 1;
 }
 
 static void
@@ -132,12 +130,12 @@ interface_base_finalize( NAIFactoryProviderInterface *klass )
 {
 	static const gchar *thisfn = "na_ifactory_provider_interface_base_finalize";
 
-	if( ifactory_provider_initialized && !ifactory_provider_finalized ){
+	st_initializations -= 1;
+
+	if( !st_initializations ){
 
 		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
-		ifactory_provider_finalized = TRUE;
-
 		g_free( klass->private );
 	}
 }
@@ -166,7 +164,7 @@ ifactory_provider_get_version( const NAIFactoryProvider *instance )
  * <example>
  *   <programlisting>
  *     &lcomment;
- *      * allocate the object to be readen
+ *      * allocate the object to be read
  *      &rcomment;
  *     NAObjectItem *item = NA_OBJECT_ITEM( na_object_action_new());
  *     &lcomment;
@@ -192,12 +190,9 @@ na_ifactory_provider_read_item( const NAIFactoryProvider *reader, void *reader_d
 	g_return_if_fail( NA_IS_IFACTORY_PROVIDER( reader ));
 	g_return_if_fail( NA_IS_IFACTORY_OBJECT( object ));
 
-	if( ifactory_provider_initialized && !ifactory_provider_finalized ){
-
-		v_factory_provider_read_start( reader, reader_data, object, messages );
-		na_factory_object_read_item( object, reader, reader_data, messages );
-		v_factory_provider_read_done( reader, reader_data, object, messages );
-	}
+	v_factory_provider_read_start( reader, reader_data, object, messages );
+	na_factory_object_read_item( object, reader, reader_data, messages );
+	v_factory_provider_read_done( reader, reader_data, object, messages );
 }
 
 /**
@@ -224,22 +219,17 @@ na_ifactory_provider_write_item( const NAIFactoryProvider *writer, void *writer_
 	g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( writer ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
 	g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
 
-	code = NA_IIO_PROVIDER_CODE_NOT_WILLING_TO_RUN;
+	g_debug( "%s: writer=%p, writer_data=%p, object=%p (%s)",
+			thisfn, ( void * ) writer, ( void * ) writer_data, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
-	if( ifactory_provider_initialized && !ifactory_provider_finalized ){
+	code = v_factory_provider_write_start( writer, writer_data, object, messages );
 
-		g_debug( "%s: writer=%p, writer_data=%p, object=%p (%s)",
-				thisfn, ( void * ) writer, ( void * ) writer_data, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+	if( code == NA_IIO_PROVIDER_CODE_OK ){
+		code = na_factory_object_write_item( object, writer, writer_data, messages );
+	}
 
-		code = v_factory_provider_write_start( writer, writer_data, object, messages );
-
-		if( code == NA_IIO_PROVIDER_CODE_OK ){
-			code = na_factory_object_write_item( object, writer, writer_data, messages );
-		}
-
-		if( code == NA_IIO_PROVIDER_CODE_OK ){
-			code = v_factory_provider_write_done( writer, writer_data, object, messages );
-		}
+	if( code == NA_IIO_PROVIDER_CODE_OK ){
+		code = v_factory_provider_write_done( writer, writer_data, object, messages );
 	}
 
 	return( code );
