@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -76,18 +75,18 @@ static void         object_dump( const NAObject *object );
 static gboolean     object_are_equal( const NAObject *a, const NAObject *b );
 static gboolean     object_is_valid( const NAObject *object );
 
-static void         ifactory_object_iface_init( NAIFactoryObjectInterface *iface );
+static void         ifactory_object_iface_init( NAIFactoryObjectInterface *iface, void *user_data );
 static guint        ifactory_object_get_version( const NAIFactoryObject *instance );
 static NADataGroup *ifactory_object_get_groups( const NAIFactoryObject *instance );
 static void         ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static guint        ifactory_object_write_start( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
-static void         icontext_iface_init( NAIContextInterface *iface );
+static void         icontext_iface_init( NAIContextInterface *iface, void *user_data );
 static gboolean     icontext_is_candidate( NAIContext *object, guint target, GList *selection );
 
-static gboolean     read_done_convert_v1_to_last( NAIFactoryObject *instance );
-static void         read_done_deals_with_toolbar_label( NAIFactoryObject *instance );
+static NAObjectProfile *read_done_convert_v1_to_v2( NAIFactoryObject *instance );
+static void             read_done_deals_with_toolbar_label( NAIFactoryObject *instance );
 
 static guint        write_done_write_profiles( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
@@ -139,11 +138,11 @@ register_type( void )
 
 	g_debug( "%s", thisfn );
 
-	type = g_type_register_static( NA_OBJECT_ITEM_TYPE, "NAObjectAction", &info, 0 );
+	type = g_type_register_static( NA_TYPE_OBJECT_ITEM, "NAObjectAction", &info, 0 );
 
-	g_type_add_interface_static( type, NA_ICONTEXT_TYPE, &icontext_iface_info );
+	g_type_add_interface_static( type, NA_TYPE_ICONTEXT, &icontext_iface_info );
 
-	g_type_add_interface_static( type, NA_IFACTORY_OBJECT_TYPE, &ifactory_object_iface_info );
+	g_type_add_interface_static( type, NA_TYPE_IFACTORY_OBJECT, &ifactory_object_iface_info );
 
 	return( type );
 }
@@ -351,11 +350,11 @@ object_is_valid( const NAObject *object )
 }
 
 static void
-ifactory_object_iface_init( NAIFactoryObjectInterface *iface )
+ifactory_object_iface_init( NAIFactoryObjectInterface *iface, void *user_data )
 {
 	static const gchar *thisfn = "na_object_action_ifactory_object_iface_init";
 
-	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
+	g_debug( "%s: iface=%p, user_data=%p", thisfn, ( void * ) iface, ( void * ) user_data );
 
 	iface->get_version = ifactory_object_get_version;
 	iface->get_groups = ifactory_object_get_groups;
@@ -378,24 +377,26 @@ ifactory_object_get_groups( const NAIFactoryObject *instance )
 
 /*
  * at this time, we don't yet have read the profiles as this will be
- * done in ifactory_provider_read_done - we so just be able to deal with
- * action-specific properties (not check for profiles consistency)
+ * triggered by ifactory_provider_read_done - we so just are able to deal with
+ * action-specific properties (not to check for profiles consistency)
  */
 static void
 ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages )
 {
 	guint iversion;
+	NAObjectProfile *profile;
 
 	g_debug( "na_object_action_ifactory_object_read_done: instance=%p", ( void * ) instance );
 
 	na_object_item_deals_with_version( NA_OBJECT_ITEM( instance ));
 
-	/* may attach a new profile if we detect a pre-v2 action
+	/* should attach a new profile if we detect a pre-v2 action
 	 * the v1_to_v2 conversion must be followed by a v2_to_v3 one
 	 */
 	iversion = na_object_get_iversion( instance );
 	if( iversion < 2 ){
-		read_done_convert_v1_to_last( instance );
+		profile = read_done_convert_v1_to_v2( instance );
+		na_object_profile_convert_v2_to_last( profile );
 	}
 
 	/* deals with obsoleted data, i.e. data which may have been written in the past
@@ -407,9 +408,7 @@ ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider
 	 */
 	na_icontext_read_done( NA_ICONTEXT( instance ));
 
-	na_object_dump( instance );
-
-	/* last, set other action defaults
+	/* last, set action defaults
 	 */
 	na_factory_object_set_defaults( instance );
 }
@@ -435,11 +434,11 @@ ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider
 }
 
 static void
-icontext_iface_init( NAIContextInterface *iface )
+icontext_iface_init( NAIContextInterface *iface, void *user_data )
 {
 	static const gchar *thisfn = "na_object_action_icontext_iface_init";
 
-	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
+	g_debug( "%s: iface=%p, user_data=%p", thisfn, ( void * ) iface, ( void * ) user_data );
 
 	iface->is_candidate = icontext_is_candidate;
 }
@@ -451,18 +450,17 @@ icontext_is_candidate( NAIContext *object, guint target, GList *selection )
 }
 
 /*
- * do we have a pre-v2 action ?
- *  it is be identified by an version = "1.x"
+ * if we have a pre-v2 action
  *  any data found in data_def_action_v1 (defined in na-object-action-factory.c)
- *  is obsoleted and moved to a new profile
+ *  is obsoleted and should be moved to a new profile
  *
  * actions read from .desktop already have iversion=3 (cf. desktop_read_start)
- * and v1 actions may only come from xml or gconf
+ * so v1 actions may only come from xml or gconf
  *
- * returns TRUE if this actually was a v1 action which has been converted to v2
+ * returns the newly defined profile
  */
-static gboolean
-read_done_convert_v1_to_last( NAIFactoryObject *instance )
+static NAObjectProfile *
+read_done_convert_v1_to_v2( NAIFactoryObject *instance )
 {
 	static const gchar *thisfn = "na_object_action_read_done_read_done_convert_v1_to_last";
 	GList *to_move;
@@ -478,7 +476,7 @@ read_done_convert_v1_to_last( NAIFactoryObject *instance )
 	def = data_def_action_v1;
 
 	while( def->name ){
-		boxed = na_ifactory_object_get_data_boxed( instance , def->name );
+		boxed = na_ifactory_object_get_data_boxed( instance, def->name );
 		if( boxed ){
 			g_debug( "%s: boxed=%p (%s) marked to be moved from action body to profile",
 							 thisfn, ( void * ) boxed, def->name );
@@ -487,10 +485,6 @@ read_done_convert_v1_to_last( NAIFactoryObject *instance )
 		def++;
 	}
 
-	if( !to_move ){
-		return( FALSE );
-	}
-
 	/* now create a new profile
 	 */
 	profile = na_object_profile_new();
@@ -498,16 +492,12 @@ read_done_convert_v1_to_last( NAIFactoryObject *instance )
 	na_object_set_label( profile, _( "Profile automatically created from pre-v2 action" ));
 	na_object_attach_profile( instance, profile );
 
-	if( to_move ){
-		for( ibox = to_move ; ibox ; ibox = ibox->next ){
-			na_factory_object_move_boxed(
-					NA_IFACTORY_OBJECT( profile ), instance, NA_DATA_BOXED( ibox->data ));
-		}
+	for( ibox = to_move ; ibox ; ibox = ibox->next ){
+		na_factory_object_move_boxed(
+				NA_IFACTORY_OBJECT( profile ), instance, NA_DATA_BOXED( ibox->data ));
 	}
 
-	na_factory_object_set_defaults( NA_IFACTORY_OBJECT( profile ));
-	na_object_profile_convert_v2_to_last( profile );
-	return( TRUE );
+	return( profile );
 }
 
 /*
@@ -616,7 +606,7 @@ na_object_action_new( void )
 {
 	NAObjectAction *action;
 
-	action = g_object_new( NA_OBJECT_ACTION_TYPE, NULL );
+	action = g_object_new( NA_TYPE_OBJECT_ACTION, NULL );
 
 	return( action );
 }
@@ -638,7 +628,7 @@ na_object_action_new_with_profile( void )
 
 	action = na_object_action_new();
 	profile = na_object_profile_new();
-	na_object_action_attach_profile( action, profile );
+	na_object_attach_profile( action, profile );
 
 	return( action );
 }
@@ -666,7 +656,7 @@ na_object_action_new_with_defaults( void )
 	na_factory_object_set_defaults( NA_IFACTORY_OBJECT( action ));
 
 	profile = na_object_profile_new_with_defaults();
-	na_object_action_attach_profile( action, profile );
+	na_object_attach_profile( action, profile );
 
 	return( action );
 }
