@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -36,25 +35,30 @@
 #include <api/na-data-def.h>
 #include <api/na-data-types.h>
 
+/*
+ * As of 3.2 non copyables data are:
+ * - the parent pointer
+ */
+
 NADataDef data_def_id [] = {
 
-	/* this data is marked non readable / non writable as it has to be readen
-	 * written specifically when serializing / unserializing items
+	/* this data is marked non readable / non writable as it has to be read
+	 * written specifically when serializing / deserializing items
 	 */
 	{ NAFO_DATA_ID,
 				FALSE,
 				FALSE,
 				TRUE,
-				"NAObjectId identifiant",
-				"Internal identifiant of the NAObjectId object. " \
+				"NAObjectId identifier",
+				"Internal identifier of the NAObjectId object. " \
 				"Historically a UUID used as a GConf directory (thus ASCII, case insensitive), " \
 				"it is also the basename of the .desktop file (thus UTF-8, case sensitive).",
-				NAFD_TYPE_STRING,
-				NULL,
+				NA_DATA_TYPE_STRING,
+				"",
 				FALSE,
 				TRUE,
 				TRUE,
-				TRUE,
+				TRUE,			/* mandatory */
 				FALSE,
 				NULL,
 				NULL,
@@ -73,7 +77,7 @@ NADataDef data_def_id [] = {
 				TRUE,
 				"NAObjectId Parent",
 				"The NAObjectItem which is the parent of this object.",
-				NAFD_TYPE_POINTER,
+				NA_DATA_TYPE_POINTER,
 				NULL,
 				FALSE,
 				FALSE,
