@@ -1,25 +1,24 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -57,8 +56,6 @@ static void     instance_init( GTypeInstance *instance, gpointer klass );
 static void     instance_dispose( GObject *object );
 static void     instance_finalize( GObject *object );
 
-static gboolean object_is_valid( const NAObject *object );
-
 static gchar   *v_new_id( const NAObjectId *object, const NAObjectId *new_parent );
 
 GType
@@ -93,7 +90,7 @@ register_type( void )
 
 	g_debug( "%s", thisfn );
 
-	type = g_type_register_static( NA_OBJECT_TYPE, "NAObjectId", &info, 0 );
+	type = g_type_register_static( NA_TYPE_OBJECT, "NAObjectId", &info, 0 );
 
 	return( type );
 }
@@ -103,7 +100,6 @@ class_init( NAObjectIdClass *klass )
 {
 	static const gchar *thisfn = "na_object_id_class_init";
 	GObjectClass *object_class;
-	NAObjectClass *naobject_class;
 
 	g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
@@ -113,28 +109,18 @@ class_init( NAObjectIdClass *klass )
 	object_class->dispose = instance_dispose;
 	object_class->finalize = instance_finalize;
 
-	naobject_class = NA_OBJECT_CLASS( klass );
-	naobject_class->dump = NULL;
-	naobject_class->copy = NULL;
-	naobject_class->are_equal = NULL;
-	naobject_class->is_valid = object_is_valid;
-
 	klass->private = g_new0( NAObjectIdClassPrivate, 1 );
 }
 
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-	static const gchar *thisfn = "na_object_id_instance_init";
 	NAObjectId *self;
 
 	g_return_if_fail( NA_IS_OBJECT_ID( instance ));
 
 	self = NA_OBJECT_ID( instance );
 
-	g_debug( "%s: instance=%p (%s), klass=%p",
-			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-
 	self->private = g_new0( NAObjectIdPrivate, 1 );
 }
 
@@ -147,7 +133,6 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_dispose( GObject *object )
 {
-	static const gchar *thisfn = "na_object_id_instance_dispose";
 	NAObjectId *self;
 	NAObjectItem *parent;
 
@@ -157,16 +142,11 @@ instance_dispose( GObject *object )
 
 	if( !self->private->dispose_has_run ){
 
-		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
 		self->private->dispose_has_run = TRUE;
 
 		parent = na_object_get_parent( object );
-		g_debug( "%s: parent=%p (%s)",
-				thisfn, ( void * ) parent, parent ? G_OBJECT_TYPE_NAME( parent ) : "n/a" );
 		if( parent ){
 			na_object_remove_item( parent, object );
-			na_object_set_parent( object, NULL );
 		}
 
 		self->private->dispose_has_run = TRUE;
@@ -195,26 +175,6 @@ instance_finalize( GObject *object )
 	}
 }
 
-/*
- * a NAObjectId is valid if it has a non-null id
- */
-static gboolean
-object_is_valid( const NAObject *object )
-{
-	gboolean is_valid;
-	gchar *id;
-
-	is_valid = TRUE;
-
-	if( is_valid ){
-		id = na_object_get_id( object );
-		is_valid = ( id != NULL && strlen( id ) > 0 );
-		g_free( id );
-	}
-
-	return( is_valid );
-}
-
 /**
  * na_object_id_sort_alpha_asc:
  * @a: first #NAObjectId.
@@ -297,8 +257,8 @@ na_object_id_sort_alpha_desc( const NAObjectId *a, const NAObjectId *b )
  * #NAObjectAction @action. The identifier is always renumbered to be
  * suitable with the already existing profiles.
  *
- * If a #NAObjectAction or a #NAObjectMenu, a new UUID is allocated if
- * and only if @relabel is %TRUE.
+ * If a #NAObjectAction or a #NAObjectMenu, a new identifier is allocated
+ * if and only if @relabel is %TRUE.
  *
  * Actual relabeling takes place if @relabel is %TRUE, depending of the
  * user preferences.
@@ -377,7 +337,7 @@ na_object_id_set_copy_of_label( NAObjectId *object )
 
 /**
  * na_object_id_set_new_id:
- * @object: the #NAObjectId object whose internal identifiant is to be
+ * @object: the #NAObjectId object whose internal identifier is to be
  * set.
  * @new_parent: if @object is a #NAObjectProfile, then @new_parent
  * should be set to the #NAObjectAction new parent. Else, it would not
@@ -415,27 +375,11 @@ na_object_id_set_new_id( NAObjectId *object, const NAObjectId *new_parent )
 static gchar *
 v_new_id( const NAObjectId *object, const NAObjectId *new_parent )
 {
-	gchar *new_id;
-	GList *hierarchy, *ih;
-	gboolean found;
+	gchar *new_id = NULL;
 
-	found = FALSE;
-	new_id = NULL;
-	hierarchy = g_list_reverse( na_object_get_hierarchy( NA_OBJECT( object )));
-	/*g_debug( "na_object_id_most_derived_id: object=%p (%s)",
-					( void * ) object, G_OBJECT_TYPE_NAME( object ));*/
-
-	for( ih = hierarchy ; ih && !found ; ih = ih->next ){
-		if( NA_OBJECT_ID_CLASS( ih->data )->new_id ){
-			new_id = NA_OBJECT_ID_CLASS( ih->data )->new_id( object, new_parent );
-			found = TRUE;
-		}
-		if( G_OBJECT_CLASS_TYPE( ih->data ) == NA_OBJECT_ID_TYPE ){
-			break;
-		}
+	if( NA_OBJECT_ID_GET_CLASS( object )->new_id ){
+		new_id = NA_OBJECT_ID_GET_CLASS( object )->new_id( object, new_parent );
 	}
 
-	na_object_free_hierarchy( hierarchy );
-
 	return( new_id );
 }
