@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -52,29 +51,32 @@ struct _NAObjectItemClassPrivate {
 struct _NAObjectItemPrivate {
 	gboolean   dispose_has_run;
 
-	void      *provider_data;
-
-	/* dynamically set when reading the item from the I/O storage
-	 * subsystem; may be reset from FALSE to TRUE if a write operation
-	 * has returned an error.
-	 * defaults to FALSE for snew, not yet written to a provider, item
+	/* set at load time
+	 * takes into account the runtime 'readonly' status as well as the i/o
+	 * provider writability status - does not consider the level-zero case
 	 */
-	gboolean   readonly;
+	gboolean   writable;
+	guint      reason;
 };
 
 static NAObjectIdClass *st_parent_class = NULL;
 
-static GType  register_type( void );
-static void   class_init( NAObjectItemClass *klass );
-static void   instance_init( GTypeInstance *instance, gpointer klass );
-static void   instance_dispose( GObject *object );
-static void   instance_finalize( GObject *object );
+static GType    register_type( void );
+static void     class_init( NAObjectItemClass *klass );
+static void     instance_init( GTypeInstance *instance, gpointer klass );
+static void     instance_dispose( GObject *object );
+static void     instance_finalize( GObject *object );
 
-static void   object_copy( NAObject*target, const NAObject *source, gboolean recursive );
+static void     object_dump( const NAObject *object );
+static void     object_copy( NAObject*target, const NAObject *source, guint mode );
+static gboolean object_are_equal( const NAObject *a, const NAObject *b );
+static gboolean object_is_valid( const NAObject *object );
 
-static gchar *object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent );
+static gchar   *object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent );
 
-static void   copy_children( NAObjectItem *target, const NAObjectItem *source );
+static void     count_items_rec( GList *items, gint *menus, gint *actions, gint *profiles, gboolean recurse );
+static GSList  *get_children_slist( const NAObjectItem *item );
+static void     copy_children( NAObjectItem *target, const NAObjectItem *source, guint mode );
 
 GType
 na_object_item_get_type( void )
@@ -108,7 +110,7 @@ register_type( void )
 
 	g_debug( "%s", thisfn );
 
-	type = g_type_register_static( NA_OBJECT_ID_TYPE, "NAObjectItem", &info, 0 );
+	type = g_type_register_static( NA_TYPE_OBJECT_ID, "NAObjectItem", &info, 0 );
 
 	return( type );
 }
@@ -130,10 +132,10 @@ class_init( NAObjectItemClass *klass )
 	object_class->finalize = instance_finalize;
 
 	naobject_class = NA_OBJECT_CLASS( klass );
-	naobject_class->dump = NULL;
+	naobject_class->dump = object_dump;
 	naobject_class->copy = object_copy;
-	naobject_class->are_equal = NULL;
-	naobject_class->is_valid = NULL;
+	naobject_class->are_equal = object_are_equal;
+	naobject_class->is_valid = object_is_valid;
 
 	naobjectid_class = NA_OBJECT_ID_CLASS( klass );
 	naobjectid_class->new_id = object_id_new_id;
@@ -144,23 +146,22 @@ class_init( NAObjectItemClass *klass )
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-	static const gchar *thisfn = "na_object_item_instance_init";
 	NAObjectItem *self;
 
 	g_return_if_fail( NA_IS_OBJECT_ITEM( instance ));
 
 	self = NA_OBJECT_ITEM( instance );
 
-	g_debug( "%s: instance=%p (%s), klass=%p",
-			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-
 	self->private = g_new0( NAObjectItemPrivate, 1 );
+
+	self->private->dispose_has_run = FALSE;
+	self->private->writable = TRUE;
+	self->private->reason = 0;
 }
 
 static void
 instance_dispose( GObject *object )
 {
-	static const gchar *thisfn = "na_object_item_instance_dispose";
 	NAObjectItem *self;
 	GList *children;
 
@@ -170,14 +171,11 @@ instance_dispose( GObject *object )
 
 	if( !self->private->dispose_has_run ){
 
-		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
 		self->private->dispose_has_run = TRUE;
 
 		children = na_object_get_items( self );
-		g_debug( "%s: children=%p (count=%d)", thisfn, ( void * ) children, g_list_length( children ));
 		na_object_set_items( self, NULL );
-		na_object_unref_items( children );
+		na_object_free_items( children );
 
 		/* chain up to the parent class */
 		if( G_OBJECT_CLASS( st_parent_class )->dispose ){
@@ -204,19 +202,46 @@ instance_finalize( GObject *object )
 }
 
 static void
-object_copy( NAObject *target, const NAObject *source, gboolean recursive )
+object_dump( const NAObject *object )
+{
+	static const gchar *thisfn = "na_object_item_object_dump";
+	NAObjectItem *item;
+
+	g_return_if_fail( NA_IS_OBJECT_ITEM( object ));
+
+	item = NA_OBJECT_ITEM( object );
+
+	if( !item->private->dispose_has_run ){
+
+		g_debug( "| %s:      writable=%s", thisfn, item->private->writable ? "True":"False" );
+		g_debug( "| %s:        reason=%u", thisfn, item->private->reason );
+
+		/* chain up to the parent class */
+		if( NA_OBJECT_CLASS( st_parent_class )->dump ){
+			NA_OBJECT_CLASS( st_parent_class )->dump( object );
+		}
+	}
+}
+
+static void
+object_copy( NAObject *target, const NAObject *source, guint mode )
 {
 	static const gchar *thisfn = "na_object_item_object_copy";
 	void *provider;
+	NAObjectItem *dest, *src;
 
 	g_return_if_fail( NA_IS_OBJECT_ITEM( target ));
 	g_return_if_fail( NA_IS_OBJECT_ITEM( source ));
 
-	if( !NA_OBJECT_ITEM( target )->private->dispose_has_run &&
-		!NA_OBJECT_ITEM( source )->private->dispose_has_run ){
+	dest = NA_OBJECT_ITEM( target );
+	src = NA_OBJECT_ITEM( source );
 
-		if( recursive ){
-			copy_children( NA_OBJECT_ITEM( target ), NA_OBJECT_ITEM( source ));
+	if( !dest->private->dispose_has_run && !src->private->dispose_has_run ){
+
+		if( mode == DUPLICATE_REC ||
+			( mode == DUPLICATE_OBJECT && G_OBJECT_TYPE( source ) == NA_TYPE_OBJECT_ACTION )){
+
+				copy_children( dest, src, mode );
 		}
 
 		provider = na_object_get_provider( source );
@@ -232,9 +257,119 @@ object_copy( NAObject *target, const NAObject *source, gboolean recursive )
 				na_io_provider_duplicate_data( NA_IO_PROVIDER( provider ), NA_OBJECT_ITEM( target ), NA_OBJECT_ITEM( source ), NULL );
 			}
 		}
+
+		dest->private->writable = src->private->writable;
+		dest->private->reason = src->private->reason;
+
+		/* chain up to the parent class */
+		if( NA_OBJECT_CLASS( st_parent_class )->copy ){
+			NA_OBJECT_CLASS( st_parent_class )->copy( target, source, mode );
+		}
 	}
 }
 
+/*
+ * object_are_equal:
+ * @a: the first (original) #NAObjectItem instance.
+ * @b: the second #NAObjectItem instance.
+ *
+ * This function participates to the #na_iduplicable_check_status() stack,
+ * and is triggered after all comparable elementary data (in #NAIFactoryObject
+ * sense) have already been successfully compared.
+ *
+ * We have to deal here with the subitems: comparing children by their ids
+ * between @a and @b.
+ *
+ * Returns: %TRUE if @a is equal to @b.
+ */
+static gboolean
+object_are_equal( const NAObject *a, const NAObject *b )
+{
+	static const gchar *thisfn = "na_object_item_object_are_equal";
+	gboolean are_equal;
+	NAObjectItem *origin, *duplicate;
+	GSList *a_slist, *b_slist;
+	gchar *a_list, *b_list;
+
+	g_return_val_if_fail( NA_IS_OBJECT_ITEM( a ), FALSE );
+	g_return_val_if_fail( NA_IS_OBJECT_ITEM( b ), FALSE );
+
+	are_equal = FALSE;
+	origin = NA_OBJECT_ITEM( a );
+	duplicate = NA_OBJECT_ITEM( b );
+
+	if( !origin->private->dispose_has_run &&
+		!duplicate->private->dispose_has_run ){
+
+		g_debug( "%s: a=%p, b=%p", thisfn, ( void * ) a, ( void * ) b );
+
+		a_slist = get_children_slist( origin );
+		a_list = na_core_utils_slist_join_at_end( a_slist, ";" );
+		na_core_utils_slist_free( a_slist );
+
+		b_slist = get_children_slist( duplicate );
+		b_list = na_core_utils_slist_join_at_end( b_slist, ";" );
+		na_core_utils_slist_free( b_slist );
+
+		are_equal = ( strcmp( a_list, b_list ) == 0 );
+
+		g_free( a_list );
+		g_free( b_list );
+	}
+
+	/* chain call to parent class */
+	if( NA_OBJECT_CLASS( st_parent_class )->are_equal ){
+		are_equal &= NA_OBJECT_CLASS( st_parent_class )->are_equal( a, b );
+	}
+
+	return( are_equal );
+}
+
+/*
+ * must have at least one valid subitem
+ */
+static gboolean
+object_is_valid( const NAObject *object )
+{
+	static const gchar *thisfn = "na_object_item_object_is_valid";
+	gboolean is_valid;
+	NAObjectItem *item;
+	GList *children, *ic;
+	gint valid_children;
+
+	g_return_val_if_fail( NA_IS_OBJECT_ITEM( object ), FALSE );
+
+	is_valid = FALSE;
+	item = NA_OBJECT_ITEM( object );
+
+	if( !item->private->dispose_has_run ){
+		g_debug( "%s: item=%p (%s)", thisfn, ( void * ) item, G_OBJECT_TYPE_NAME( item ));
+
+		is_valid = TRUE;
+
+		valid_children = 0;
+		children = na_object_get_items( item );
+		for( ic = children ; ic && !valid_children ; ic = ic->next ){
+			if( na_object_is_valid( ic->data )){
+				valid_children += 1;
+			}
+		}
+
+		is_valid &= ( valid_children > 0 );
+
+		if( !is_valid ){
+			na_object_debug_invalid( item, "no valid child" );
+		}
+	}
+
+	/* chain up to the parent class */
+	if( NA_OBJECT_CLASS( st_parent_class )->is_valid ){
+		is_valid &= NA_OBJECT_CLASS( st_parent_class )->is_valid( object );
+	}
+
+	return( is_valid );
+}
+
 /*
  * new_parent is not relevant when allocating a new identifier for an
  * action or a menu ; it may safely be left as NULL though there is no
@@ -268,124 +403,6 @@ object_id_new_id( const NAObjectId *item, const NAObjectId *new_parent )
 	return( new_uuid );
 }
 
-/**
- * na_object_item_are_equal:
- * @a: the first (original) #NAObjectItem instance.
- * @b: the second #NAObjectItem instance.
- *
- * This function participates to the #na_iduplicable_check_status() stack,
- * and is triggered after all comparable elementary data (in #NAIFactoryObject
- * sense) have already been successfully compared.
- *
- * We have to deal here with the subitems: comparing children by their ids
- * between @a and @b.
- *
- * Note that, when called from na_object_check_status, the status of children
- * have already been checked, and so we should be able to rely on them.
- *
- * Returns: %TRUE if @a is equal to @b.
- *
- * Since: 2.30
- */
-gboolean
-na_object_item_are_equal( const NAObjectItem *a, const NAObjectItem *b )
-{
-	static const gchar *thisfn = "na_object_item_are_equal";
-	gboolean equal;
-	GList *a_children, *b_children, *it;
-	gchar *first_id, *second_id;
-	NAObjectId *first_obj, *second_obj;
-	gint first_pos, second_pos;
-	GList *second_list;
-
-	g_return_val_if_fail( NA_IS_OBJECT_ITEM( a ), FALSE );
-	g_return_val_if_fail( NA_IS_OBJECT_ITEM( b ), FALSE );
-
-	equal = FALSE;
-
-	if( !NA_OBJECT_ITEM( a )->private->dispose_has_run &&
-		!NA_OBJECT_ITEM( b )->private->dispose_has_run ){
-
-		equal = TRUE;
-
-		if( equal ){
-			a_children = na_object_get_items( a );
-			b_children = na_object_get_items( b );
-			equal = ( g_list_length( a_children ) == g_list_length( b_children ));
-			if( !equal ){
-				g_debug( "%s: %p (%s) not equal as g_list_length not equal",
-						thisfn, ( void * ) b, G_OBJECT_TYPE_NAME( b ));
-				g_debug( "a=%p children_count=%u", ( void * ) a, g_list_length( a_children ));
-				for( it = a_children ; it ; it = it->next ){
-					g_debug( "a_child=%p", ( void * ) it->data );
-				}
-				g_debug( "b=%p children_count=%u", ( void * ) b, g_list_length( b_children ));
-				for( it = b_children ; it ; it = it->next ){
-					g_debug( "b_child=%p", ( void * ) it->data );
-				}
-			}
-		}
-
-		if( equal ){
-			for( it = a_children ; it && equal ; it = it->next ){
-				first_id = na_object_get_id( it->data );
-				second_obj = na_object_get_item( b, first_id );
-				first_pos = -1;
-				second_pos = -1;
-
-				if( second_obj ){
-					first_pos = g_list_position( a_children, it );
-					second_list = g_list_find( b_children, second_obj );
-					second_pos = g_list_position( b_children, second_list );
-
-					if( first_pos != second_pos ){
-						equal = FALSE;
-						g_debug( "%s: %p (%s) not equal as child %s is at pos %u",
-								thisfn, ( void * ) b, G_OBJECT_TYPE_NAME( b ), first_id, second_pos );
-					}
-
-				} else {
-					equal = FALSE;
-					g_debug( "%s: %p (%s) not equal as child %s removed",
-							thisfn, ( void * ) b, G_OBJECT_TYPE_NAME( b ), first_id );
-				}
-
-				g_free( first_id );
-			}
-		}
-
-		if( equal ){
-			for( it = b_children ; it && equal ; it = it->next ){
-				second_id = na_object_get_id( it->data );
-				first_obj = na_object_get_item( a, second_id );
-
-				if( !first_obj ){
-					equal = FALSE;
-					g_debug( "%s: %p (%s) not equal as child %s added",
-							thisfn, ( void * ) b, G_OBJECT_TYPE_NAME( b ), second_id );
-
-				} else {
-					equal = !na_object_is_modified( it->data );
-
-					if( !equal ){
-						g_debug( "%s: %p (%s) not equal as child %s modified",
-								thisfn, ( void * ) b, G_OBJECT_TYPE_NAME( b ), second_id );
-					}
-				}
-
-				g_free( second_id );
-			}
-		}
-
-		/*g_debug( "na_object_item_object_are_equal: a=%p (%s), b=%p (%s), are_equal=%s",
-				( void * ) a, G_OBJECT_TYPE_NAME( a ),
-				( void * ) b, G_OBJECT_TYPE_NAME( b ),
-				equal ? "True":"False" );*/
-	}
-
-	return( equal );
-}
-
 /**
  * na_object_item_get_item:
  * @item: the #NAObjectItem from which we want retrieve a subitem.
@@ -401,7 +418,7 @@ na_object_item_are_equal( const NAObjectItem *a, const NAObjectItem *b )
 NAObjectId *
 na_object_item_get_item( const NAObjectItem *item, const gchar *id )
 {
-	GList *childs, *it;
+	GList *children, *it;
 	NAObjectId *found = NULL;
 	NAObjectId *isub;
 	gchar *isubid;
@@ -410,8 +427,8 @@ na_object_item_get_item( const NAObjectItem *item, const gchar *id )
 
 	if( !item->private->dispose_has_run ){
 
-		childs = na_object_get_items( item );
-		for( it = childs ; it && !found ; it = it->next ){
+		children = na_object_get_items( item );
+		for( it = children ; it && !found ; it = it->next ){
 			isub = NA_OBJECT_ID( it->data );
 			isubid = na_object_get_id( isub );
 			if( !strcmp( id, isubid )){
@@ -620,15 +637,15 @@ guint
 na_object_item_get_items_count( const NAObjectItem *item )
 {
 	guint count = 0;
-	GList *childs;
+	GList *children;
 
 	/*g_debug( "na_object_item_get_items_count: item=%p (%s)", ( void * ) item, G_OBJECT_TYPE_NAME( item ));*/
 	g_return_val_if_fail( NA_IS_OBJECT_ITEM( item ), 0 );
 
 	if( !item->private->dispose_has_run ){
 
-		childs = na_object_get_items( item );
-		count = childs ? g_list_length( childs ) : 0;
+		children = na_object_get_items( item );
+		count = children ? g_list_length( children ) : 0;
 	}
 
 	return( count );
@@ -653,17 +670,24 @@ na_object_item_get_items_count( const NAObjectItem *item )
 void
 na_object_item_count_items( GList *items, gint *menus, gint *actions, gint *profiles, gboolean recurse )
 {
-	GList *it;
+	*menus = 0;
+	*actions = 0;
+	*profiles = 0;
 
-	/*g_debug( "na_object_item_count_items: items=%p (count=%d), menus=%d, actions=%d, profiles=%d",
-			( void * ) items, items ? g_list_length( items ) : 0, *menus, *actions, *profiles );*/
+	count_items_rec( items, menus, actions, profiles, recurse );
+}
+
+static void
+count_items_rec( GList *items, gint *menus, gint *actions, gint *profiles, gboolean recurse )
+{
+	GList *it;
 
 	for( it = items ; it ; it = it->next ){
 
 		if( recurse ){
 			if( NA_IS_OBJECT_ITEM( it->data )){
 				GList *subitems = na_object_get_items( it->data );
-				na_object_count_items( subitems, menus, actions, profiles, recurse );
+				count_items_rec( subitems, menus, actions, profiles, recurse );
 			}
 		}
 
@@ -680,54 +704,66 @@ na_object_item_count_items( GList *items, gint *menus, gint *actions, gint *prof
 }
 
 /**
- * na_object_item_unref_items:
+ * na_object_item_copyref_items:
  * @items: a list of #NAObject -derived items.
  *
- * Unref only the first level the #NAObject of the list, freeing the list at last.
+ * Creates a copy of the provided list, recursively incrementing the
+ * reference count of NAObjects.
  *
- * This is rather only used by NAPivot.
+ * Returns: the new list, which should be na_object_free_items() by the
+ * caller.
  *
- * Since: 2.30
+ * Since: 3.1
  */
-void
-na_object_item_unref_items( GList *items )
+GList *
+na_object_item_copyref_items( GList *items )
 {
-	g_list_foreach( items, ( GFunc ) g_object_unref, NULL );
-	g_list_free( items );
+	GList *copy = NULL;
+
+	if( items ){
+		copy = g_list_copy( items );
+		g_list_foreach( copy, ( GFunc ) na_object_object_ref, NULL );
+		g_debug( "na_object_item_copyref_items: list at %p contains %s at %p (ref_count=%d)",
+				( void * ) copy,
+				G_OBJECT_TYPE_NAME( copy->data ), ( void * ) copy->data, G_OBJECT( copy->data )->ref_count );
+	}
+
+	return( copy );
 }
 
 /**
- * na_object_item_unref_items_rec:
+ * na_object_item_free_items:
  * @items: a list of #NAObject -derived items.
  *
- * Recursively unref the #NAObject's of the list, freeing the list at last.
+ * Free the items list.
  *
- * This is heavily used by NACT.
+ * Returns: a %NULL pointer.
  *
- * Since: 2.30
+ * Since: 3.1
  */
-void
-na_object_item_unref_items_rec( GList *items )
+GList *
+na_object_item_free_items( GList *items )
 {
-	GList *it;
-
-	for( it = items ; it ; it = it->next ){
-		na_object_unref( it->data );
+	if( items ){
+		g_debug( "na_object_item_free_items: freeing list at %p which contains %s at %p (ref_count=%d)",
+				( void * ) items,
+				G_OBJECT_TYPE_NAME( items->data ), ( void * ) items->data, G_OBJECT( items->data )->ref_count );
+		g_list_foreach( items, ( GFunc ) na_object_object_unref, NULL );
+		g_list_free( items );
 	}
-
-	g_list_free( items );
+	return( NULL );
 }
 
 /**
  * na_object_item_deals_with_version:
  * @item: this #NAObjectItem -derived object.
  *
- * Just after the @item has been readen from NAIFactoryProvider, setup
+ * Just after the @item has been read from NAIFactoryProvider, setup
  * the version. This is needed because some conversions may occur in
  * this object.
  *
  * Note that there is only some 2.x versions where the version string
- * was not systematically written. If @item has been readen from a
+ * was not systematically written. If @item has been read from a
  * .desktop file, then iversion is already set to (at least) 3.
  *
  * Since: 2.30
@@ -772,30 +808,43 @@ void
 na_object_item_rebuild_children_slist( NAObjectItem *item )
 {
 	GSList *slist;
-	GList *subitems, *it;
-	gchar *id;
 
 	na_object_set_items_slist( item, NULL );
 
 	if( !item->private->dispose_has_run ){
 
-		subitems = na_object_get_items( item );
-		slist = NULL;
-
-		for( it = subitems ; it ; it = it->next ){
-			id = na_object_get_id( it->data );
-			slist = g_slist_prepend( slist, id );
-		}
-		slist = g_slist_reverse( slist );
-
+		slist = get_children_slist( item );
 		na_object_set_items_slist( item, slist );
-
 		na_core_utils_slist_free( slist );
 	}
 }
 
+/*
+ */
+static GSList *
+get_children_slist( const NAObjectItem *item )
+{
+	GSList *slist;
+	GList *subitems, *it;
+	gchar *id;
+
+	slist = NULL;
+	subitems = na_object_get_items( item );
+
+	for( it = subitems ; it ; it = it->next ){
+		id = na_object_get_id( it->data );
+		slist = g_slist_prepend( slist, id );
+	}
+
+	return( g_slist_reverse( slist ));
+}
+
+/*
+ * only copy children if mode is 'full recursive'
+ * or mode is 'duplicate object' and this is an action with profiles
+ */
 static void
-copy_children( NAObjectItem *target, const NAObjectItem *source )
+copy_children( NAObjectItem *target, const NAObjectItem *source, guint mode )
 {
 	static const gchar *thisfn = "na_object_item_copy_children";
 	GList *tgt_children, *src_children, *ic;
@@ -804,14 +853,15 @@ copy_children( NAObjectItem *target, const NAObjectItem *source )
 	tgt_children = na_object_get_items( target );
 	if( tgt_children ){
 		g_warning( "%s: target_children=%p (count=%d)",
-				thisfn, ( void * ) tgt_children, g_list_length( tgt_children ));
+				thisfn,
+				( void * ) tgt_children, g_list_length( tgt_children ));
 		g_return_if_fail( tgt_children == NULL );
 	}
 
 	src_children = na_object_get_items( source );
 	for( ic = src_children ; ic ; ic = ic->next ){
 
-		dup = ( NAObject * ) na_object_duplicate( ic->data );
+		dup = ( NAObject * ) na_object_duplicate( ic->data, mode );
 		na_object_set_parent( dup, target );
 		tgt_children = g_list_prepend( tgt_children, dup );
 	}
@@ -819,3 +869,57 @@ copy_children( NAObjectItem *target, const NAObjectItem *source )
 	tgt_children = g_list_reverse( tgt_children );
 	na_object_set_items( target, tgt_children );
 }
+
+/**
+ * na_object_item_is_finally_writable:
+ * @item: this #NAObjectItem -derived object.
+ * @reason: if not %NULL, a pointer to a guint which will hold the reason code.
+ *
+ * Returns: the writability status of the @item.
+ *
+ * Since: 3.1
+ */
+gboolean
+na_object_item_is_finally_writable( const NAObjectItem *item, guint *reason )
+{
+	gboolean writable;
+
+	if( reason ){
+		*reason = NA_IIO_PROVIDER_STATUS_UNDETERMINED;
+	}
+	g_return_val_if_fail( NA_IS_OBJECT_ITEM( item ), FALSE );
+
+	writable = FALSE;
+
+	if( !item->private->dispose_has_run ){
+
+		writable = item->private->writable;
+		if( reason ){
+			*reason = item->private->reason;
+		}
+	}
+
+	return( writable );
+}
+
+/**
+ * na_object_item_set_writability_status:
+ * @item: this #NAObjectItem -derived object.
+ * @writable: whether the item is finally writable.
+ * @reason: the reason code.
+ *
+ * Set the writability status of the @item.
+ *
+ * Since: 3.1
+ */
+void
+na_object_item_set_writability_status( NAObjectItem *item, gboolean writable, guint reason )
+{
+	g_return_if_fail( NA_IS_OBJECT_ITEM( item ));
+
+	if( !item->private->dispose_has_run ){
+
+		item->private->writable = writable;
+		item->private->reason = reason;
+	}
+}
