@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -48,47 +47,27 @@ struct _NAObjectPrivate {
 	gboolean   dispose_has_run;
 };
 
-/* while iterating on the class hierarchy for are_equal() and is_valid()
- */
-typedef struct {
-	NAObject *object;
-	gboolean  result;
-}
-	HierarchyIter;
-
-/* while iterating on the class hierarchy for object_copy()
- */
-typedef struct {
-	NAObject *target;
-	gboolean  recursive;
-}
-	CopyIter;
-
-typedef gboolean ( *HierarchyIterFunc )( GObjectClass *class, const NAObject *object, void *user_data );
-
 static GObjectClass *st_parent_class   = NULL;
 
-static GType          register_type( void );
-static void           class_init( NAObjectClass *klass );
-static void           instance_init( GTypeInstance *instance, gpointer klass );
-static void           instance_dispose( GObject *object );
-static void           instance_finalize( GObject *object );
+static GType    register_type( void );
+static void     class_init( NAObjectClass *klass );
+static void     instance_init( GTypeInstance *instance, gpointer klass );
+static void     instance_dispose( GObject *object );
+static void     instance_finalize( GObject *object );
 
-static void           object_dump( const NAObject *object );
+static void     object_dump( const NAObject *object );
 
-static void           iduplicable_iface_init( NAIDuplicableInterface *iface );
-static void           iduplicable_copy( NAIDuplicable *target, const NAIDuplicable *source );
-static gboolean       iduplicable_are_equal( const NAIDuplicable *a, const NAIDuplicable *b );
-static gboolean       iduplicable_are_equal_iter( GObjectClass *class, const NAObject *a, HierarchyIter *str );
-static gboolean       iduplicable_is_valid( const NAIDuplicable *object );
-static gboolean       iduplicable_is_valid_iter( GObjectClass *class, const NAObject *a, HierarchyIter *str );
+static void     iduplicable_iface_init( NAIDuplicableInterface *iface, void *user_data );
+static void     iduplicable_copy( NAIDuplicable *target, const NAIDuplicable *source, guint mode );
+static gboolean iduplicable_are_equal( const NAIDuplicable *a, const NAIDuplicable *b );
+static gboolean iduplicable_is_valid( const NAIDuplicable *object );
 
-static void           push_modified_status_up( const NAObject *object, gboolean is_modified );
-static gboolean       object_copy_iter( GObjectClass *class, const NAObject *source, CopyIter *data );
-static gboolean       dump_class_hierarchy_iter( GObjectClass *class, const NAObject *object, void *user_data );
-static void           dump_tree( GList *tree, gint level );
-static void           iter_on_class_hierarchy( const NAObject *object, HierarchyIterFunc pfn, void *user_data );
-static GList         *build_class_hierarchy( const NAObject *object );
+static void     check_status_down_rec( const NAObject *object );
+static void     check_status_up_rec( const NAObject *object, gboolean was_modified, gboolean was_valid );
+static void     v_copy( NAObject *target, const NAObject *source, guint mode );
+static gboolean v_are_equal( const NAObject *a, const NAObject *b );
+static gboolean v_is_valid( const NAObject *a );
+static void     dump_tree( GList *tree, gint level );
 
 GType
 na_object_object_get_type( void )
@@ -130,7 +109,7 @@ register_type( void )
 
 	type = g_type_register_static( G_TYPE_OBJECT, "NAObject", &info, 0 );
 
-	g_type_add_interface_static( type, NA_IDUPLICABLE_TYPE, &iduplicable_iface_info );
+	g_type_add_interface_static( type, NA_TYPE_IDUPLICABLE, &iduplicable_iface_info );
 
 	return( type );
 }
@@ -151,36 +130,29 @@ class_init( NAObjectClass *klass )
 	object_class->finalize = instance_finalize;
 
 	naobject_class = NA_OBJECT_CLASS( klass );
-	naobject_class->dump = NULL;
+	naobject_class->dump = object_dump;
 	naobject_class->copy = NULL;
 	naobject_class->are_equal = NULL;
 	naobject_class->is_valid = NULL;
 
 	klass->private = g_new0( NAObjectClassPrivate, 1 );
-
-	klass->dump = object_dump;
 }
 
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-	static const gchar *thisfn = "na_object_instance_init";
 	NAObject *self;
 
 	g_return_if_fail( NA_IS_OBJECT( instance ));
 
 	self = NA_OBJECT( instance );
 
-	g_debug( "%s: instance=%p (%s), klass=%p",
-			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-
 	self->private = g_new0( NAObjectPrivate, 1 );
 }
 
 static void
 instance_dispose( GObject *object )
 {
-	static const gchar *thisfn = "na_object_instance_dispose";
 	NAObject *self;
 
 	g_return_if_fail( NA_IS_OBJECT( object ));
@@ -189,8 +161,6 @@ instance_dispose( GObject *object )
 
 	if( !self->private->dispose_has_run ){
 
-		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
 		self->private->dispose_has_run = TRUE;
 
 		na_iduplicable_dispose( NA_IDUPLICABLE( object ));
@@ -205,15 +175,12 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
-	static const gchar *thisfn = "na_object_instance_finalize";
 	NAObject *self;
 
 	g_return_if_fail( NA_IS_OBJECT( object ));
 
 	self = NA_OBJECT( object );
 
-	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
 	g_free( self->private );
 
 	if( NA_IS_IFACTORY_OBJECT( object )){
@@ -229,24 +196,22 @@ instance_finalize( GObject *object )
 static void
 object_dump( const NAObject *object )
 {
-	static const char *thisfn = "na_object_do_dump";
+	if( !object->private->dispose_has_run ){
 
-	g_debug( "%s: object=%p (%s, ref_count=%d)", thisfn,
-			( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );
+		na_iduplicable_dump( NA_IDUPLICABLE( object ));
 
-	na_iduplicable_dump( NA_IDUPLICABLE( object ));
-
-	if( NA_IS_IFACTORY_OBJECT( object )){
-		na_factory_object_dump( NA_IFACTORY_OBJECT( object ));
+		if( NA_IS_IFACTORY_OBJECT( object )){
+			na_factory_object_dump( NA_IFACTORY_OBJECT( object ));
+		}
 	}
 }
 
 static void
-iduplicable_iface_init( NAIDuplicableInterface *iface )
+iduplicable_iface_init( NAIDuplicableInterface *iface, void *user_data )
 {
 	static const gchar *thisfn = "na_object_iduplicable_iface_init";
 
-	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
+	g_debug( "%s: iface=%p, user_data=%p", thisfn, ( void * ) iface, ( void * ) user_data );
 
 	iface->copy = iduplicable_copy;
 	iface->are_equal = iduplicable_are_equal;
@@ -258,16 +223,43 @@ iduplicable_iface_init( NAIDuplicableInterface *iface )
  * it recursively copies @source to @target
  */
 static void
-iduplicable_copy( NAIDuplicable *target, const NAIDuplicable *source )
+iduplicable_copy( NAIDuplicable *target, const NAIDuplicable *source, guint mode )
 {
-	na_object_copy( NA_OBJECT( target ), NA_OBJECT( source ), TRUE );
+	static const gchar *thisfn = "na_object_iduplicable_copy";
+	NAObject *dest, *src;
+
+	g_return_if_fail( NA_IS_OBJECT( target ));
+	g_return_if_fail( NA_IS_OBJECT( source ));
+
+	dest = NA_OBJECT( target );
+	src = NA_OBJECT( source );
+
+	if( !dest->private->dispose_has_run &&
+		!src->private->dispose_has_run ){
+
+		g_debug( "%s: target=%p (%s), source=%p (%s), mode=%d",
+				thisfn,
+				( void * ) dest, G_OBJECT_TYPE_NAME( dest ),
+				( void * ) src, G_OBJECT_TYPE_NAME( src ),
+				mode );
+
+		if( NA_IS_IFACTORY_OBJECT( target )){
+			na_factory_object_copy( NA_IFACTORY_OBJECT( target ), NA_IFACTORY_OBJECT( source ));
+		}
+
+		if( NA_IS_ICONTEXT( target )){
+			na_icontext_copy( NA_ICONTEXT( target ), NA_ICONTEXT( source ));
+		}
+
+		v_copy( dest, src, mode );
+	}
 }
 
 static gboolean
 iduplicable_are_equal( const NAIDuplicable *a, const NAIDuplicable *b )
 {
+	static const gchar *thisfn = "na_object_iduplicable_are_equal";
 	gboolean are_equal;
-	HierarchyIter *str;
 
 	g_return_val_if_fail( NA_IS_OBJECT( a ), FALSE );
 	g_return_val_if_fail( NA_IS_OBJECT( b ), FALSE );
@@ -277,247 +269,195 @@ iduplicable_are_equal( const NAIDuplicable *a, const NAIDuplicable *b )
 	if( !NA_OBJECT( a )->private->dispose_has_run &&
 		!NA_OBJECT( b )->private->dispose_has_run ){
 
+		g_debug( "%s: a=%p (%s), b=%p", thisfn, ( void * ) a, G_OBJECT_TYPE_NAME( a ), ( void * ) b );
+
+		are_equal = TRUE;
+
 		if( NA_IS_IFACTORY_OBJECT( a )){
-			are_equal = na_factory_object_are_equal( NA_IFACTORY_OBJECT( a ), NA_IFACTORY_OBJECT( b ));
-
-		} else {
-			str = g_new0( HierarchyIter, 1 );
-			str->object = NA_OBJECT( b );
-			str->result = FALSE;
-
-			iter_on_class_hierarchy( NA_OBJECT( a ), ( HierarchyIterFunc ) &iduplicable_are_equal_iter, str );
-
-			are_equal = str->result;
-
-			g_free( str );
+			are_equal &= na_factory_object_are_equal( NA_IFACTORY_OBJECT( a ), NA_IFACTORY_OBJECT( b ));
 		}
+
+		if( NA_IS_ICONTEXT( a )){
+			are_equal &= na_icontext_are_equal( NA_ICONTEXT( a ), NA_ICONTEXT( b ));
+		}
+
+		are_equal &= v_are_equal( NA_OBJECT( a ), NA_OBJECT( b ));
 	}
 
 	return( are_equal );
 }
 
-static gboolean
-iduplicable_are_equal_iter( GObjectClass *class, const NAObject *a, HierarchyIter *str )
-{
-	gboolean stop = FALSE;
-
-	if( NA_OBJECT_CLASS( class )->are_equal ){
-		str->result = NA_OBJECT_CLASS( class )->are_equal( a, str->object );
-		stop = !str->result;
-	}
-
-	return( stop );
-}
-
 static gboolean
 iduplicable_is_valid( const NAIDuplicable *object )
 {
 	static const gchar *thisfn = "na_object_iduplicable_is_valid";
 	gboolean is_valid;
-	HierarchyIter *str;
-
-	g_debug( "%s: object=%p (%s)",
-			thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
 	g_return_val_if_fail( NA_IS_OBJECT( object ), FALSE );
 
 	is_valid = FALSE;
 
 	if( !NA_OBJECT( object )->private->dispose_has_run ){
+		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
+		is_valid = TRUE;
 
 		if( NA_IS_IFACTORY_OBJECT( object )){
-			is_valid = na_factory_object_is_valid( NA_IFACTORY_OBJECT( object ));
-
-		} else {
-			g_debug( "%s: object=%p (%s): iterating on class hierarchy",
-					thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
-			str = g_new0( HierarchyIter, 1 );
-			str->result = TRUE;
-			iter_on_class_hierarchy( NA_OBJECT( object ), ( HierarchyIterFunc ) &iduplicable_is_valid_iter, str );
-			is_valid = str->result;
-			g_free( str );
+			is_valid &= na_factory_object_is_valid( NA_IFACTORY_OBJECT( object ));
 		}
+
+		if( NA_IS_ICONTEXT( object )){
+			is_valid &= na_icontext_is_valid( NA_ICONTEXT( object ));
+		}
+
+		is_valid &= v_is_valid( NA_OBJECT( object ));
 	}
 
 	return( is_valid );
 }
 
-static gboolean
-iduplicable_is_valid_iter( GObjectClass *class, const NAObject *a, HierarchyIter *str )
-{
-	gboolean stop = FALSE;
-
-	if( NA_OBJECT_CLASS( class )->is_valid ){
-
-		str->result = NA_OBJECT_CLASS( class )->is_valid( a );
-		stop = !str->result;
-	}
-
-	return( stop );
-}
-
 /**
- * na_object_object_check_status:
+ * na_object_object_check_status_rec:
  * @object: the #NAObject -derived object to be checked.
  *
- * Recursively checks for the edition status of @object and its childs
+ * Recursively checks for the edition status of @object and its children
  * (if any).
  *
  * Internally set some properties which may be requested later. This
  * two-steps check-request let us optimize some work in the UI.
  *
- * na_object_object_check_status( object )
+ * <literallayout>
+ * na_object_object_check_status_rec( object )
  *  +- na_iduplicable_check_status( object )
  *      +- get_origin( object )
- *      +- modified_status = v_are_equal( origin, object ) -> interface <structfield>NAObjectClass::are_equal</structfield>
+ *      +- modified_status = v_are_equal( origin, object )
+ *      |  +-> interface <structfield>NAObjectClass::are_equal</structfield>
+ *      |      which happens to be iduplicable_are_equal( a, b )
+ *      |       +- v_are_equal( a, b )
+ *      |           +- NAObjectAction::are_equal()
+ *      |               +- na_factory_object_are_equal()
+ *      |               +- check NAObjectActionPrivate data
+ *      |               +- call parent class
+ *      |                  +- NAObjectItem::are_equal()
+ *      |                      +- check NAObjectItemPrivate data
+ *      |                      +- call parent class
+ *      |                          +- NAObjectId::are_equal()
+ *      |
  *      +- valid_status = v_is_valid( object )             -> interface <structfield>NAObjectClass::is_valid</structfield>
+ * </literallayout>
  *
- * Note that the recursivity is managed here, so that we can be sure
- * that edition status of childs is actually checked before those of
- * the parent.
+ *   Note that the recursivity is managed here, so that we can be sure
+ *   that edition status of children is actually checked before those of
+ *   the parent.
+ *
+ * <formalpara>
+ *  <title>
+ *   As of 3.1.0:
+ *  </title>
+ *  <para>
+ *   <itemizedlist>
+ *    <listitem>
+ *     <para>
+ *      when the modification status of a NAObjectProfile changes, then its
+ *      NAObjectAction parent is rechecked;
+ *     </para>
+ *    </listitem>
+ *    <listitem>
+ *     <para>
+ *      when the validity status of an object is changed, then its parent is
+ *      also rechecked.
+ *     </para>
+ *    </listitem>
+ *   </itemizedlist>
+ *  </para>
+ * </formalpara>
  *
  * Since: 2.30
  */
 void
-na_object_object_check_status( const NAObject *object )
+na_object_object_check_status_rec( const NAObject *object )
 {
-	static const gchar *thisfn = "na_object_object_check_status";
-	GList *children, *ic;
+	static const gchar *thisfn = "na_object_object_check_status_rec";
+	gboolean was_modified, was_valid;
 
 	g_return_if_fail( NA_IS_OBJECT( object ));
 
 	if( !object->private->dispose_has_run ){
-
-		g_debug( "%s: object=%p (%s)",
-				thisfn,
-				( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
-		if( NA_IS_OBJECT_ITEM( object )){
-			children = na_object_get_items( object );
-
-			for( ic = children ; ic ; ic = ic->next ){
-				na_object_check_status( ic->data );
-			}
-		}
-
-		na_iduplicable_check_status( NA_IDUPLICABLE( object ));
-	}
-}
-
-/**
- * na_object_object_check_status_up:
- * @object: the object at the start of the hierarchy.
- *
- * Checks for modification and validity status of the @object, its
- * parent, the parent of its parent, etc. up to the top of the hierarchy.
- *
- * Checking the modification of any of the status should be more
- * efficient that systematically force the display of the item.
- *
- * Returns: %TRUE if at least one of the status has changed, %FALSE else.
- *
- * Since: 2.30
- */
-gboolean
-na_object_object_check_status_up( const NAObject *object )
-{
-	gboolean changed;
-	gboolean was_modified, is_modified;
-	gboolean was_valid, is_valid;
-	NAObjectItem *parent;
-
-	g_return_val_if_fail( NA_OBJECT( object ), FALSE );
-
-	changed = FALSE;
-
-	if( !object->private->dispose_has_run ){
+		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 
 		was_modified = na_object_is_modified( object );
 		was_valid = na_object_is_valid( object );
+		check_status_down_rec( object );
+		check_status_up_rec( object, was_modified, was_valid );
+	}
+}
 
-		na_iduplicable_check_status( NA_IDUPLICABLE( object ));
-
-		is_modified = na_object_is_modified( object );
-		is_valid = na_object_is_valid( object );
-
-		/* if a child becomes modified, then we can safely push this 'modified'
-		 * status up to all its parent hierarchy
-		 */
-		if( !was_modified && is_modified ){
-			push_modified_status_up( object, is_modified );
-		}
-
-		/* but if a child becomes non modified, or its validity status changes,
-		 * then we have to recompute these status for all the parent hierarchy
-		 */
-		changed = (( was_valid && !is_valid ) ||
-				( !was_valid && is_valid ) ||
-				( was_modified && !is_modified ));
-
-		if( changed ){
-			parent = na_object_get_parent( object );
-			if( parent ){
-				na_object_check_status_up( parent );
-			}
-		}
+/*
+ * recursively checks the status downstream
+ */
+static void
+check_status_down_rec( const NAObject *object )
+{
+	if( NA_IS_OBJECT_ITEM( object )){
+		g_list_foreach( na_object_get_items( object ), ( GFunc ) check_status_down_rec, NULL );
 	}
 
-	return( changed );
+	na_iduplicable_check_status( NA_IDUPLICABLE( object ));
+}
+
+/*
+ * if the status appears changed, then rechecks the parent
+ * recurse upstream while there is a parent, and its status changes
+ */
+static void
+check_status_up_rec( const NAObject *object, gboolean was_modified, gboolean was_valid )
+{
+	gboolean is_modified, is_valid;
+	NAObjectItem *parent;
+
+	is_modified = na_object_is_modified( object );
+	is_valid = na_object_is_valid( object );
+
+	if(( NA_IS_OBJECT_PROFILE( object ) && was_modified != is_modified ) ||
+			was_valid != is_valid ){
+
+			parent = na_object_get_parent( object );
+
+			if( parent ){
+				was_modified = na_object_is_modified( parent );
+				was_valid = na_object_is_valid( parent );
+				na_iduplicable_check_status( NA_IDUPLICABLE( parent ));
+				check_status_up_rec( NA_OBJECT( parent ), was_modified, was_valid );
+			}
+	}
 }
 
 static void
-push_modified_status_up( const NAObject *object, gboolean is_modified )
+v_copy( NAObject *target, const NAObject *source, guint mode )
 {
-	NAObject *parent = ( NAObject * ) na_object_get_parent( object );
-	if( parent ){
-		na_iduplicable_set_modified( NA_IDUPLICABLE( parent ), is_modified );
-		push_modified_status_up( parent, is_modified );
-	}
-}
-
-/**
- * na_object_object_copy:
- * @target: the target #NAObject -derived object.
- * @source: the source #NAObject -derived object.
- * @recursive: whether the copy should be recursive.
- *
- * Copies @source to @target.
- *
- * Since: 2.30
- */
-void
-na_object_object_copy( NAObject *target, const NAObject *source, gboolean recursive )
-{
-	CopyIter *data;
-
-	g_return_if_fail( NA_IS_OBJECT( target ));
-	g_return_if_fail( NA_IS_OBJECT( source ));
-
-	if( !NA_OBJECT( source )->private->dispose_has_run &&
-		!NA_OBJECT( target )->private->dispose_has_run ){
-
-		data = g_new0( CopyIter, 1 );
-		data->target = target;
-		data->recursive = recursive;
-
-		iter_on_class_hierarchy( NA_OBJECT( source ),
-					( HierarchyIterFunc ) object_copy_iter, ( void * ) data );
-
-		g_free( data );
+	if( NA_OBJECT_GET_CLASS( target )->copy ){
+		NA_OBJECT_GET_CLASS( target )->copy( target, source, mode );
 	}
 }
 
 static gboolean
-object_copy_iter( GObjectClass *class, const NAObject *source, CopyIter *data )
+v_are_equal( const NAObject *a, const NAObject *b )
 {
-	gboolean stop = FALSE;
-
-	if( NA_OBJECT_CLASS( class )->copy ){
-		NA_OBJECT_CLASS( class )->copy( data->target, source, data->recursive );
+	if( NA_OBJECT_GET_CLASS( a )->are_equal ){
+		return( NA_OBJECT_GET_CLASS( a )->are_equal( a, b ));
 	}
 
-	return( stop );
+	return( TRUE );
+}
+
+static gboolean
+v_is_valid( const NAObject *a )
+{
+	if( NA_OBJECT_GET_CLASS( a )->is_valid ){
+		return( NA_OBJECT_GET_CLASS( a )->is_valid( a ));
+	}
+
+	return( TRUE );
 }
 
 /**
@@ -528,7 +468,7 @@ object_copy_iter( GObjectClass *class, const NAObject *source, CopyIter *data )
  *
  * The recursivity is dealt with here because, if we would let
  * #NAObjectItem do this, the dump of #NAObjectItem -derived object
- * would be splitted, childs being inserted inside.
+ * would be splitted, children being inserted inside.
  *
  * na_object_dump() doesn't modify the reference count of the dumped
  * object.
@@ -538,7 +478,7 @@ object_copy_iter( GObjectClass *class, const NAObject *source, CopyIter *data )
 void
 na_object_object_dump( const NAObject *object )
 {
-	GList *childs, *ic;
+	GList *children, *ic;
 
 	g_return_if_fail( NA_IS_OBJECT( object ));
 
@@ -547,10 +487,9 @@ na_object_object_dump( const NAObject *object )
 		na_object_dump_norec( object );
 
 		if( NA_IS_OBJECT_ITEM( object )){
+			children = na_object_get_items( object );
 
-			childs = na_object_get_items( object );
-			for( ic = childs ; ic ; ic = ic->next ){
-
+			for( ic = children ; ic ; ic = ic->next ){
 				na_object_dump( ic->data );
 			}
 		}
@@ -573,23 +512,12 @@ na_object_object_dump_norec( const NAObject *object )
 	g_return_if_fail( NA_IS_OBJECT( object ));
 
 	if( !object->private->dispose_has_run ){
-
-		iter_on_class_hierarchy( object, ( HierarchyIterFunc ) &dump_class_hierarchy_iter, NULL );
+		if( NA_OBJECT_GET_CLASS( object )->dump ){
+			NA_OBJECT_GET_CLASS( object )->dump( object );
+		}
 	}
 }
 
-static gboolean
-dump_class_hierarchy_iter( GObjectClass *class, const NAObject *object, void *user_data )
-{
-	gboolean stop = FALSE;
-
-	if( NA_OBJECT_CLASS( class )->dump ){
-		NA_OBJECT_CLASS( class )->dump( object );
-	}
-
-	return( stop );
-}
-
 /**
  * na_object_object_dump_tree:
  * @tree: a hierarchical list of #NAObject -derived objects.
@@ -609,8 +537,8 @@ dump_tree( GList *tree, gint level )
 {
 	GString *prefix;
 	gint i;
-	GList *subitems, *it;
-	gchar *id;
+	GList *it;
+	const NAObject *object;
 	gchar *label;
 
 	prefix = g_string_new( "" );
@@ -619,16 +547,14 @@ dump_tree( GList *tree, gint level )
 	}
 
 	for( it = tree ; it ; it = it->next ){
-		id = na_object_get_id( it->data );
-		label = na_object_get_label( it->data );
-		g_debug( "na_object_dump_tree: %s%p (%s) %s \"%s\"",
-				prefix->str, ( void * ) it->data, G_OBJECT_TYPE_NAME( it->data ), id, label );
-		g_free( id );
+		object = ( const NAObject * ) it->data;
+		label = na_object_get_label( object );
+		g_debug( "na_object_dump_tree: %s%p (%s, ref_count=%u) '%s'", prefix->str,
+				( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count, label );
 		g_free( label );
 
-		if( NA_IS_OBJECT_ITEM( it->data )){
-			subitems = na_object_get_items( it->data );
-			dump_tree( subitems, level+1 );
+		if( NA_IS_OBJECT_ITEM( object )){
+			dump_tree( na_object_get_items( object ), level+1 );
 		}
 	}
 
@@ -680,34 +606,23 @@ na_object_object_reset_origin( NAObject *object, const NAObject *origin )
  * Recursively ref the @object and all its children, incrementing their
  * reference_count by 1.
  *
- * Returns: a reference on the @pbject.
+ * Returns: a reference on the @object.
  *
  * Since: 2.30
  */
 NAObject *
 na_object_object_ref( NAObject *object )
 {
-	NAObject *ref = NULL;
-	GList *children, *ic;
+	NAObject *ref;
 
 	g_return_val_if_fail( NA_IS_OBJECT( object ), NULL );
 
+	ref = NULL;
+
 	if( !object->private->dispose_has_run ){
 
-		g_debug( "na_object_object_ref: object=%p (%s, ref_count=%d)",
-				( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );
-
 		if( NA_IS_OBJECT_ITEM( object )){
-
-			children = na_object_get_items( object );
-
-			for( ic = children ; ic ; ic = ic->next ){
-				/*
-				g_debug( "na_object_object_ref: child=%p (%s, ref_count=%d)",
-							( void * ) ic->data, G_OBJECT_TYPE_NAME( ic->data ), G_OBJECT( ic->data )->ref_count );
-							*/
-				na_object_ref( ic->data );
-			}
+			g_list_foreach( na_object_get_items( object ), ( GFunc ) na_object_object_ref, NULL );
 		}
 
 		ref = g_object_ref( object );
@@ -723,60 +638,26 @@ na_object_object_ref( NAObject *object )
  * Recursively unref the @object and all its children, decrementing their
  * reference_count by 1.
  *
+ * Note that we may want to free a copy+ref of a list of items whichy have
+ * had already disposed (which is probably a bug somewhere). So first test
+ * is the object is still alive.
+ *
  * Since: 2.30
  */
 void
 na_object_object_unref( NAObject *object )
 {
-	GList *children;
-	GList *ic, *icnext;
-
 	g_return_if_fail( NA_IS_OBJECT( object ));
 
 	if( !object->private->dispose_has_run ){
-
-		g_debug( "na_object_object_unref: object=%p (%s, ref_count=%d)",
-				( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );
-
 		if( NA_IS_OBJECT_ITEM( object )){
-			children = na_object_get_items( object );
-
-			for( ic = children ; ic ; ic = icnext ){
-				icnext = ic->next;
-				g_object_unref( ic->data );
-			}
+			g_list_foreach( na_object_get_items( object ), ( GFunc ) na_object_object_unref, NULL );
 		}
-
-		/*g_debug( "na_object_object_unref:about_to_unref: object=%p (%s, ref_count=%d)",
-				( void * ) object, G_OBJECT_TYPE_NAME( object ), G_OBJECT( object )->ref_count );*/
-
 		g_object_unref( object );
 	}
 }
 
-/*
- * iter on the whole class hierarchy
- * starting with NAObject, and to the most derived up to NAObjectAction..
- */
-static void
-iter_on_class_hierarchy( const NAObject *object, HierarchyIterFunc pfn, void *user_data )
-{
-	gboolean stop;
-	GObjectClass *class;
-	GList *hierarchy, *ih;
-
-	stop = FALSE;
-	hierarchy = build_class_hierarchy( object );
-
-	for( ih = hierarchy ; ih && !stop ; ih = ih->next ){
-		class = ( GObjectClass * ) ih->data;
-		/*g_debug( "iter_on_class_hierarchy: class=%s", G_OBJECT_CLASS_NAME( class ));*/
-		stop = ( *pfn )( class, object, user_data );
-	}
-
-	g_list_free( hierarchy );
-}
-
+#ifdef NA_ENABLE_DEPRECATED
 /*
  * build the class hierarchy
  * returns a list of GObjectClass, which starts with NAObject,
@@ -791,7 +672,7 @@ build_class_hierarchy( const NAObject *object )
 	hierarchy = NULL;
 	class = G_OBJECT_GET_CLASS( object );
 
-	while( G_OBJECT_CLASS_TYPE( class ) != NA_OBJECT_TYPE ){
+	while( G_OBJECT_CLASS_TYPE( class ) != NA_TYPE_OBJECT ){
 
 		hierarchy = g_list_prepend( hierarchy, class );
 		class = g_type_class_peek_parent( class );
@@ -803,16 +684,17 @@ build_class_hierarchy( const NAObject *object )
 }
 
 /**
- * na_object_object_get_hierarchy:
+ * na_object_get_hierarchy:
  * @object: the #NAObject -derived object.
  *
  * Returns: the class hierarchy,
  * from the topmost base class, to the most-derived one.
  *
  * Since: 2.30
+ * Deprecated: 3.1
  */
 GList *
-na_object_object_get_hierarchy( const NAObject *object )
+na_object_get_hierarchy( const NAObject *object )
 {
 	GList *hierarchy;
 
@@ -836,12 +718,14 @@ na_object_object_get_hierarchy( const NAObject *object )
  * Releases the #NAObject hierarchy.
  *
  * Since: 2.30
+ * Deprecated: 3.1
  */
 void
 na_object_free_hierarchy( GList *hierarchy )
 {
 	g_list_free( hierarchy );
 }
+#endif /* NA_ENABLE_DEPRECATED */
 
 /**
  * na_object_object_debug_invalid:
