@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -75,6 +74,7 @@ static void            instance_dispose( GObject *object );
 static void            instance_finalize( GObject *object );
 
 static void            dump( const NASelectedInfo *nsi );
+static const char     *dump_file_type( GFileType type );
 static NASelectedInfo *new_from_nautilus_file_info( NautilusFileInfo *item );
 static NASelectedInfo *new_from_uri( const gchar *uri, const gchar *mimetype, gchar **errmsg );
 static void            query_file_attributes( NASelectedInfo *info, GFile *location, gchar **errmsg );
@@ -704,11 +704,34 @@ dump( const NASelectedInfo *nsi )
 	g_debug( "%s:           username=%s", thisfn, nsi->private->username );
 	g_debug( "%s:             scheme=%s", thisfn, nsi->private->scheme );
 	g_debug( "%s:               port=%d", thisfn, nsi->private->port );
+	g_debug( "%s: attributes_are_set=%s", thisfn, nsi->private->attributes_are_set ? "True":"False" );
+	g_debug( "%s:          file_type=%s", thisfn, dump_file_type( nsi->private->file_type ));
 	g_debug( "%s:           can_read=%s", thisfn, nsi->private->can_read ? "True":"False" );
 	g_debug( "%s:          can_write=%s", thisfn, nsi->private->can_write ? "True":"False" );
 	g_debug( "%s:        can_execute=%s", thisfn, nsi->private->can_execute ? "True":"False" );
 	g_debug( "%s:              owner=%s", thisfn, nsi->private->owner );
-	g_debug( "%s: attributes_are_set=%s", thisfn, nsi->private->attributes_are_set ? "True":"False" );
+}
+
+static const char *
+dump_file_type( GFileType type )
+{
+	switch( type ){
+		case G_FILE_TYPE_REGULAR:
+			return( "regular" );
+		case G_FILE_TYPE_DIRECTORY:
+			return( "directory" );
+		case G_FILE_TYPE_SYMBOLIC_LINK:
+			return( "symbolic link" );
+		case G_FILE_TYPE_SPECIAL:
+			return( "special (socket, fifo, blockdev, chardev)" );
+		case G_FILE_TYPE_SHORTCUT:
+			return( "shortcut" );
+		case G_FILE_TYPE_MOUNTABLE:
+			return( "mountable" );
+		default:
+			break;
+	}
+	return( "unknown" );
 }
 
 static NASelectedInfo *
@@ -716,7 +739,6 @@ new_from_nautilus_file_info( NautilusFileInfo *item )
 {
 	gchar *uri = nautilus_file_info_get_uri( item );
 	gchar *mimetype = nautilus_file_info_get_mime_type( item );
-	g_debug( "new_from_nautilus_file_info: uri=%s, mimetype=%s", uri, mimetype );
 	NASelectedInfo *info = new_from_uri( uri, mimetype, NULL );
 	g_free( mimetype );
 	g_free( uri );
@@ -773,7 +795,6 @@ new_from_nautilus_file_info( NautilusFileInfo *item )
  * be properly represented within a URI.
  *
  * pwi 2011-01-04:
- *
  * It results from the above excerpt that:
  * - as double quotes are not valid character in URI, they have to be
  *   escaped as %22, and so Nautilus does
@@ -787,36 +808,38 @@ new_from_uri( const gchar *uri, const gchar *mimetype, gchar **errmsg )
 {
 	GFile *location;
 	NAGnomeVFSURI *vfs;
-	GError *error;
 
-	NASelectedInfo *info = g_object_new( NA_SELECTED_INFO_TYPE, NULL );
+	NASelectedInfo *info = g_object_new( NA_TYPE_SELECTED_INFO, NULL );
 
 	info->private->uri = g_strdup( uri );
 	if( mimetype ){
 		info->private->mimetype = g_strdup( mimetype );
 	}
 
+	/* pwi 2011-05-18
+	 * Filename and dirname should be taken from the GFile location, itself taken
+	 * from the URI, so that we have dir='/home/pierre/.gvfs/sftp on stormy.trychlos.org/etc'
+	 * Taking filename and dirname from URI just gives '/etc'
+	 * see #650523
+	 */
+	location = g_file_new_for_uri( uri );
+	info->private->filename = g_file_get_path( location );
+
 	vfs = g_new0( NAGnomeVFSURI, 1 );
 	na_gnome_vfs_uri_parse( vfs, uri );
-	error = NULL;
-	info->private->filename = g_filename_from_uri( uri, NULL, &error );
-	if( error ){
-		g_debug( "new_from_uri: uri='%s', error=%s", uri, error->message );
-		g_error_free( error );
-	}
 	if( !info->private->filename ){
-		g_debug( "new_from_uri: uri='%s', filename=NULL, setting it to '%s'", uri, vfs->path );
+		g_debug( "na_selected_info_new_from_uri: uri='%s', filename=NULL, setting it to '%s'", uri, vfs->path );
 		info->private->filename = g_strdup( vfs->path );
 	}
-	info->private->dirname = g_path_get_dirname( info->private->filename );
+
 	info->private->basename = g_path_get_basename( info->private->filename );
+	info->private->dirname = g_path_get_dirname( info->private->filename );
 	info->private->hostname = g_strdup( vfs->host_name );
 	info->private->username = g_strdup( vfs->user_name );
 	info->private->scheme = g_strdup( vfs->scheme );
 	info->private->port = vfs->host_port;
 	na_gnome_vfs_uri_free( vfs );
 
-	location = g_file_new_for_uri( uri );
 	query_file_attributes( info, location, errmsg );
 	g_object_unref( location );
 
@@ -845,8 +868,7 @@ query_file_attributes( NASelectedInfo *nsi, GFile *location, gchar **errmsg )
 		if( errmsg ){
 			*errmsg = g_strdup_printf( _( "Error when querying informations for %s URI: %s" ), nsi->private->uri, error->message );
 		} else {
-			g_warning( "%s: URI='%s'", thisfn, nsi->private->uri );
-			g_warning( "%s: g_file_query_info: %s", thisfn, error->message );
+			g_warning( "%s: uri=%s, g_file_query_info: %s", thisfn, nsi->private->uri, error->message );
 		}
 		g_error_free( error );
 		return;
