@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -147,19 +146,20 @@ static const KeyDef st_def_keys[] = {
 	{ NA_IPREFS_TRY_EXEC_WSP,                     GROUP_NACT,    NA_DATA_TYPE_UINT_LIST,   "" },
 	{ NA_IPREFS_TRY_EXEC_URI,                     GROUP_NACT,    NA_DATA_TYPE_STRING,      "file:///bin" },
 	{ NA_IPREFS_EXPORT_ASK_USER_WSP,              GROUP_NACT,    NA_DATA_TYPE_UINT_LIST,   "" },
-	{ NA_IPREFS_EXPORT_ASK_USER_LAST_FORMAT,      GROUP_NACT,    NA_DATA_TYPE_STRING,      NA_IPREFS_DEFAULT_EXPORT_FORMAT },
+	{ NA_IPREFS_EXPORT_ASK_USER_LAST_FORMAT,      GROUP_NACT,    NA_DATA_TYPE_STRING,      "Desktop1" },
 	{ NA_IPREFS_EXPORT_ASK_USER_KEEP_LAST_CHOICE, GROUP_NACT,    NA_DATA_TYPE_BOOLEAN,     "false" },
 	{ NA_IPREFS_EXPORT_ASSISTANT_WSP,             GROUP_NACT,    NA_DATA_TYPE_UINT_LIST,   "" },
 	{ NA_IPREFS_EXPORT_ASSISTANT_URI,             GROUP_NACT,    NA_DATA_TYPE_STRING,      "file:///tmp" },
-	{ NA_IPREFS_EXPORT_PREFERRED_FORMAT,          GROUP_NACT,    NA_DATA_TYPE_STRING,      NA_IPREFS_DEFAULT_EXPORT_FORMAT },
+	{ NA_IPREFS_EXPORT_ASSISTANT_PANED,           GROUP_NACT,    NA_DATA_TYPE_UINT,        "200" },
+	{ NA_IPREFS_EXPORT_PREFERRED_FORMAT,          GROUP_NACT,    NA_DATA_TYPE_STRING,      "Ask" },
 	{ NA_IPREFS_FOLDER_CHOOSER_WSP,               GROUP_NACT,    NA_DATA_TYPE_UINT_LIST,   "" },
 	{ NA_IPREFS_FOLDER_CHOOSER_URI,               GROUP_NACT,    NA_DATA_TYPE_STRING,      "file:///" },
 	{ NA_IPREFS_IMPORT_ASK_USER_WSP,              GROUP_NACT,    NA_DATA_TYPE_UINT_LIST,   "" },
-	{ NA_IPREFS_IMPORT_ASK_USER_LAST_MODE,        GROUP_NACT,    NA_DATA_TYPE_STRING,      NA_IPREFS_DEFAULT_IMPORT_MODE },
+	{ NA_IPREFS_IMPORT_ASK_USER_LAST_MODE,        GROUP_NACT,    NA_DATA_TYPE_STRING,      "NoImport" },
 	{ NA_IPREFS_IMPORT_ASSISTANT_WSP,             GROUP_NACT,    NA_DATA_TYPE_UINT_LIST,   "" },
 	{ NA_IPREFS_IMPORT_ASSISTANT_URI,             GROUP_NACT,    NA_DATA_TYPE_STRING,      "file:///tmp" },
 	{ NA_IPREFS_IMPORT_ASK_USER_KEEP_LAST_CHOICE, GROUP_NACT,    NA_DATA_TYPE_BOOLEAN,     "false" },
-	{ NA_IPREFS_IMPORT_PREFERRED_MODE,            GROUP_NACT,    NA_DATA_TYPE_STRING,      NA_IPREFS_DEFAULT_IMPORT_MODE },
+	{ NA_IPREFS_IMPORT_PREFERRED_MODE,            GROUP_NACT,    NA_DATA_TYPE_STRING,      "Ask" },
 	{ NA_IPREFS_IO_PROVIDERS_WRITE_ORDER,         GROUP_NACT,    NA_DATA_TYPE_STRING_LIST, "" },
 	{ NA_IPREFS_ICON_CHOOSER_URI,                 GROUP_NACT,    NA_DATA_TYPE_STRING,      "file:///" },
 	{ NA_IPREFS_ICON_CHOOSER_PANED,               GROUP_NACT,    NA_DATA_TYPE_UINT,        "200" },
@@ -167,10 +167,11 @@ static const KeyDef st_def_keys[] = {
 	{ NA_IPREFS_ITEMS_ADD_ABOUT_ITEM,             GROUP_RUNTIME, NA_DATA_TYPE_BOOLEAN,     "true" },
 	{ NA_IPREFS_ITEMS_CREATE_ROOT_MENU,           GROUP_RUNTIME, NA_DATA_TYPE_BOOLEAN,     "true" },
 	{ NA_IPREFS_ITEMS_LEVEL_ZERO_ORDER,           GROUP_RUNTIME, NA_DATA_TYPE_STRING_LIST, "" },
-	{ NA_IPREFS_ITEMS_LIST_ORDER_MODE,            GROUP_RUNTIME, NA_DATA_TYPE_STRING,      NA_IPREFS_DEFAULT_LIST_ORDER_MODE },
+	{ NA_IPREFS_ITEMS_LIST_ORDER_MODE,            GROUP_RUNTIME, NA_DATA_TYPE_STRING,      "AscendingOrder" },
 	{ NA_IPREFS_MAIN_PANED,                       GROUP_NACT,    NA_DATA_TYPE_UINT,        "200" },
 	{ NA_IPREFS_MAIN_SAVE_AUTO,                   GROUP_NACT,    NA_DATA_TYPE_BOOLEAN,     "false" },
 	{ NA_IPREFS_MAIN_SAVE_PERIOD,                 GROUP_NACT,    NA_DATA_TYPE_UINT,        "5" },
+	{ NA_IPREFS_MAIN_TABS_POS,                    GROUP_NACT,    NA_DATA_TYPE_STRING,      "Top" },
 	{ NA_IPREFS_MAIN_TOOLBAR_EDIT_DISPLAY,        GROUP_NACT,    NA_DATA_TYPE_BOOLEAN,     "true" },
 	{ NA_IPREFS_MAIN_TOOLBAR_FILE_DISPLAY,        GROUP_NACT,    NA_DATA_TYPE_BOOLEAN,     "true" },
 	{ NA_IPREFS_MAIN_TOOLBAR_HELP_DISPLAY,        GROUP_NACT,    NA_DATA_TYPE_BOOLEAN,     "true" },
@@ -422,7 +423,8 @@ settings_new( void )
 		g_free( dir );
 
 		dir = g_build_filename( g_get_home_dir(), ".config", PACKAGE, NULL );
-		g_mkdir_with_parents( dir, 750 );
+		g_mkdir_with_parents( dir, 0750 );
+		na_core_utils_dir_list_perms( dir, thisfn );
 		g_debug( "%s: reading user configuration", thisfn );
 		st_settings->private->user = key_file_new( dir );
 		g_free( dir );
@@ -451,7 +453,7 @@ na_settings_free( void )
  *
  * Registers a new consumer of the monitoring of the @key.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 void
 na_settings_register_key_callback( const gchar *key, GCallback callback, gpointer user_data )
@@ -486,7 +488,7 @@ na_settings_register_key_callback( const gchar *key, GCallback callback, gpointe
  *
  * Returns: the value of the key, of its default value if not found.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_settings_get_boolean( const gchar *key, gboolean *found, gboolean *mandatory )
@@ -508,7 +510,7 @@ na_settings_get_boolean( const gchar *key, gboolean *found, gboolean *mandatory
  *
  * Returns: the value of the key, of its default value if not found.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_settings_get_boolean_ex( const gchar *group, const gchar *key, gboolean *found, gboolean *mandatory )
@@ -551,7 +553,7 @@ na_settings_get_boolean_ex( const gchar *group, const gchar *key, gboolean *foun
  * Returns: the value of the key as a newly allocated string, which should
  * be g_free() by the caller.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gchar *
 na_settings_get_string( const gchar *key, gboolean *found, gboolean *mandatory )
@@ -594,7 +596,7 @@ na_settings_get_string( const gchar *key, gboolean *found, gboolean *mandatory )
  * Returns: the value of the key as a newly allocated list of strings.
  * The returned list should be na_core_utils_slist_free() by the caller.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 GSList *
 na_settings_get_string_list( const gchar *key, gboolean *found, gboolean *mandatory )
@@ -636,7 +638,7 @@ na_settings_get_string_list( const gchar *key, gboolean *found, gboolean *mandat
  *
  * Returns: the value of the key.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 guint
 na_settings_get_uint( const gchar *key, gboolean *found, gboolean *mandatory )
@@ -679,7 +681,7 @@ na_settings_get_uint( const gchar *key, gboolean *found, gboolean *mandatory )
  * Returns: the value of the key as a newly allocated list of uints.
  * The returned list should be g_list_free() by the caller.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 GList *
 na_settings_get_uint_list( const gchar *key, gboolean *found, gboolean *mandatory )
@@ -717,7 +719,7 @@ na_settings_get_uint_list( const gchar *key, gboolean *found, gboolean *mandator
  *
  * Returns: %TRUE is the writing has been successful, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_settings_set_boolean( const gchar *key, gboolean value )
@@ -742,7 +744,7 @@ na_settings_set_boolean( const gchar *key, gboolean value )
  *
  * Returns: %TRUE is the writing has been successful, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_settings_set_boolean_ex( const gchar *group, const gchar *key, gboolean value )
@@ -769,7 +771,7 @@ na_settings_set_boolean_ex( const gchar *group, const gchar *key, gboolean value
  *
  * Returns: %TRUE is the writing has been successful, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_settings_set_string( const gchar *key, const gchar *value )
@@ -777,6 +779,24 @@ na_settings_set_string( const gchar *key, const gchar *value )
 	return( set_key_value( NULL, key, value ));
 }
 
+/**
+ * na_settings_set_string_ex:
+ * @group: the group in the keyed file;
+ * @key: the key whose value is to be returned.
+ * @value: the string to be written.
+ *
+ * This function writes @value as a user preference.
+ *
+ * Returns: %TRUE is the writing has been successful, %FALSE else.
+ *
+ * Since: 3.2
+ */
+gboolean
+na_settings_set_string_ex( const gchar *group, const gchar *key, const gchar *value )
+{
+	return( set_key_value( group, key, value ));
+}
+
 /**
  * na_settings_set_string_list:
  * @key: the key whose value is to be returned.
@@ -789,7 +809,7 @@ na_settings_set_string( const gchar *key, const gchar *value )
  *
  * Returns: %TRUE is the writing has been successful, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_settings_set_string_list( const gchar *key, const GSList *value )
@@ -808,6 +828,31 @@ na_settings_set_string_list( const gchar *key, const GSList *value )
 	return( ok );
 }
 
+/**
+ * na_settings_set_int_ex:
+ * @group: the group in the keyed file;
+ * @key: the key whose value is to be returned.
+ * @value: the unsigned integer to be written.
+ *
+ * This function writes @value as a user preference.
+ *
+ * Returns: %TRUE is the writing has been successful, %FALSE else.
+ *
+ * Since: 3.2
+ */
+gboolean
+na_settings_set_int_ex( const gchar *group, const gchar *key, int value )
+{
+	gchar *string;
+	gboolean ok;
+
+	string = g_strdup_printf( "%d", value );
+	ok = set_key_value( group, key, string );
+	g_free( string );
+
+	return( ok );
+}
+
 /**
  * na_settings_set_uint:
  * @key: the key whose value is to be returned.
@@ -820,7 +865,7 @@ na_settings_set_string_list( const gchar *key, const GSList *value )
  *
  * Returns: %TRUE is the writing has been successful, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_settings_set_uint( const gchar *key, guint value )
@@ -847,7 +892,7 @@ na_settings_set_uint( const gchar *key, guint value )
  *
  * Returns: %TRUE is the writing has been successful, %FALSE else.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 gboolean
 na_settings_set_uint_list( const gchar *key, const GList *value )
@@ -876,7 +921,7 @@ na_settings_set_uint_list( const gchar *key, const GList *value )
  * known i/o providers from preferences. We do not care of returning unique
  * or sorted group names.
  *
- * Since: 3.1.0
+ * Since: 3.1
  */
 GSList *
 na_settings_get_groups( void )
@@ -1260,10 +1305,9 @@ read_key_value_from_key_file( GKeyFile *key_file, const gchar *group, const gcha
 	gchar *str;
 	GError *error;
 
-	g_debug( "%s: group=%s, key=%s", thisfn, group, key );
-
 	value = NULL;
 	error = NULL;
+	str = NULL;
 
 	switch( key_def->type ){
 
@@ -1294,14 +1338,23 @@ read_key_value_from_key_file( GKeyFile *key_file, const gchar *group, const gcha
 						break;
 				}
 			}
-			g_free( str );
 			break;
 
 		default:
-			g_warning( "%s: unmanaged boxed type: %d", thisfn, key_def->type );
-			break;
+			g_warning( "%s: group=%s, key=%s - unmanaged boxed type: %d", thisfn, group, key, key_def->type );
+			return( NULL );
 	}
 
+#ifdef NA_MAINTAINER_MODE
+	if( value ){
+		g_debug( "%s: group=%s, key=%s value=%s", thisfn, group, key, str );
+	} else {
+		g_debug( "%s: group=%s, key=%s not found", thisfn, group, key );
+	}
+#endif
+
+	g_free( str );
+
 	return( value );
 }
 
