@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -90,7 +89,7 @@ static void      instance_finalize( GObject *object );
 static void      child_watch_fn( GPid pid, gint status, ChildStr *child_str );
 static void      display_output( const gchar *command, int fd_stdout, int fd_stderr );
 static gchar    *display_output_get_content( int fd );
-static void      execute_action_command( gchar *command, const NAObjectProfile *profile );
+static void      execute_action_command( gchar *command, const NAObjectProfile *profile, const NATokens *tokens );
 static gchar    *get_command_execution_display_output( const gchar *command );
 static gchar    *get_command_execution_embedded( const gchar *command );
 static gchar    *get_command_execution_normal( const gchar *command );
@@ -260,7 +259,7 @@ na_tokens_new_for_example( void )
 	GSList *is;
 	gboolean first;
 
-	tokens = g_object_new( NA_TOKENS_TYPE, NULL );
+	tokens = g_object_new( NA_TYPE_TOKENS, NULL );
 	first = TRUE;
 	tokens->private->count = 2;
 
@@ -316,7 +315,7 @@ na_tokens_new_from_selection( GList *selection )
 	g_debug( "%s: selection=%p (count=%d)", thisfn, ( void * ) selection, g_list_length( selection ));
 
 	first = TRUE;
-	tokens = g_object_new( NA_TOKENS_TYPE, NULL );
+	tokens = g_object_new( NA_TYPE_TOKENS, NULL );
 
 	tokens->private->count = g_list_length( selection );
 
@@ -395,13 +394,13 @@ na_tokens_execute_action( const NATokens *tokens, const NAObjectProfile *profile
 	if( singular ){
 		for( i = 0 ; i < tokens->private->count ; ++i ){
 			command = parse_singular( tokens, exec, i, FALSE, TRUE );
-			execute_action_command( command, profile );
+			execute_action_command( command, profile, tokens );
 			g_free( command );
 		}
 
 	} else {
 		command = parse_singular( tokens, exec, 0, FALSE, TRUE );
-		execute_action_command( command, profile );
+		execute_action_command( command, profile, tokens );
 		g_free( command );
 	}
 
@@ -490,14 +489,14 @@ display_output_get_content( int fd )
  * - DisplayOutput: execute in a shell
  */
 static void
-execute_action_command( gchar *command, const NAObjectProfile *profile )
+execute_action_command( gchar *command, const NAObjectProfile *profile, const NATokens *tokens )
 {
 	static const gchar *thisfn = "nautilus_actions_execute_action_command";
 	GError *error;
 	gchar *execution_mode, *run_command;
 	gchar **argv;
 	gint argc;
-	gchar *wdir;
+	gchar *wdir, *wdir_nq;
 	GPid child_pid;
 	ChildStr *child_str;
 
@@ -535,17 +534,19 @@ execute_action_command( gchar *command, const NAObjectProfile *profile )
 
 		} else {
 			wdir = na_object_get_working_dir( profile );
-			g_debug( "%s: run_command=%s, wdir=%s", thisfn, run_command, wdir );
+			wdir_nq = parse_singular( tokens, wdir, 0, FALSE, FALSE );
+			g_debug( "%s: run_command=%s, wdir=%s", thisfn, run_command, wdir_nq );
 
 			/* it appears that at least mplayer does not support g_spawn_async_with_pipes
-			 * (at least when notrun in '-quiet' mode) while, e.g., totem and vlc rightly
+			 * (at least when not run in '-quiet' mode) while, e.g., totem and vlc rightly
 			 * support this function
 			 * So only use g_spawn_async_with_pipes when we really need to get back
 			 * the content of output and error streams
 			 * See https://bugzilla.gnome.org/show_bug.cgi?id=644289.
 			 */
 			if( child_str->is_output_displayed ){
-				g_spawn_async_with_pipes( wdir,
+				g_spawn_async_with_pipes(
+						wdir_nq,
 						argv,
 						NULL,
 						G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
@@ -558,7 +559,8 @@ execute_action_command( gchar *command, const NAObjectProfile *profile )
 						&error );
 
 			} else {
-				g_spawn_async( wdir,
+				g_spawn_async(
+						wdir_nq,
 						argv,
 						NULL,
 						G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
@@ -578,6 +580,7 @@ execute_action_command( gchar *command, const NAObjectProfile *profile )
 			}
 
 			g_free( wdir );
+			g_free( wdir_nq );
 			g_strfreev( argv );
 		}
 
@@ -719,6 +722,8 @@ is_singular_exec( const NATokens *tokens, const gchar *exec )
  * @i: the number of the iteration in a multiple selection, starting with zero.
  * @utf8: whether the @input string is UTF-8 encoded, or a standard ASCII
  *  string.
+ * @quoted: whether the filenames have to be quoted (should be %TRUE when
+ *  about to execute a command).
  *
  * A command is said of 'singular form' when its first parameter is not
  * of plural form. In the case of a multiple selection, singular form
