@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -53,6 +52,7 @@ struct _NadpDesktopFilePrivate {
 	gboolean   dispose_has_run;
 	gchar     *id;
 	gchar     *uri;
+	gchar     *type;
 	GKeyFile  *key_file;
 };
 
@@ -178,6 +178,7 @@ instance_finalize( GObject *object )
 
 	g_free( self->private->id );
 	g_free( self->private->uri );
+	g_free( self->private->type );
 
 	if( self->private->key_file ){
 		g_key_file_free( self->private->key_file );
@@ -201,7 +202,7 @@ nadp_desktop_file_new( void )
 {
 	NadpDesktopFile *ndf;
 
-	ndf = g_object_new( NADP_DESKTOP_FILE_TYPE, NULL );
+	ndf = g_object_new( NADP_TYPE_DESKTOP_FILE, NULL );
 
 	return( ndf );
 }
@@ -277,26 +278,35 @@ nadp_desktop_file_new_from_uri( const gchar *uri )
 	gsize length;
 
 	ndf = NULL;
+	data = NULL;
+	length = 0;
+
 	g_debug( "%s: uri=%s", thisfn, uri );
 	g_return_val_if_fail( uri && g_utf8_strlen( uri, -1 ), ndf );
 
-	ndf = ndf_new( uri );
 	data = na_core_utils_file_load_from_uri( uri, &length );
+	g_debug( "%s: length=%lu", thisfn, ( unsigned long ) length );
 
-	error = NULL;
-	g_key_file_load_from_data( ndf->private->key_file, data, length, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &error );
-	if( error ){
-		if( error->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND ){
-			g_warning( "%s: %s", thisfn, error->message );
-		}
-		g_error_free( error );
-		g_object_unref( ndf );
-		g_free( data );
+	/* normally, length and data should be both NULL or both not NULL
+	 */
+	if( !length || !data ){
 		return( NULL );
 	}
 
+	error = NULL;
+	ndf = ndf_new( uri );
+	g_key_file_load_from_data( ndf->private->key_file, data, length, G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &error );
 	g_free( data );
 
+	if( error ){
+		if( error->code != G_KEY_FILE_ERROR_GROUP_NOT_FOUND ){
+			g_debug( "%s: %s", thisfn, error->message );
+		}
+		g_error_free( error );
+		g_object_unref( ndf );
+		return( NULL );
+	}
+
 	if( !check_key_file( ndf )){
 		g_object_unref( ndf );
 		return( NULL );
@@ -391,7 +401,7 @@ ndf_new( const gchar *uri )
 {
 	NadpDesktopFile *ndf;
 
-	ndf = g_object_new( NADP_DESKTOP_FILE_TYPE, NULL );
+	ndf = g_object_new( NADP_TYPE_DESKTOP_FILE, NULL );
 
 	ndf->private->id = uri2id( uri );
 	ndf->private->uri = g_strdup( uri );
@@ -440,6 +450,7 @@ check_key_file( NadpDesktopFile *ndf )
 	gchar *start_group;
 	gboolean has_key;
 	gboolean hidden;
+	gchar *type;
 	GError *error;
 
 	ret = TRUE;
@@ -448,7 +459,7 @@ check_key_file( NadpDesktopFile *ndf )
 	/* start group must be [Desktop Entry] */
 	start_group = g_key_file_get_start_group( ndf->private->key_file );
 	if( strcmp( start_group, NADP_GROUP_DESKTOP )){
-		g_warning( "%s: %s: invalid start group, found %s, waited for %s",
+		g_debug( "%s: %s: invalid start group, found %s, waited for %s",
 				thisfn, ndf->private->uri, start_group, NADP_GROUP_DESKTOP );
 		ret = FALSE;
 	}
@@ -457,13 +468,13 @@ check_key_file( NadpDesktopFile *ndf )
 	if( ret ){
 		has_key = g_key_file_has_key( ndf->private->key_file, start_group, NADP_KEY_HIDDEN, &error );
 		if( error ){
-			g_warning( "%s: %s: %s", thisfn, ndf->private->uri, error->message );
+			g_debug( "%s: %s: %s", thisfn, ndf->private->uri, error->message );
 			ret = FALSE;
 
 		} else if( has_key ){
 			hidden = g_key_file_get_boolean( ndf->private->key_file, start_group, NADP_KEY_HIDDEN, &error );
 			if( error ){
-				g_warning( "%s: %s: %s", thisfn, ndf->private->uri, error->message );
+				g_debug( "%s: %s: %s", thisfn, ndf->private->uri, error->message );
 				ret = FALSE;
 
 			} else if( hidden ){
@@ -473,6 +484,42 @@ check_key_file( NadpDesktopFile *ndf )
 		}
 	}
 
+	/* must have no Type (which defaults to Action)
+	 * or a known one (Action or Menu)
+	 */
+	if( ret ){
+		type = NULL;
+		has_key = g_key_file_has_key( ndf->private->key_file, start_group, NADP_KEY_TYPE, &error );
+		if( error ){
+			g_debug( "%s: %s", thisfn, error->message );
+			g_error_free( error );
+			ret = FALSE;
+
+		} else if( has_key ){
+			type = g_key_file_get_string( ndf->private->key_file, start_group, NADP_KEY_TYPE, &error );
+			if( error ){
+				g_debug( "%s: %s", thisfn, error->message );
+				g_free( type );
+				g_error_free( error );
+				ret = FALSE;
+			}
+		}
+		if( ret ){
+			if( !type || !strlen( type )){
+				type = g_strdup( NADP_VALUE_TYPE_ACTION );
+
+			} else if( strcmp( type, NADP_VALUE_TYPE_MENU ) && strcmp( type, NADP_VALUE_TYPE_ACTION )){
+				g_debug( "%s: unmanaged type: %s", thisfn, type );
+				g_free( type );
+				ret = FALSE;
+			}
+		}
+		if( ret ){
+			g_return_val_if_fail( type && strlen( type ), FALSE );
+			ndf->private->type = type;
+		}
+	}
+
 	g_free( start_group );
 
 	return( ret );
@@ -488,10 +535,7 @@ check_key_file( NadpDesktopFile *ndf )
 gchar *
 nadp_desktop_file_get_file_type( const NadpDesktopFile *ndf )
 {
-	static const gchar *thisfn = "nadp_desktop_file_get_file_type";
 	gchar *type;
-	gboolean has_key;
-	GError *error;
 
 	g_return_val_if_fail( NADP_IS_DESKTOP_FILE( ndf ), NULL );
 
@@ -499,22 +543,7 @@ nadp_desktop_file_get_file_type( const NadpDesktopFile *ndf )
 
 	if( !ndf->private->dispose_has_run ){
 
-		error = NULL;
-
-		has_key = g_key_file_has_key( ndf->private->key_file, NADP_GROUP_DESKTOP, NADP_KEY_TYPE, &error );
-		if( error ){
-			g_warning( "%s: %s", thisfn, error->message );
-			g_error_free( error );
-
-		} else if( has_key ){
-			type = g_key_file_get_string( ndf->private->key_file, NADP_GROUP_DESKTOP, NADP_KEY_TYPE, &error );
-			if( error ){
-				g_warning( "%s: %s", thisfn, error->message );
-				g_error_free( error );
-				g_free( type );
-				type = NULL;
-			}
-		}
+		type = g_strdup( ndf->private->type );
 	}
 
 	return( type );
@@ -591,6 +620,37 @@ nadp_desktop_file_get_profiles( const NadpDesktopFile *ndf )
 	return( list );
 }
 
+/**
+ * nadp_desktop_file_has_profile:
+ * @ndf: the #NadpDesktopFile instance.
+ * @profile_id: the identifier of the profile.
+ *
+ * Returns: %TRUE if a group can be found in the .desktop file for this profile,
+ * %FALSE else.
+ *
+ * Since: 3.1
+ */
+gboolean
+nadp_desktop_file_has_profile( const NadpDesktopFile *ndf, const gchar *profile_id )
+{
+	gboolean has_profile;
+	gchar *group_name;
+
+	g_return_val_if_fail( NADP_IS_DESKTOP_FILE( ndf ), FALSE );
+	g_return_val_if_fail( profile_id && g_utf8_strlen( profile_id, -1 ), FALSE );
+
+	has_profile = FALSE;
+
+	if( !ndf->private->dispose_has_run ){
+
+		group_name = g_strdup_printf( "%s %s", NADP_GROUP_PROFILE, profile_id );
+		has_profile = g_key_file_has_group( ndf->private->key_file, group_name );
+		g_free( group_name );
+	}
+
+	return( has_profile );
+}
+
 /**
  * nadp_desktop_file_remove_key:
  * @ndf: this #NadpDesktopFile instance.
