@@ -1,25 +1,24 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -39,6 +38,7 @@
 #include <api/na-ifactory-provider.h>
 
 #include "nadp-desktop-provider.h"
+#include "nadp-formats.h"
 #include "nadp-keys.h"
 #include "nadp-monitor.h"
 #include "nadp-reader.h"
@@ -46,39 +46,37 @@
 
 /* private class data
  */
-struct NadpDesktopProviderClassPrivate {
+struct _NadpDesktopProviderClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
-extern NAIExporterFormat nadp_formats[];
-
 static GType         st_module_type = 0;
 static GObjectClass *st_parent_class = NULL;
 static guint         st_burst_timeout = 100;		/* burst timeout in msec */
 
-static void                     class_init( NadpDesktopProviderClass *klass );
-static void                     instance_init( GTypeInstance *instance, gpointer klass );
-static void                     instance_dispose( GObject *object );
-static void                     instance_finalize( GObject *object );
+static void   class_init( NadpDesktopProviderClass *klass );
+static void   instance_init( GTypeInstance *instance, gpointer klass );
+static void   instance_dispose( GObject *object );
+static void   instance_finalize( GObject *object );
 
-static void                     iio_provider_iface_init( NAIIOProviderInterface *iface );
-static gchar                   *iio_provider_get_id( const NAIIOProvider *provider );
-static gchar                   *iio_provider_get_name( const NAIIOProvider *provider );
-static guint                    iio_provider_get_version( const NAIIOProvider *provider );
+static void   iio_provider_iface_init( NAIIOProviderInterface *iface );
+static gchar *iio_provider_get_id( const NAIIOProvider *provider );
+static gchar *iio_provider_get_name( const NAIIOProvider *provider );
+static guint  iio_provider_get_version( const NAIIOProvider *provider );
 
-static void                     ifactory_provider_iface_init( NAIFactoryProviderInterface *iface );
-static guint                    ifactory_provider_get_version( const NAIFactoryProvider *reader );
+static void   ifactory_provider_iface_init( NAIFactoryProviderInterface *iface );
+static guint  ifactory_provider_get_version( const NAIFactoryProvider *reader );
 
-static void                     iimporter_iface_init( NAIImporterInterface *iface );
-static guint                    iimporter_get_version( const NAIImporter *importer );
+static void   iimporter_iface_init( NAIImporterInterface *iface );
+static guint  iimporter_get_version( const NAIImporter *importer );
 
-static void                     iexporter_iface_init( NAIExporterInterface *iface );
-static guint                    iexporter_get_version( const NAIExporter *exporter );
-static gchar                   *iexporter_get_name( const NAIExporter *exporter );
-static const NAIExporterFormat *iexporter_get_formats( const NAIExporter *exporter );
+static void   iexporter_iface_init( NAIExporterInterface *iface );
+static guint  iexporter_get_version( const NAIExporter *exporter );
+static gchar *iexporter_get_name( const NAIExporter *exporter );
+static void  *iexporter_get_formats( const NAIExporter *exporter );
+static void   iexporter_free_formats( const NAIExporter *exporter, GList *format_list );
 
-static gboolean                 on_monitor_timeout( NadpDesktopProvider *provider );
-static gulong                   time_val_diff( const GTimeVal *recent, const GTimeVal *old );
+static void   on_monitor_timeout( NadpDesktopProvider *provider );
 
 GType
 nadp_desktop_provider_get_type( void )
@@ -131,13 +129,13 @@ nadp_desktop_provider_register_type( GTypeModule *module )
 
 	st_module_type = g_type_module_register_type( module, G_TYPE_OBJECT, "NadpDesktopProvider", &info, 0 );
 
-	g_type_module_add_interface( module, st_module_type, NA_IIO_PROVIDER_TYPE, &iio_provider_iface_info );
+	g_type_module_add_interface( module, st_module_type, NA_TYPE_IIO_PROVIDER, &iio_provider_iface_info );
 
-	g_type_module_add_interface( module, st_module_type, NA_IFACTORY_PROVIDER_TYPE, &ifactory_provider_iface_info );
+	g_type_module_add_interface( module, st_module_type, NA_TYPE_IFACTORY_PROVIDER, &ifactory_provider_iface_info );
 
-	g_type_module_add_interface( module, st_module_type, NA_IIMPORTER_TYPE, &iimporter_iface_info );
+	g_type_module_add_interface( module, st_module_type, NA_TYPE_IIMPORTER, &iimporter_iface_info );
 
-	g_type_module_add_interface( module, st_module_type, NA_IEXPORTER_TYPE, &iexporter_iface_info );
+	g_type_module_add_interface( module, st_module_type, NA_TYPE_IEXPORTER, &iexporter_iface_info );
 }
 
 static void
@@ -163,15 +161,21 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	static const gchar *thisfn = "nadp_desktop_provider_instance_init";
 	NadpDesktopProvider *self;
 
+	g_return_if_fail( NADP_IS_DESKTOP_PROVIDER( instance ));
+
 	g_debug( "%s: instance=%p (%s), klass=%p",
 			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-	g_return_if_fail( NADP_IS_DESKTOP_PROVIDER( instance ));
+
 	self = NADP_DESKTOP_PROVIDER( instance );
 
 	self->private = g_new0( NadpDesktopProviderPrivate, 1 );
 
 	self->private->dispose_has_run = FALSE;
 	self->private->monitors = NULL;
+	self->private->timeout.timeout = st_burst_timeout;
+	self->private->timeout.handler = ( NATimeoutFunc ) on_monitor_timeout;
+	self->private->timeout.user_data = self;
+	self->private->timeout.source_id = 0;
 }
 
 static void
@@ -180,12 +184,14 @@ instance_dispose( GObject *object )
 	static const gchar *thisfn = "nadp_desktop_provider_instance_dispose";
 	NadpDesktopProvider *self;
 
-	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 	g_return_if_fail( NADP_IS_DESKTOP_PROVIDER( object ));
+
 	self = NADP_DESKTOP_PROVIDER( object );
 
 	if( !self->private->dispose_has_run ){
 
+		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 		self->private->dispose_has_run = TRUE;
 
 		nadp_desktop_provider_release_monitors( self );
@@ -200,9 +206,13 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
+	static const gchar *thisfn = "nadp_desktop_provider_instance_finalize";
 	NadpDesktopProvider *self;
 
-	g_assert( NADP_IS_DESKTOP_PROVIDER( object ));
+	g_return_if_fail( NADP_IS_DESKTOP_PROVIDER( object ));
+
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 	self = NADP_DESKTOP_PROVIDER( object );
 
 	g_free( self->private );
@@ -240,7 +250,7 @@ iio_provider_get_version( const NAIIOProvider *provider )
 static gchar *
 iio_provider_get_id( const NAIIOProvider *provider )
 {
-	return( g_strdup( "na-desktop" ));
+	return( g_strdup( PROVIDER_ID ));
 }
 
 static gchar *
@@ -285,7 +295,7 @@ iimporter_iface_init( NAIImporterInterface *iface )
 static guint
 iimporter_get_version( const NAIImporter *importer )
 {
-	return( 1 );
+	return( 2 );
 }
 
 static void
@@ -298,6 +308,7 @@ iexporter_iface_init( NAIExporterInterface *iface )
 	iface->get_version = iexporter_get_version;
 	iface->get_name = iexporter_get_name;
 	iface->get_formats = iexporter_get_formats;
+	iface->free_formats = iexporter_free_formats;
 	iface->to_file = nadp_writer_iexporter_export_to_file;
 	iface->to_buffer = nadp_writer_iexporter_export_to_buffer;
 }
@@ -305,7 +316,7 @@ iexporter_iface_init( NAIExporterInterface *iface )
 static guint
 iexporter_get_version( const NAIExporter *exporter )
 {
-	return( 1 );
+	return( 2 );
 }
 
 static gchar *
@@ -314,10 +325,16 @@ iexporter_get_name( const NAIExporter *exporter )
 	return( g_strdup( "NA Desktop Exporter" ));
 }
 
-static const NAIExporterFormat *
+static void *
 iexporter_get_formats( const NAIExporter *exporter )
 {
-	return( nadp_formats );
+	return(( void * ) nadp_formats_get_formats( exporter ));
+}
+
+static void
+iexporter_free_formats( const NAIExporter *exporter, GList *format_list )
+{
+	nadp_formats_free_formats( format_list );
 }
 
 /**
@@ -354,12 +371,7 @@ nadp_desktop_provider_on_monitor_event( NadpDesktopProvider *provider )
 
 	if( !provider->private->dispose_has_run ){
 
-		g_get_current_time( &provider->private->last_event );
-
-		if( !provider->private->event_source_id ){
-			provider->private->event_source_id =
-				g_timeout_add( st_burst_timeout, ( GSourceFunc ) on_monitor_timeout, provider );
-		}
+		na_timeout_event( &provider->private->timeout );
 	}
 }
 
@@ -382,19 +394,10 @@ nadp_desktop_provider_release_monitors( NadpDesktopProvider *provider )
 	}
 }
 
-static gboolean
+static void
 on_monitor_timeout( NadpDesktopProvider *provider )
 {
 	static const gchar *thisfn = "nadp_desktop_provider_on_monitor_timeout";
-	GTimeVal now;
-	gulong diff;
-	gulong timeout_usec = 1000*st_burst_timeout;
-
-	g_get_current_time( &now );
-	diff = time_val_diff( &now, &provider->private->last_event );
-	if( diff < timeout_usec ){
-		return( TRUE );
-	}
 
 	/* last individual notification is older that the st_burst_timeout
 	 * so triggers the NAIIOProvider interface and destroys this timeout
@@ -403,17 +406,4 @@ on_monitor_timeout( NadpDesktopProvider *provider )
 			thisfn, ( void * ) provider, G_OBJECT_TYPE_NAME( provider ));
 
 	na_iio_provider_item_changed( NA_IIO_PROVIDER( provider ));
-	provider->private->event_source_id = 0;
-	return( FALSE );
-}
-
-/*
- * returns the difference in microseconds.
- */
-static gulong
-time_val_diff( const GTimeVal *recent, const GTimeVal *old )
-{
-	gulong microsec = 1000000 * ( recent->tv_sec - old->tv_sec );
-	microsec += recent->tv_usec  - old->tv_usec;
-	return( microsec );
 }
