@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -32,6 +31,7 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -61,6 +61,8 @@ typedef struct {
 }
 	NadpReaderData;
 
+#define ERR_NOT_DESKTOP		_( "The Desktop I/O Provider is not able to handle the URI" )
+
 static GList            *get_list_of_desktop_paths( NadpDesktopProvider *provider, GSList **mesages );
 static void              get_list_of_desktop_files( const NadpDesktopProvider *provider, GList **files, const gchar *dir, GSList **messages );
 static gboolean          is_already_loaded( const NadpDesktopProvider *provider, GList *files, const gchar *desktop_id );
@@ -105,6 +107,7 @@ nadp_iio_provider_read_items( const NAIIOProvider *provider, GSList **messages )
 
 		if( item ){
 			items = g_list_prepend( items, item );
+			na_object_dump( item );
 		}
 	}
 
@@ -269,7 +272,7 @@ item_from_desktop_path( const NadpDesktopProvider *provider, DesktopPath *dps, G
 static NAIFactoryObject *
 item_from_desktop_file( const NadpDesktopProvider *provider, NadpDesktopFile *ndf, GSList **messages )
 {
-	static const gchar *thisfn = "nadp_reader_item_from_desktop_file";
+	/*static const gchar *thisfn = "nadp_reader_item_from_desktop_file";*/
 	NAIFactoryObject *item;
 	gchar *type;
 	NadpReaderData *reader_data;
@@ -278,14 +281,15 @@ item_from_desktop_file( const NadpDesktopProvider *provider, NadpDesktopFile *nd
 	item = NULL;
 	type = nadp_desktop_file_get_file_type( ndf );
 
-	if( !type || !strlen( type ) || !strcmp( type, NADP_VALUE_TYPE_ACTION )){
+	if( !strcmp( type, NADP_VALUE_TYPE_ACTION )){
 		item = NA_IFACTORY_OBJECT( na_object_action_new());
 
 	} else if( !strcmp( type, NADP_VALUE_TYPE_MENU )){
 		item = NA_IFACTORY_OBJECT( na_object_menu_new());
 
 	} else {
-		g_warning( "%s: unknown type=%s", thisfn, type );
+		/* i18n: 'type' is the nature of the item: Action or Menu */
+		na_core_utils_slist_add_message( messages, _( "unknown type: %s" ), type );
 	}
 
 	if( item ){
@@ -304,6 +308,8 @@ item_from_desktop_file( const NadpDesktopProvider *provider, NadpDesktopFile *nd
 		g_free( reader_data );
 	}
 
+	g_free( type );
+
 	return( item );
 }
 
@@ -350,32 +356,39 @@ free_desktop_paths( GList *paths )
  * GLib does not have any primitive to load a key file from an uri.
  * So we have to load the file into memory, and then try to load the key
  * file from the memory data.
+ *
+ * Starting with N-A 3.2, we only honor the version 2 of #NAIImporter interface,
+ * thus no more checking here against possible duplicate identifiers.
  */
 guint
-nadp_reader_iimporter_import_from_uri( const NAIImporter *instance, NAIImporterImportFromUriParms *parms )
+nadp_reader_iimporter_import_from_uri( const NAIImporter *instance, void *parms_ptr )
 {
 	static const gchar *thisfn = "nadp_reader_iimporter_import_from_uri";
 	guint code;
+	NAIImporterImportFromUriParmsv2 *parms;
 	NadpDesktopFile *ndf;
-	NAIImporterManageImportModeParms manage_parms;
 
-	g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, ( void * ) parms );
+	g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, parms_ptr );
 
 	g_return_val_if_fail( NA_IS_IIMPORTER( instance ), IMPORTER_CODE_PROGRAM_ERROR );
 	g_return_val_if_fail( NADP_IS_DESKTOP_PROVIDER( instance ), IMPORTER_CODE_PROGRAM_ERROR );
 
+	parms = ( NAIImporterImportFromUriParmsv2 * ) parms_ptr;
+
+	if( !na_core_utils_file_is_loadable( parms->uri )){
+		code = IMPORTER_CODE_NOT_LOADABLE;
+		return( code );
+	}
+
 	code = IMPORTER_CODE_NOT_WILLING_TO;
 
 	ndf = nadp_desktop_file_new_from_uri( parms->uri );
 	if( ndf ){
-		parms->exist = FALSE;
-		parms->import_mode = IMPORTER_MODE_NO_IMPORT;
 		parms->imported = ( NAObjectItem * ) item_from_desktop_file(
 				( const NadpDesktopProvider * ) NADP_DESKTOP_PROVIDER( instance ),
 				ndf, &parms->messages );
 
 		if( parms->imported ){
-			code = IMPORTER_CODE_OK;
 			g_return_val_if_fail( NA_IS_OBJECT_ITEM( parms->imported ), IMPORTER_CODE_NOT_WILLING_TO );
 
 			/* remove the weak reference on desktop file set by 'item_from_desktop_file'
@@ -385,27 +398,16 @@ nadp_reader_iimporter_import_from_uri( const NAIImporter *instance, NAIImporterI
 			g_object_weak_unref( G_OBJECT( parms->imported ), ( GWeakNotify ) desktop_weak_notify, ndf );
 			g_object_unref( ndf );
 
-			manage_parms.version = 1;
-			manage_parms.imported = parms->imported;
-			manage_parms.check_fn = parms->check_fn;
-			manage_parms.check_fn_data = parms->check_fn_data;
-			manage_parms.ask_fn = parms->ask_fn;
-			manage_parms.ask_fn_data = parms->ask_fn_data;
-			manage_parms.asked_mode = parms->asked_mode;
-			manage_parms.messages = parms->messages;
+			/* also remove the 'writable' status'
+			 */
+			na_object_set_readonly( parms->imported, FALSE );
 
-			code = na_iimporter_manage_import_mode( &manage_parms );
-
-			parms->exist = manage_parms.exist;
-			parms->import_mode = manage_parms.import_mode;
+			code = IMPORTER_CODE_OK;
 		}
+	}
 
-		if( code != IMPORTER_CODE_OK ){
-			if( parms->imported ){
-				g_object_unref( parms->imported );
-				parms->imported = NULL;
-			}
-		}
+	if( code == IMPORTER_CODE_NOT_WILLING_TO ){
+		na_core_utils_slist_add_message( &parms->messages, ERR_NOT_DESKTOP );
 	}
 
 	return( code );
@@ -626,17 +628,22 @@ read_done_item_is_writable( const NAIFactoryProvider *provider, NAObjectItem *it
 }
 
 /*
- * read and attach profiles in the specified order
- * profiles which may exist in .desktop files, but are not referenced
- * in the 'Profiles' string list are just ignored
+ * Read and attach profiles in the specified order
+ * - profiles which may exist in .desktop files, but are not referenced
+ *   in the 'Profiles' string list are just ignored
+ * - profiles which may be referenced in the action string list, but are not
+ *   found in the .desktop file are recreated with default values (plus a warning)
+ * - ensure that there is at least one profile attached to the action
  */
 static void
 read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectAction *action, NadpReaderData *reader_data, GSList **messages )
 {
+	static const gchar *thisfn = "nadp_reader_read_done_action_read_profiles";
 	GSList *order;
 	GSList *ip;
 	gchar *profile_id;
 	NAObjectId *found;
+	NAObjectProfile *profile;
 
 	reader_data->action = action;
 	order = na_object_get_items_slist( action );
@@ -650,21 +657,34 @@ read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectActi
 	}
 
 	na_core_utils_slist_free( order );
+
+	if( !na_object_get_items_count( action )){
+		g_warning( "%s: no profile found in .desktop file", thisfn );
+		profile = na_object_profile_new_with_defaults();
+		na_object_attach_profile( action, profile );
+	}
 }
 
 static void
 read_done_action_load_profile( const NAIFactoryProvider *provider, NadpReaderData *reader_data, const gchar *profile_id, GSList **messages )
 {
+	static const gchar *thisfn = "nadp_reader_read_done_action_load_profile";
 	NAObjectProfile *profile;
 
-	g_debug( "nadp_reader_read_done_action_load_profile: loading profile=%s", profile_id );
+	g_debug( "%s: loading profile=%s", thisfn, profile_id );
 
-	profile = na_object_profile_new();
+	profile = na_object_profile_new_with_defaults();
 	na_object_set_id( profile, profile_id );
 
-	na_ifactory_provider_read_item(
-			NA_IFACTORY_PROVIDER( provider ),
-			reader_data,
-			NA_IFACTORY_OBJECT( profile ),
-			messages );
+	if( nadp_desktop_file_has_profile( reader_data->ndf, profile_id )){
+		na_ifactory_provider_read_item(
+				NA_IFACTORY_PROVIDER( provider ),
+				reader_data,
+				NA_IFACTORY_OBJECT( profile ),
+				messages );
+
+	} else {
+		g_warning( "%s: profile '%s' not found in .desktop file", thisfn, profile_id );
+		na_object_attach_profile( reader_data->action, profile );
+	}
 }
