@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -71,7 +70,11 @@ static void            desktop_weak_notify( NadpDesktopFile *ndf, GObject *item
 static void            write_start_write_type( NadpDesktopFile *ndp, NAObjectItem *item );
 static void            write_done_write_subitems_list( NadpDesktopFile *ndp, NAObjectItem *item );
 
-static ExportFormatFn *find_export_format_fn( GQuark format );
+static ExportFormatFn *find_export_format_fn( const gchar *format );
+
+#ifdef NA_ENABLE_DEPRECATED
+static ExportFormatFn *find_export_format_fn_from_quark( GQuark format );
+#endif
 
 /*
  * This is implementation of NAIIOProvider::is_willing_to_write method
@@ -94,22 +97,21 @@ nadp_iio_provider_is_able_to_write( const NAIIOProvider *provider )
 	static const gchar *thisfn = "nadp_writer_iio_provider_is_able_to_write";
 	gboolean able_to;
 	gchar *userdir;
-	GSList *messages;
 
 	g_return_val_if_fail( NADP_IS_DESKTOP_PROVIDER( provider ), FALSE );
 
 	able_to = FALSE;
-	messages = NULL;
 
 	userdir = nadp_xdg_dirs_get_user_data_dir();
 
 	if( g_file_test( userdir, G_FILE_TEST_IS_DIR )){
 		able_to = na_core_utils_dir_is_writable_path( userdir );
 
-	} else if( g_mkdir_with_parents( userdir, 0700 )){
+	} else if( g_mkdir_with_parents( userdir, 0750 )){
 		g_warning( "%s: %s: %s", thisfn, userdir, g_strerror( errno ));
 
 	} else {
+		na_core_utils_dir_list_perms( userdir, thisfn );
 		able_to = na_core_utils_dir_is_writable_path( userdir );
 	}
 
@@ -158,9 +160,11 @@ nadp_iio_provider_write_item( const NAIIOProvider *provider, const NAObjectItem
 		dir_ok = TRUE;
 
 		if( !g_file_test( fulldir, G_FILE_TEST_IS_DIR )){
-			if( g_mkdir_with_parents( fulldir, 0700 )){
+			if( g_mkdir_with_parents( fulldir, 0750 )){
 				g_warning( "%s: %s: %s", thisfn, userdir, g_strerror( errno ));
 				dir_ok = FALSE;
+			} else {
+				na_core_utils_dir_list_perms( userdir, thisfn );
 			}
 		}
 		g_free( userdir );
@@ -343,12 +347,12 @@ nadp_iio_provider_duplicate_data( const NAIIOProvider *provider, NAObjectItem *d
 /**
  * nadp_writer_iexporter_export_to_buffer:
  * @instance: this #NAIExporter instance.
- * @parms: a #NAIExporterBufferParms structure.
+ * @parms: a #NAIExporterBufferParmsv2 structure.
  *
  * Export the specified 'item' to a newly allocated buffer.
  */
 guint
-nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporterBufferParms *parms )
+nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporterBufferParmsv2 *parms )
 {
 	static const gchar *thisfn = "nadp_writer_iexporter_export_to_buffer";
 	guint code, write_code;
@@ -366,7 +370,16 @@ nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporter
 	}
 
 	if( code == NA_IEXPORTER_CODE_OK ){
+
+#ifdef NA_ENABLE_DEPRECATED
+		if( parms->version == 1 ){
+			fmt = find_export_format_fn_from_quark((( NAIExporterBufferParms * ) parms )->format );
+		} else {
+			fmt = find_export_format_fn( parms->format );
+		}
+#else
 		fmt = find_export_format_fn( parms->format );
+#endif
 
 		if( !fmt ){
 			code = NA_IEXPORTER_CODE_INVALID_FORMAT;
@@ -394,12 +407,12 @@ nadp_writer_iexporter_export_to_buffer( const NAIExporter *instance, NAIExporter
 /**
  * nadp_writer_iexporter_export_to_file:
  * @instance: this #NAIExporter instance.
- * @parms: a #NAIExporterFileParms structure.
+ * @parms: a #NAIExporterFileParmsv2 structure.
  *
  * Export the specified 'item' to a newly created file.
  */
 guint
-nadp_writer_iexporter_export_to_file( const NAIExporter *instance, NAIExporterFileParms *parms )
+nadp_writer_iexporter_export_to_file( const NAIExporter *instance, NAIExporterFileParmsv2 *parms )
 {
 	static const gchar *thisfn = "nadp_writer_iexporter_export_to_file";
 	guint code, write_code;
@@ -417,7 +430,16 @@ nadp_writer_iexporter_export_to_file( const NAIExporter *instance, NAIExporterFi
 	}
 
 	if( code == NA_IEXPORTER_CODE_OK ){
+
+#ifdef NA_ENABLE_DEPRECATED
+		if( parms->version == 1 ){
+			fmt = find_export_format_fn_from_quark((( NAIExporterFileParms * ) parms )->format );
+		} else {
+			fmt = find_export_format_fn( parms->format );
+		}
+#else
 		fmt = find_export_format_fn( parms->format );
+#endif
 
 		if( !fmt ){
 			code = NA_IEXPORTER_CODE_INVALID_FORMAT;
@@ -613,7 +635,27 @@ write_done_write_subitems_list( NadpDesktopFile *ndp, NAObjectItem *item )
 }
 
 static ExportFormatFn *
-find_export_format_fn( GQuark format )
+find_export_format_fn( const gchar *format )
+{
+	ExportFormatFn *found;
+	ExportFormatFn *i;
+
+	found = NULL;
+	i = st_export_format_fn;
+
+	while( i->format && !found ){
+		if( !strcmp( i->format, format )){
+			found = i;
+		}
+		i++;
+	}
+
+	return( found );
+}
+
+#ifdef NA_ENABLE_DEPRECATED
+static ExportFormatFn *
+find_export_format_fn_from_quark( GQuark format )
 {
 	ExportFormatFn *found;
 	ExportFormatFn *i;
@@ -630,3 +672,4 @@ find_export_format_fn( GQuark format )
 
 	return( found );
 }
+#endif
