@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -37,41 +36,41 @@
 #include <api/na-iimporter.h>
 
 #include "naxml-provider.h"
+#include "naxml-formats.h"
 #include "naxml-reader.h"
 #include "naxml-writer.h"
 
 /* private class data
  */
-struct NAXMLProviderClassPrivate {
+struct _NAXMLProviderClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAXMLProviderPrivate {
+struct _NAXMLProviderPrivate {
 	gboolean dispose_has_run;
 };
 
-extern NAIExporterFormat naxml_formats[];
-
 static GType         st_module_type = 0;
 static GObjectClass *st_parent_class = NULL;
 
-static void                     class_init( NAXMLProviderClass *klass );
-static void                     instance_init( GTypeInstance *instance, gpointer klass );
-static void                     instance_dispose( GObject *object );
-static void                     instance_finalize( GObject *object );
+static void   class_init( NAXMLProviderClass *klass );
+static void   instance_init( GTypeInstance *instance, gpointer klass );
+static void   instance_dispose( GObject *object );
+static void   instance_finalize( GObject *object );
 
-static void                     iimporter_iface_init( NAIImporterInterface *iface );
-static guint                    iimporter_get_version( const NAIImporter *importer );
+static void   iimporter_iface_init( NAIImporterInterface *iface );
+static guint  iimporter_get_version( const NAIImporter *importer );
 
-static void                     iexporter_iface_init( NAIExporterInterface *iface );
-static guint                    iexporter_get_version( const NAIExporter *exporter );
-static gchar                   *iexporter_get_name( const NAIExporter *exporter );
-static const NAIExporterFormat *iexporter_get_formats( const NAIExporter *exporter );
+static void   iexporter_iface_init( NAIExporterInterface *iface );
+static guint  iexporter_get_version( const NAIExporter *exporter );
+static gchar *iexporter_get_name( const NAIExporter *exporter );
+static void  *iexporter_get_formats( const NAIExporter *exporter );
+static void   iexporter_free_formats( const NAIExporter *exporter, GList *format_list );
 
-static void                     ifactory_provider_iface_init( NAIFactoryProviderInterface *iface );
-static guint                    ifactory_provider_get_version( const NAIFactoryProvider *factory );
+static void   ifactory_provider_iface_init( NAIFactoryProviderInterface *iface );
+static guint  ifactory_provider_get_version( const NAIFactoryProvider *factory );
 
 GType
 naxml_provider_get_type( void )
@@ -118,11 +117,11 @@ naxml_provider_register_type( GTypeModule *module )
 
 	st_module_type = g_type_module_register_type( module, G_TYPE_OBJECT, "NAXMLProvider", &info, 0 );
 
-	g_type_module_add_interface( module, st_module_type, NA_IIMPORTER_TYPE, &iimporter_iface_info );
+	g_type_module_add_interface( module, st_module_type, NA_TYPE_IIMPORTER, &iimporter_iface_info );
 
-	g_type_module_add_interface( module, st_module_type, NA_IEXPORTER_TYPE, &iexporter_iface_info );
+	g_type_module_add_interface( module, st_module_type, NA_TYPE_IEXPORTER, &iexporter_iface_info );
 
-	g_type_module_add_interface( module, st_module_type, NA_IFACTORY_PROVIDER_TYPE, &ifactory_provider_iface_info );
+	g_type_module_add_interface( module, st_module_type, NA_TYPE_IFACTORY_PROVIDER, &ifactory_provider_iface_info );
 }
 
 static void
@@ -148,9 +147,11 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	static const gchar *thisfn = "naxml_provider_instance_init";
 	NAXMLProvider *self;
 
+	g_return_if_fail( NA_IS_XML_PROVIDER( instance ));
+
 	g_debug( "%s: instance=%p (%s), klass=%p",
 			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-	g_return_if_fail( NA_IS_XML_PROVIDER( instance ));
+
 	self = NAXML_PROVIDER( instance );
 
 	self->private = g_new0( NAXMLProviderPrivate, 1 );
@@ -164,12 +165,14 @@ instance_dispose( GObject *object )
 	static const gchar *thisfn = "naxml_provider_instance_dispose";
 	NAXMLProvider *self;
 
-	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
 	g_return_if_fail( NA_IS_XML_PROVIDER( object ));
+
 	self = NAXML_PROVIDER( object );
 
 	if( !self->private->dispose_has_run ){
 
+		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 		self->private->dispose_has_run = TRUE;
 
 		/* chain up to the parent class */
@@ -182,9 +185,13 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
+	static const gchar *thisfn = "naxml_provider_instance_finalize";
 	NAXMLProvider *self;
 
-	g_assert( NA_IS_XML_PROVIDER( object ));
+	g_return_if_fail( NA_IS_XML_PROVIDER( object ));
+
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 	self = NAXML_PROVIDER( object );
 
 	g_free( self->private );
@@ -209,7 +216,7 @@ iimporter_iface_init( NAIImporterInterface *iface )
 static guint
 iimporter_get_version( const NAIImporter *importer )
 {
-	return( 1 );
+	return( 2 );
 }
 
 static void
@@ -222,6 +229,7 @@ iexporter_iface_init( NAIExporterInterface *iface )
 	iface->get_version = iexporter_get_version;
 	iface->get_name = iexporter_get_name;
 	iface->get_formats = iexporter_get_formats;
+	iface->free_formats = iexporter_free_formats;
 	iface->to_file = naxml_writer_export_to_file;
 	iface->to_buffer = naxml_writer_export_to_buffer;
 }
@@ -229,7 +237,7 @@ iexporter_iface_init( NAIExporterInterface *iface )
 static guint
 iexporter_get_version( const NAIExporter *exporter )
 {
-	return( 1 );
+	return( 2 );
 }
 
 static gchar *
@@ -238,10 +246,16 @@ iexporter_get_name( const NAIExporter *exporter )
 	return( g_strdup( "NAXML Exporter" ));
 }
 
-static const NAIExporterFormat *
+static void *
 iexporter_get_formats( const NAIExporter *exporter )
 {
-	return( naxml_formats );
+	return(( void * ) naxml_formats_get_formats( exporter ));
+}
+
+static void
+iexporter_free_formats( const NAIExporter *exporter, GList *format_list )
+{
+	naxml_formats_free_formats( format_list );
 }
 
 static void
