@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -74,25 +73,25 @@ typedef struct {
  * to import. We thus have one NAXMLReader object per import operation.
  */
 struct _NAXMLReaderPrivate {
-	gboolean                       dispose_has_run;
+	gboolean                         dispose_has_run;
 
 	/* data provided by the caller
 	 */
-	NAIImporter                   *importer;
-	NAIImporterImportFromUriParms *parms;
+	NAIImporter                     *importer;
+	NAIImporterImportFromUriParmsv2 *parms;
 
 	/* data dynamically set during the import operation
 	 */
-	gboolean                       type_found;
-	GList                         *nodes;
-	GList                         *dealt;
-	RootNodeStr                   *root_node_str;
-	gchar                         *item_id;
+	gboolean                         type_found;
+	GList                           *nodes;
+	GList                           *dealt;
+	RootNodeStr                     *root_node_str;
+	gchar                           *item_id;
 
 	/* following values are reset and reused while iterating on each
 	 * element nodes of the imported item (cf. reset_node_data())
 	 */
-	gboolean                       node_ok;
+	gboolean                         node_ok;
 };
 
 extern NAXMLKeyStr naxml_schema_key_schema_str[];
@@ -152,9 +151,7 @@ static RootNodeStr st_root_node_str[] = {
 #define ERR_NODE_UNKNOWN			_( "Unknown element %s found at line %d while waiting for %s." )
 /* i18n: do not translate keywords 'Action' nor 'Menu' */
 #define ERR_NODE_UNKNOWN_TYPE		_( "Unknown type %s found at line %d, while waiting for Action or Menu." )
-#define ERR_ROOT_UNKNOWN			_( "Invalid XML root element %s found at line %d while waiting for %s." )
-#define ERR_XMLDOC_UNABLE_TOPARSE	_( "Unable to parse XML file: %s." )
-#define WARN_UNDEALT_NODE			_( "Node %s at line %d has not been dealt with." )
+#define ERR_NOT_IOXML				_( "The XML I/O Provider is not able to handle the URI" )
 
 static void          read_start_profile_attach_profile( NAXMLReader *reader, NAObjectProfile *profile );
 static gboolean      read_data_is_path_adhoc_for_object( NAXMLReader *reader, const NAIFactoryObject *object, xmlChar *text );
@@ -175,8 +172,6 @@ static gchar        *build_root_node_list( void );
 static gchar        *get_value_from_child_node( xmlNode *node, const gchar *child );
 static gchar        *get_value_from_child_child_node( xmlNode *node, const gchar *first, const gchar *second );
 static gboolean      is_profile_path( NAXMLReader *reader, xmlChar *text );
-static guint         manage_import_mode( NAXMLReader *reader );
-static void          publish_undealt_nodes( NAXMLReader *reader );
 static void          reset_node_data( NAXMLReader *reader );
 static xmlNode      *search_for_child_node( xmlNode *node, const gchar *key );
 static int           strxcmp( const xmlChar *a, const char *b );
@@ -311,57 +306,70 @@ reader_new( void )
 /**
  * naxml_reader_import_uri:
  * @instance: the #NAIImporter provider.
- * @parms: a #NAIImporterUriParms structure.
+ * @parms: a #NAIImporterImportFromUriParmsv2 structure.
  *
  * Imports an item.
  *
  * Returns: the import operation code.
+ *
+ * If we do not found at least a well-formed XML document with a known root node,
+ *  then we do not return any error message at all, but just the 'unwilling to'
+ *  code.
+ *
+ * Starting with N-A 3.2, we only honor the version 2 of #NAIImporter interface,
+ * thus no more checking here against possible duplicate identifiers.
  */
 guint
-naxml_reader_import_from_uri( const NAIImporter *instance, NAIImporterImportFromUriParms *parms )
+naxml_reader_import_from_uri( const NAIImporter *instance, void *parms_ptr )
 {
 	static const gchar *thisfn = "naxml_reader_import_from_uri";
 	NAXMLReader *reader;
+	NAIImporterImportFromUriParmsv2* parms;
 	guint code;
 
-	g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, ( void * ) parms );
+	g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, parms_ptr );
 
 	g_return_val_if_fail( NA_IS_IIMPORTER( instance ), IMPORTER_CODE_PROGRAM_ERROR );
 
+	parms = ( NAIImporterImportFromUriParmsv2 * ) parms_ptr;
+	parms->imported = NULL;
+
+	if( !na_core_utils_file_is_loadable( parms->uri )){
+		return( IMPORTER_CODE_NOT_LOADABLE );
+	}
+
 	reader = reader_new();
 	reader->private->importer = ( NAIImporter * ) instance;
 	reader->private->parms = parms;
 
-	parms->exist = FALSE;
-	parms->import_mode = IMPORTER_MODE_NO_IMPORT;
-	parms->imported = NULL;
-
 	code = reader_parse_xmldoc( reader );
 
-	if( code == IMPORTER_CODE_OK ){
-		g_return_val_if_fail( NA_IS_OBJECT_ITEM( reader->private->parms->imported ), IMPORTER_CODE_PROGRAM_ERROR );
-		code = manage_import_mode( reader );
-	}
-
-	if( code != IMPORTER_CODE_OK ){
-		if( reader->private->parms->imported ){
-			g_object_unref( reader->private->parms->imported );
-			reader->private->parms->imported = NULL;
-		}
-	}
-
-	if( code == IMPORTER_CODE_OK ){
-		publish_undealt_nodes( reader );
+	if( code == IMPORTER_CODE_NOT_WILLING_TO ){
+		na_core_utils_slist_add_message( &reader->private->parms->messages, ERR_NOT_IOXML );
 	}
 
 	g_object_unref( reader );
 
+	if( code == IMPORTER_CODE_OK ){
+		na_object_dump( parms->imported );
+
+	} else if( parms->imported ){
+		g_object_unref( parms->imported );
+		parms->imported = NULL;
+	}
+
 	return( code );
 }
 
 /*
- * check that the file is a valid XML document
+ * This is only used when trying to import an item from an URI.
+ *
+ * Check that the file is a valid XML document
  * and that the root node can be identified as a schema or a dump
+ *
+ * At import time, it is worthless to say that there is, e.g. a badly formed
+ * xml file, as we are not even sure that we are trying to import a .xml.
+ * So just keep ride of error messages here.
  */
 static guint
 reader_parse_xmldoc( NAXMLReader *reader )
@@ -374,8 +382,6 @@ reader_parse_xmldoc( NAXMLReader *reader )
 
 	if( !doc ){
 		xmlErrorPtr error = xmlGetLastError();
-		na_core_utils_slist_add_message( &reader->private->parms->messages,
-				ERR_XMLDOC_UNABLE_TOPARSE, error->message );
 		xmlResetError( error );
 		code = IMPORTER_CODE_NOT_WILLING_TO;
 
@@ -396,10 +402,9 @@ reader_parse_xmldoc( NAXMLReader *reader )
 
 		if( !found ){
 			gchar *node_list = build_root_node_list();
-			na_core_utils_slist_add_message( &reader->private->parms->messages,
-						ERR_ROOT_UNKNOWN,
-						( const char * ) root_node->name, root_node->line, node_list );
 			g_free( node_list );
+			na_core_utils_slist_free( reader->private->parms->messages );
+			reader->private->parms->messages = NULL;
 			code = IMPORTER_CODE_NOT_WILLING_TO;
 		}
 
@@ -411,9 +416,18 @@ reader_parse_xmldoc( NAXMLReader *reader )
 }
 
 /*
- * parse a XML tree
+ * Parse an XML tree when importing an URI.
+ *
+ * We are almost sure here that the imported file is a well-formed XML
+ * document, with a known root document node. Starting from here,we should
+ * no more return a 'unwilling to' code, but an error one.
+ *
+ * Check that:
  * - must have one child on the named 'first_child' key (others are warned)
- * - then iter on child nodes of this previous first named which must ne 'next_child'
+ * - then iter on child nodes of this previous first named which must be
+ * 'next_child'
+ * e.g. for a <gconfentryfile> root node, we must have one and only one
+ * <entrylist> child.
  */
 static guint
 iter_on_root_children( NAXMLReader *reader, xmlNode *root )
@@ -463,6 +477,8 @@ iter_on_root_children( NAXMLReader *reader, xmlNode *root )
 }
 
 /*
+ * Parse an XML tree when importing an URI.
+ *
  * iter on 'schema/entry' element nodes
  * each node should correspond to an elementary data of the imported item
  * other nodes are warned (and ignored)
@@ -545,12 +561,12 @@ iter_on_list_children( NAXMLReader *reader, xmlNode *list )
 		}
 	}
 
-	/* check that we have a not empty id
+	/* if we do not have any error, check that we have at least a not empty id
 	 */
 	if( code == IMPORTER_CODE_OK ){
 		if( !reader->private->item_id || !strlen( reader->private->item_id )){
 			na_core_utils_slist_add_message( &reader->private->parms->messages, ERR_ITEM_ID_NOT_FOUND );
-			code = 	IMPORTER_CODE_NO_ITEM_ID;
+			code = IMPORTER_CODE_NO_ITEM_ID;
 		}
 	}
 
@@ -807,8 +823,10 @@ read_done_item_set_localized_icon( NAXMLReader *reader, NAObjectItem *item )
 static void
 read_done_action_read_profiles( NAXMLReader *reader, NAObjectAction *action )
 {
+	static const gchar *thisfn = "naxml_reader_read_done_action_read_profiles";
 	GSList *order, *ip;
 	gchar *profile_id;
+	NAObjectProfile *profile;
 
 	if( !na_object_get_items_count( reader->private->parms->imported )){
 
@@ -833,6 +851,14 @@ read_done_action_read_profiles( NAXMLReader *reader, NAObjectAction *action )
 			}
 		}
 	}
+
+	/* make sure we have at least one profile attached to the action
+	 */
+	if( !na_object_get_items_count( action )){
+		g_warning( "%s: no profile found in .xml file", thisfn );
+		profile = na_object_profile_new_with_defaults();
+		na_object_attach_profile( action, profile );
+	}
 }
 
 /*
@@ -879,7 +905,7 @@ read_done_action_load_profile( NAXMLReader *reader, const gchar *profile_id )
 {
 	/*g_debug( "naxml_reader_read_done_action_load_profile: profile_id=%s", profile_id );*/
 
-	NAObjectProfile *profile = na_object_profile_new();
+	NAObjectProfile *profile = na_object_profile_new_with_defaults();
 
 	na_object_set_id( profile, profile_id );
 
@@ -968,12 +994,13 @@ schema_parse_schema_content( NAXMLReader *reader, xmlNode *schema )
 		str->reader_found = TRUE;
 
 		/* set the item id the first time, check after
+		 * - until v 2.0 of the exported schemas, both <key> and <applyto>
+		 *   has the id of the item (because there was one fake schema for
+		 *   each item)
+		 * - starting with v 3, only <applyto> key has this id
 		 */
-		if( !strxcmp( iter->name, NAXML_KEY_SCHEMA_NODE_KEY ) ||
-			!strxcmp( iter->name, NAXML_KEY_SCHEMA_NODE_APPLYTO )){
-
+		if( !strxcmp( iter->name, NAXML_KEY_SCHEMA_NODE_APPLYTO )){
 			schema_check_for_id( reader, iter );
-
 			if( !reader->private->node_ok ){
 				continue;
 			}
@@ -982,9 +1009,7 @@ schema_parse_schema_content( NAXMLReader *reader, xmlNode *schema )
 		/* search for the type of the item
 		 */
 		if( !strxcmp( iter->name, NAXML_KEY_SCHEMA_NODE_APPLYTO )){
-
 			schema_check_for_type( reader, iter );
-
 			if( !reader->private->node_ok ){
 				continue;
 			}
@@ -995,7 +1020,7 @@ schema_parse_schema_content( NAXMLReader *reader, xmlNode *schema )
 }
 
 /*
- * check the id on 'key' and 'applyto' keys
+ * check the id on 'applyto' key
  */
 static void
 schema_check_for_id( NAXMLReader *reader, xmlNode *iter )
@@ -1183,7 +1208,7 @@ dump_check_for_type( NAXMLReader *reader, xmlNode *key_node )
 }
 
 /*
- * string list is converted to GSList, then to a GConf string
+ * string list is converted to GSList, then to a NABoxed string list 'value;value'
  */
 static gchar *
 dump_read_value( NAXMLReader *reader, xmlNode *node, const NADataDef *def )
@@ -1240,24 +1265,25 @@ dump_read_value( NAXMLReader *reader, xmlNode *node, const NADataDef *def )
 	return( string );
 }
 
+/*
+ * NABoxed accepts a string list as a semi-comma-separated list of strings
+ */
 static gchar *
 slist_to_string( GSList *slist )
 {
 	GSList *is;
-	GString *str = g_string_new( "[" );
+	GString *str = g_string_new( "" );
 	gboolean first;
 
 	first = TRUE;
 	for( is = slist ; is ; is = is->next ){
 		if( !first ){
-			str = g_string_append( str, "," );
+			str = g_string_append( str, ";" );
 		}
 		str = g_string_append( str, ( const gchar * ) is->data );
 		first = FALSE;
 	}
 
-	str = g_string_append( str, "]" );
-
 	return( g_string_free( str, FALSE ));
 }
 
@@ -1363,50 +1389,6 @@ is_profile_path( NAXMLReader *reader, xmlChar *text )
 	return( is_profile );
 }
 
-static guint
-manage_import_mode( NAXMLReader *reader )
-{
-	NAIImporterManageImportModeParms parms;
-	guint code;
-
-	parms.version = 1;
-	parms.imported = reader->private->parms->imported;
-	parms.check_fn = reader->private->parms->check_fn;
-	parms.check_fn_data = reader->private->parms->check_fn_data;
-	parms.ask_fn = reader->private->parms->ask_fn;
-	parms.ask_fn_data = reader->private->parms->ask_fn_data;
-	parms.asked_mode = reader->private->parms->asked_mode;
-	parms.messages = reader->private->parms->messages;
-
-	code = na_iimporter_manage_import_mode( &parms );
-
-	reader->private->parms->exist = parms.exist;
-	reader->private->parms->import_mode = parms.import_mode;
-
-	return( code );
-}
-
-static void
-publish_undealt_nodes( NAXMLReader *reader )
-{
-	GList *iter;
-	xmlChar *text;
-
-	g_debug( "naxml_reader_publish_undealt_nodes: count=%d", g_list_length( reader->private->nodes ));
-
-	for( iter = reader->private->nodes ; iter ; iter = iter->next ){
-		xmlNode *node = ( xmlNode * ) iter->data;
-
-		if( !g_list_find( reader->private->dealt, node )){
-			text = xmlNodeGetContent( node );
-			g_debug( "test=%s, line=%d", ( const gchar * ) text, node->line );
-			na_core_utils_slist_add_message(
-					&reader->private->parms->messages, WARN_UNDEALT_NODE, ( const gchar * ) text, node->line );
-			xmlFree( text );
-		}
-	}
-}
-
 /*
  * data are reset before first run on nodes for an item
  */
