@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -115,8 +114,14 @@ static void            write_data_dump_element( NAXMLWriter *writer, const NADat
 static void            write_type_dump( NAXMLWriter *writer, const NAObjectItem *object, const NADataDef *def, const gchar *value );
 
 static xmlDocPtr       build_xml_doc( NAXMLWriter *writer );
-static ExportFormatFn *find_export_format_fn( GQuark format );
-static gchar          *get_output_fname( const NAObjectItem *item, const gchar *folder, GQuark format );
+static gchar          *convert_to_gconf_slist( const gchar *str );
+static ExportFormatFn *find_export_format_fn( const gchar *format );
+
+#ifdef NA_ENABLE_DEPRECATED
+static ExportFormatFn *find_export_format_fn_from_quark( GQuark format );
+#endif
+
+static gchar          *get_output_fname( const NAObjectItem *item, const gchar *folder, const gchar *format );
 static void            output_xml_to_file( const gchar *xml, const gchar *filename, GSList **msg );
 static guint           writer_to_buffer( NAXMLWriter *writer );
 
@@ -262,12 +267,12 @@ instance_finalize( GObject *object )
 /**
  * naxml_writer_export_to_buffer:
  * @instance: this #NAIExporter instance.
- * @parms: a #NAIExporterBufferParms structure.
+ * @parms: a #NAIExporterBufferParmsv2 structure.
  *
  * Export the specified 'item' to a newly allocated buffer.
  */
 guint
-naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferParms *parms )
+naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferParmsv2 *parms )
 {
 	static const gchar *thisfn = "naxml_writer_export_to_buffer";
 	NAXMLWriter *writer;
@@ -287,7 +292,15 @@ naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferPar
 		writer->private->provider = ( NAIExporter * ) instance;
 		writer->private->exported = parms->exported;
 		writer->private->messages = parms->messages;
+#ifdef NA_ENABLE_DEPRECATED
+		if( parms->version == 1 ){
+			writer->private->fn_str = find_export_format_fn_from_quark((( NAIExporterBufferParms * ) parms )->format );
+		} else {
+			writer->private->fn_str = find_export_format_fn( parms->format );
+		}
+#else
 		writer->private->fn_str = find_export_format_fn( parms->format );
+#endif
 		writer->private->buffer = NULL;
 
 		if( !writer->private->fn_str ){
@@ -310,17 +323,18 @@ naxml_writer_export_to_buffer( const NAIExporter *instance, NAIExporterBufferPar
 /**
  * naxml_writer_export_to_file:
  * @instance: this #NAIExporter instance.
- * @parms: a #NAIExporterFileParms structure.
+ * @parms: a #NAIExporterFileParmsv2 structure.
  *
  * Export the specified 'item' to a newly created file.
  */
 guint
-naxml_writer_export_to_file( const NAIExporter *instance, NAIExporterFileParms *parms )
+naxml_writer_export_to_file( const NAIExporter *instance, NAIExporterFileParmsv2 *parms )
 {
 	static const gchar *thisfn = "naxml_writer_export_to_file";
 	NAXMLWriter *writer;
 	gchar *filename;
 	guint code;
+	const gchar *format2;
 
 	g_debug( "%s: instance=%p, parms=%p", thisfn, ( void * ) instance, ( void * ) parms );
 
@@ -336,7 +350,18 @@ naxml_writer_export_to_file( const NAIExporter *instance, NAIExporterFileParms *
 		writer->private->provider = ( NAIExporter * ) instance;
 		writer->private->exported = parms->exported;
 		writer->private->messages = parms->messages;
+#ifdef NA_ENABLE_DEPRECATED
+		if( parms->version == 1 ){
+			writer->private->fn_str = find_export_format_fn_from_quark((( NAIExporterFileParms * ) parms )->format );
+			format2 = g_quark_to_string((( NAIExporterFileParms * ) parms )->format );
+		} else {
+			writer->private->fn_str = find_export_format_fn( parms->format );
+			format2 = parms->format;
+		}
+#else
 		writer->private->fn_str = find_export_format_fn( parms->format );
+		format2 = parms->format;
+#endif
 		writer->private->buffer = NULL;
 
 		if( !writer->private->fn_str ){
@@ -346,7 +371,7 @@ naxml_writer_export_to_file( const NAIExporter *instance, NAIExporterFileParms *
 			code = writer_to_buffer( writer );
 
 			if( code == NA_IEXPORTER_CODE_OK ){
-				filename = get_output_fname( parms->exported, parms->folder, parms->format );
+				filename = get_output_fname( parms->exported, parms->folder, format2 );
 
 				if( filename ){
 					parms->basename = g_path_get_basename( filename );
@@ -520,13 +545,23 @@ write_data_schema_v2( NAXMLWriter *writer, const NAObjectId *object, const NADat
 {
 	gchar *object_id;
 	gchar *value_str;
+	gchar *tmp;
 
 	value_str = na_boxed_get_string( NA_BOXED( boxed ));
 
 	/* boolean value must be lowercase
 	 */
 	if( def->type == NA_DATA_TYPE_BOOLEAN ){
-		gchar *tmp = g_ascii_strdown( value_str, -1 );
+		tmp = g_ascii_strdown( value_str, -1 );
+		g_free( value_str );
+		value_str = tmp;
+	}
+
+	/* string or uint list value must be converted to gconf format
+	 * comma-separated and enclosed within square brackets
+	 */
+	if( def->type == NA_DATA_TYPE_STRING_LIST || def->type == NA_DATA_TYPE_UINT_LIST ){
+		tmp = convert_to_gconf_slist( value_str );
 		g_free( value_str );
 		value_str = tmp;
 	}
@@ -622,13 +657,23 @@ write_data_dump( NAXMLWriter *writer, const NAObjectId *object, const NADataBoxe
 {
 	gchar *entry;
 	gchar *value_str;
+	gchar *tmp;
 
 	value_str = na_boxed_get_string( NA_BOXED( boxed ));
 
 	/* boolean value must be lowercase
 	 */
 	if( def->type == NA_DATA_TYPE_BOOLEAN ){
-		gchar *tmp = g_ascii_strdown( value_str, -1 );
+		tmp = g_ascii_strdown( value_str, -1 );
+		g_free( value_str );
+		value_str = tmp;
+	}
+
+	/* string or uint list value must be converted to gconf format
+	 * comma-separated and enclosed within square brackets
+	 */
+	if( def->type == NA_DATA_TYPE_STRING_LIST || def->type == NA_DATA_TYPE_UINT_LIST ){
+		tmp = convert_to_gconf_slist( value_str );
 		g_free( value_str );
 		value_str = tmp;
 	}
@@ -689,8 +734,56 @@ write_type_dump( NAXMLWriter *writer, const NAObjectItem *object, const NADataDe
 	write_data_dump_element( writer, def, NULL, def->gconf_entry, value );
 }
 
+/*
+ * we have here a string list as "value; value;"
+ * we want "[value, value]"
+ */
+static gchar *
+convert_to_gconf_slist( const gchar *slist_str )
+{
+	GSList *values;
+	GSList *is;
+	gboolean first;
+	GString *str = g_string_new( "[" );
+
+	values = na_core_utils_slist_from_split( slist_str, ";" );
+	first = TRUE;
+
+	for( is = values ; is ; is = is->next ){
+		if( !first ){
+			str = g_string_append( str, "," );
+		}
+		str = g_string_append( str, ( const gchar * ) is->data );
+		first = FALSE;
+	}
+
+	str = g_string_append( str, "]" );
+
+	return( g_string_free( str, FALSE ));
+}
+
 static ExportFormatFn *
-find_export_format_fn( GQuark format )
+find_export_format_fn( const gchar *format )
+{
+	ExportFormatFn *found;
+	ExportFormatFn *i;
+
+	found = NULL;
+	i = st_export_format_fn;
+
+	while( i->format && !found ){
+		if( !strcmp( i->format, format )){
+			found = i;
+		}
+		i++;
+	}
+
+	return( found );
+}
+
+#ifdef NA_ENABLE_DEPRECATED
+static ExportFormatFn *
+find_export_format_fn_from_quark( GQuark format )
 {
 	ExportFormatFn *found;
 	ExportFormatFn *i;
@@ -707,6 +800,7 @@ find_export_format_fn( GQuark format )
 
 	return( found );
 }
+#endif
 
 /*
  * get_output_fname:
@@ -726,7 +820,7 @@ find_export_format_fn( GQuark format )
  * between our test of inexistance and the actual write.
  */
 static gchar *
-get_output_fname( const NAObjectItem *item, const gchar *folder, GQuark format )
+get_output_fname( const NAObjectItem *item, const gchar *folder, const gchar *format )
 {
 	static const gchar *thisfn = "naxml_writer_get_output_fname";
 	gchar *item_id;
@@ -741,20 +835,20 @@ get_output_fname( const NAObjectItem *item, const gchar *folder, GQuark format )
 
 	item_id = na_object_get_id( item );
 
-	if( format == g_quark_from_string( NAXML_FORMAT_GCONF_SCHEMA_V1 )){
+	if( !strcmp( format, NAXML_FORMAT_GCONF_SCHEMA_V1 )){
 		canonical_fname = g_strdup_printf( "config_%s", item_id );
 		canonical_ext = g_strdup( "schemas" );
 
-	} else if( format == g_quark_from_string( NAXML_FORMAT_GCONF_SCHEMA_V2 )){
+	} else if( !strcmp( format, NAXML_FORMAT_GCONF_SCHEMA_V2 )){
 		canonical_fname = g_strdup_printf( "config-%s", item_id );
 		canonical_ext = g_strdup( "schema" );
 
-	} else if( format == g_quark_from_string( NAXML_FORMAT_GCONF_ENTRY )){
+	} else if( !strcmp( format, NAXML_FORMAT_GCONF_ENTRY )){
 		canonical_fname = g_strdup_printf( "%s-%s", NA_IS_OBJECT_ACTION( item ) ? "action" : "menu", item_id );
 		canonical_ext = g_strdup( "xml" );
 
 	} else {
-		g_warning( "%s: unknown format: %s", thisfn, g_quark_to_string( format ));
+		g_warning( "%s: unknown format: %s", thisfn, format );
 	}
 
 	g_free( item_id );
