@@ -1,25 +1,24 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -38,13 +37,13 @@
 
 /* private class data
  */
-struct BaseBuilderClassPrivate {
+struct _BaseBuilderClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct BaseBuilderPrivate {
+struct _BaseBuilderPrivate {
 	gboolean  dispose_has_run;
 	GSList   *fnames;
 };
@@ -55,8 +54,8 @@ static GType    register_type( void );
 static void     class_init( BaseBuilderClass *klass );
 static void     instance_init( GTypeInstance *instance, gpointer klass );
 static void     instance_dispose( GObject *application );
+static void     free_built_object( GObject *object, gpointer user_data );
 static void     instance_finalize( GObject *application );
-
 static gboolean already_loaded( BaseBuilder *builder, const gchar *filename );
 
 GType
@@ -119,10 +118,11 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	static const gchar *thisfn = "base_builder_instance_init";
 	BaseBuilder *self;
 
+	g_return_if_fail( BASE_IS_BUILDER( instance ));
+
 	g_debug( "%s: instance=%p (%s), klass=%p",
 			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 
-	g_return_if_fail( BASE_IS_BUILDER( instance ));
 	self = BASE_BUILDER( instance );
 
 	self->private = g_new0( BaseBuilderPrivate, 1 );
@@ -135,13 +135,20 @@ instance_dispose( GObject *instance )
 {
 	static const gchar *thisfn = "base_builder_instance_dispose";
 	BaseBuilder *self;
+	GSList *objects;
 
-	g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 	g_return_if_fail( BASE_IS_BUILDER( instance ));
+
 	self = BASE_BUILDER( instance );
 
 	if( !self->private->dispose_has_run ){
 
+		g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
+
+		objects = gtk_builder_get_objects( GTK_BUILDER( instance ));
+		g_slist_foreach( objects, ( GFunc ) free_built_object, NULL );
+		g_slist_free( objects );
+
 		self->private->dispose_has_run = TRUE;
 
 		/* chain up to the parent class */
@@ -152,14 +159,33 @@ instance_dispose( GObject *instance )
 }
 
 static void
-instance_finalize( GObject *window )
+free_built_object( GObject *object, gpointer user_data )
+{
+	static const gchar *thisfn = "base_builder_free_built_object";
+
+	if( GTK_IS_WIDGET( object )){
+		if( gtk_widget_is_toplevel( GTK_WIDGET( object ))){
+
+			g_debug( "%s: object=%p (%s) %s", thisfn,
+					( void * ) object, G_OBJECT_TYPE_NAME( object ),
+					gtk_buildable_get_name( GTK_BUILDABLE( object )));
+
+			gtk_widget_destroy( GTK_WIDGET( object ));
+		}
+	}
+}
+
+static void
+instance_finalize( GObject *instance )
 {
 	static const gchar *thisfn = "base_builder_instance_finalize";
 	BaseBuilder *self;
 
-	g_debug( "%s: window=%p", thisfn, ( void * ) window );
-	g_return_if_fail( BASE_IS_BUILDER( window ));
-	self = BASE_BUILDER( window );
+	g_return_if_fail( BASE_IS_BUILDER( instance ));
+
+	g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
+
+	self = BASE_BUILDER( instance );
 
 	na_core_utils_slist_free( self->private->fnames );
 
@@ -167,7 +193,7 @@ instance_finalize( GObject *window )
 
 	/* chain call to parent class */
 	if( G_OBJECT_CLASS( st_parent_class )->finalize ){
-		G_OBJECT_CLASS( st_parent_class )->finalize( window );
+		G_OBJECT_CLASS( st_parent_class )->finalize( instance );
 	}
 }
 
@@ -181,7 +207,7 @@ base_builder_new( void )
 {
 	BaseBuilder *builder;
 
-	builder = g_object_new( BASE_BUILDER_TYPE, NULL );
+	builder = g_object_new( BASE_TYPE_BUILDER, NULL );
 
 	return( builder );
 }
@@ -190,12 +216,12 @@ base_builder_new( void )
  * base_builder_add_from_file:
  * @builder: this #BaseBuilder object.
  * @filename: the filename to load.
- * @error: a #GError whilch will be allocated if an error occurs.
+ * @error: a #GError which will be allocated if an error occurs.
  *
  * Loads the file into the GtkBuilder, taking care of not loading it
  * twice.
  *
- * Returns: %TRUE if filename has been successfully loaded, or were
+ * Returns: %TRUE if filename has been successfully loaded, or was
  * already loaded, %FALSE else.
  */
 gboolean
@@ -225,39 +251,6 @@ base_builder_add_from_file( BaseBuilder *builder, const gchar *filename, GError
 	return( ret );
 }
 
-/**
- * base_builder_load_named_toplevel:
- * @builder: this #BaseBuilder object.
- * @name: the name of the searched toplevel window.
- *
- * This function provides a pointer to the toplevel dialog associated
- * with the specified #BaseWindow.
- *
- * Returns: a pointer to the named dialog, or NULL.
- * This pointer is owned by GtkBuilder instance, and must not be
- * g_free() nor g_object_unref() by the caller.
- */
-GtkWindow *
-base_builder_load_named_toplevel( BaseBuilder *builder, const gchar *name )
-{
-	GtkWindow *toplevel = NULL;
-
-	g_return_val_if_fail( BASE_IS_BUILDER( builder ), NULL );
-	g_return_val_if_fail( name, NULL );
-	g_return_val_if_fail( g_utf8_strlen( name, -1 ), NULL );
-
-	if( !builder->private->dispose_has_run ){
-
-		toplevel = GTK_WINDOW( gtk_builder_get_object( GTK_BUILDER( builder ), name ));
-
-		if( toplevel ){
-			g_return_val_if_fail( GTK_IS_WINDOW( toplevel ), NULL );
-		}
-	}
-
-	return( toplevel );
-}
-
 static gboolean
 already_loaded( BaseBuilder *builder, const gchar *filename )
 {
@@ -272,3 +265,39 @@ already_loaded( BaseBuilder *builder, const gchar *filename )
 
 	return( loaded );
 }
+
+/**
+ * base_builder_get_toplevel_by_name:
+ * @builder: this #BaseBuilder object.
+ * @name: the name of the searched toplevel window.
+ *
+ * This function provides a pointer to the toplevel window associated
+ * with the specified @name.
+ *
+ * Returns: a pointer to the named window, or %NULL.
+ * This pointer is owned by GtkBuilder instance, and must not be
+ * g_free() nor g_object_unref() by the caller.
+ */
+GtkWindow *
+base_builder_get_toplevel_by_name( const BaseBuilder *builder, const gchar *name )
+{
+	static const gchar *thisfn = "base_builder_get_toplevel_by_name";
+	GtkWindow *toplevel = NULL;
+
+	g_return_val_if_fail( BASE_IS_BUILDER( builder ), NULL );
+	g_return_val_if_fail( name, NULL );
+	g_return_val_if_fail( g_utf8_strlen( name, -1 ), NULL );
+
+	if( !builder->private->dispose_has_run ){
+
+		toplevel = GTK_WINDOW( gtk_builder_get_object( GTK_BUILDER( builder ), name ));
+
+		if( toplevel ){
+			g_return_val_if_fail( GTK_IS_WINDOW( toplevel ), NULL );
+		} else {
+			na_core_utils_slist_dump( thisfn, builder->private->fnames );
+		}
+	}
+
+	return( toplevel );
+}
