@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -45,7 +44,7 @@
  *    <key>/schemas/apps/nautilus-actions/..../uuid/label</key>
  *    <applyto>/apps/..../label</applyto>
  *
- * I don't know why Frederic had choosen to export as schema. But this
+ * I don't know why Frederic had chosen to export as schema. But this
  * implies that :
  * - if all actions are imported via gconftool-2 --install-schema-file,
  *   then the schema will be repeated once for each imported action (as
@@ -66,24 +65,26 @@
 
 G_BEGIN_DECLS
 
-#define NACT_ASSISTANT_EXPORT_TYPE					( nact_assistant_export_get_type())
-#define NACT_ASSISTANT_EXPORT( object )				( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_ASSISTANT_EXPORT_TYPE, NactAssistantExport ))
-#define NACT_ASSISTANT_EXPORT_CLASS( klass )		( G_TYPE_CHECK_CLASS_CAST( klass, NACT_ASSISTANT_EXPORT_TYPE, NactAssistantExportClass ))
-#define NACT_IS_ASSISTANT_EXPORT( object )			( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_ASSISTANT_EXPORT_TYPE ))
-#define NACT_IS_ASSISTANT_EXPORT_CLASS( klass )		( G_TYPE_CHECK_CLASS_TYPE(( klass ), NACT_ASSISTANT_EXPORT_TYPE ))
-#define NACT_ASSISTANT_EXPORT_GET_CLASS( object )	( G_TYPE_INSTANCE_GET_CLASS(( object ), NACT_ASSISTANT_EXPORT_TYPE, NactAssistantExportClass ))
+#define NACT_TYPE_ASSISTANT_EXPORT                ( nact_assistant_export_get_type())
+#define NACT_ASSISTANT_EXPORT( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_TYPE_ASSISTANT_EXPORT, NactAssistantExport ))
+#define NACT_ASSISTANT_EXPORT_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NACT_TYPE_ASSISTANT_EXPORT, NactAssistantExportClass ))
+#define NACT_IS_ASSISTANT_EXPORT( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_TYPE_ASSISTANT_EXPORT ))
+#define NACT_IS_ASSISTANT_EXPORT_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NACT_TYPE_ASSISTANT_EXPORT ))
+#define NACT_ASSISTANT_EXPORT_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NACT_TYPE_ASSISTANT_EXPORT, NactAssistantExportClass ))
 
-typedef struct NactAssistantExportPrivate      NactAssistantExportPrivate;
+typedef struct _NactAssistantExportPrivate        NactAssistantExportPrivate;
 
 typedef struct {
+	/*< private >*/
 	BaseAssistant               parent;
 	NactAssistantExportPrivate *private;
 }
 	NactAssistantExport;
 
-typedef struct NactAssistantExportClassPrivate NactAssistantExportClassPrivate;
+typedef struct _NactAssistantExportClassPrivate   NactAssistantExportClassPrivate;
 
 typedef struct {
+	/*< private >*/
 	BaseAssistantClass               parent;
 	NactAssistantExportClassPrivate *private;
 }
