@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -39,7 +38,6 @@
 
 #include <core/na-exporter.h>
 #include <core/na-export-format.h>
-#include <core/na-iprefs.h>
 
 #include "nact-application.h"
 #include "nact-export-ask.h"
@@ -265,7 +263,7 @@ nact_clipboard_new( BaseWindow *window )
 
 	g_return_val_if_fail( BASE_IS_WINDOW( window ), NULL );
 
-	clipboard = g_object_new( NACT_CLIPBOARD_TYPE, NULL );
+	clipboard = g_object_new( NACT_TYPE_CLIPBOARD, NULL );
 
 	clipboard->private->window = window;
 
@@ -287,7 +285,6 @@ nact_clipboard_dnd_set( NactClipboard *clipboard, guint target, GList *rows, con
 {
 	static const gchar *thisfn = "nact_clipboard_dnd_set";
 	NactClipboardDndData *data;
-	GtkTreeModel *model;
 	GList *it;
 
 	g_return_if_fail( NACT_IS_CLIPBOARD( clipboard ));
@@ -302,8 +299,6 @@ nact_clipboard_dnd_set( NactClipboard *clipboard, guint target, GList *rows, con
 		data->rows = NULL;
 		data->copy = copy_data;
 
-		model = gtk_tree_row_reference_get_model(( GtkTreeRowReference * ) rows->data );
-
 		for( it = rows ; it ; it = it->next ){
 			data->rows = g_list_append(
 					data->rows,
@@ -337,7 +332,6 @@ nact_clipboard_dnd_get_data( NactClipboard *clipboard, gboolean *copy_data )
 	GList *rows = NULL;
 	GtkSelectionData *selection;
 	NactClipboardDndData *data;
-	GtkTreeModel *model;
 	GList *it;
 
 	g_debug( "%s: clipboard=%p", thisfn, ( void * ) clipboard );
@@ -351,19 +345,9 @@ nact_clipboard_dnd_get_data( NactClipboard *clipboard, gboolean *copy_data )
 
 		selection = gtk_clipboard_wait_for_contents( clipboard->private->dnd, NACT_CLIPBOARD_NACT_ATOM );
 		if( selection ){
-
-/* gtk_selection_data_get_data() appears with Gtk+ 2.14.0 release on 2008-09-04
- * see http://git.gnome.org/browse/gtk+/commit/?id=9eae7a1d2e7457d67ba00bb8c35775c1523fa186
- */
-#if GTK_CHECK_VERSION( 2, 14, 0 )
 			data = ( NactClipboardDndData * ) gtk_selection_data_get_data( selection );
-#else
-			data = ( NactClipboardDndData * ) selection->data;
-#endif
+
 			if( data->target == NACT_XCHANGE_FORMAT_NACT ){
-
-				model = gtk_tree_row_reference_get_model(( GtkTreeRowReference * ) data->rows->data );
-
 				for( it = data->rows ; it ; it = it->next ){
 					rows = g_list_append( rows,
 							gtk_tree_row_reference_copy(( GtkTreeRowReference * ) it->data ));
@@ -426,6 +410,7 @@ nact_clipboard_dnd_drag_end( NactClipboard *clipboard )
 	static const gchar *thisfn = "nact_clipboard_dnd_drag_end";
 	GtkSelectionData *selection;
 	NactClipboardDndData *data;
+	gchar *buffer;
 
 	g_debug( "%s: clipboard=%p", thisfn, ( void * ) clipboard );
 	g_return_if_fail( NACT_IS_CLIPBOARD( clipboard ));
@@ -436,16 +421,13 @@ nact_clipboard_dnd_drag_end( NactClipboard *clipboard )
 		g_debug( "%s: selection=%p", thisfn, ( void * ) selection );
 
 		if( selection ){
-#if GTK_CHECK_VERSION( 2, 14, 0 )
 			data = ( NactClipboardDndData * ) gtk_selection_data_get_data( selection );
-#else
-			data = ( NactClipboardDndData * ) selection->data;
-#endif
 			g_debug( "%s: data=%p (NactClipboardDndData)", thisfn, ( void * ) data );
 
 			if( data->target == NACT_XCHANGE_FORMAT_XDS ){
 				g_debug( "%s: folder=%s", thisfn, data->folder );
-				export_rows( clipboard, data->rows, data->folder );
+				buffer = export_rows( clipboard, data->rows, data->folder );
+				g_free( buffer );
 			}
 
 			gtk_selection_data_free( selection );
@@ -475,11 +457,7 @@ get_from_dnd_clipboard_callback( GtkClipboard *clipboard, GtkSelectionData *sele
 	static const gchar *thisfn = "nact_clipboard_get_from_dnd_clipboard_callback";
 	GdkAtom selection_data_target;
 
-#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_target = gtk_selection_data_get_target( selection_data );
-#else
-	selection_data_target = selection_data->target;
-#endif
 
 	g_debug( "%s: clipboard=%p, selection_data=%p, target=%s, info=%d, data=%p",
 			thisfn, ( void * ) clipboard,
@@ -502,9 +480,14 @@ clear_dnd_clipboard_callback( GtkClipboard *clipboard, NactClipboardDndData *dat
 	g_free( data );
 }
 
+/*
+ * returns a buffer which contains all exported items if dest_folder is null
+ * else export items as files to target directory, returning an empty string
+ */
 static gchar *
 export_rows( NactClipboard *clipboard, GList *rows, const gchar *dest_folder )
 {
+	static const gchar *thisfn = "nact_clipboard_export_rows";
 	GString *data;
 	GtkTreeModel *model;
 	GList *exported, *irow;
@@ -514,6 +497,9 @@ export_rows( NactClipboard *clipboard, GList *rows, const gchar *dest_folder )
 	gchar *buffer;
 	gboolean first;
 
+	g_debug( "%s: clipboard=%p, rows=%p (count=%d), dest_folder=%s",
+			thisfn, ( void * ) clipboard, ( void * ) rows, g_list_length( rows ), dest_folder );
+
 	first = TRUE;
 	buffer = NULL;
 	exported = NULL;
@@ -571,25 +557,32 @@ export_objects( NactClipboard *clipboard, GList *objects )
 }
 
 /*
- * export to a buffer if dest_folder is null
- * else export to a new file in the target directory
+ * export to a buffer if dest_folder is null, and returns this buffer
+ * else export to a new file in the target directory (returning an empty string)
+ *
+ * exported maintains a list of exported items, so that the same item is not
+ * exported twice
  */
 static gchar *
 export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest_folder, GList **exported, gboolean first )
 {
+	static const gchar *thisfn = "nact_clipboard_export_row_object";
 	GList *subitems, *isub;
 	NactApplication *application;
 	NAUpdater *updater;
-	NAObjectAction *action;
+	NAObjectItem *item;
+	gchar *item_label;
 	gint index;
 	GString *data;
 	gchar *buffer;
-	GQuark format;
+	gchar *format;
 	gchar *fname;
 	GSList *msgs;
 
 	data = g_string_new( "" );
 
+	/* if we have a menu, first export the subitems
+	 */
 	if( NA_IS_OBJECT_MENU( object )){
 		subitems = na_object_get_items( object );
 
@@ -603,38 +596,50 @@ export_row_object( NactClipboard *clipboard, NAObject *object, const gchar *dest
 		}
 	}
 
+	/* only export NAObjectItem type
+	 * here, object may be a menu, an action or a profile
+	 */
 	msgs = NULL;
-	action = ( NAObjectAction * ) object;
+	item = ( NAObjectItem * ) object;
 	if( NA_IS_OBJECT_PROFILE( object )){
-		action = NA_OBJECT_ACTION( na_object_get_parent( object ));
+		item = NA_OBJECT_ITEM( na_object_get_parent( object ));
 	}
 
 	application = NACT_APPLICATION( base_window_get_application( clipboard->private->window ));
 	updater = nact_application_get_updater( application );
 
-	index = g_list_index( *exported, ( gconstpointer ) action );
+	index = g_list_index( *exported, ( gconstpointer ) item );
 	if( index == -1 ){
 
-		*exported = g_list_prepend( *exported, ( gpointer ) action );
-		format = na_iprefs_get_export_format( NA_IPREFS_EXPORT_PREFERRED_FORMAT, NULL );
+		item_label = na_object_get_label( item );
+		g_debug( "%s: exporting %s", thisfn, item_label );
+		g_free( item_label );
 
-		if( format == IPREFS_EXPORT_FORMAT_ASK ){
-			format = nact_export_ask_user( clipboard->private->window, NA_OBJECT_ITEM( action ), first );
+		*exported = g_list_prepend( *exported, ( gpointer ) item );
+		format = na_settings_get_string( NA_IPREFS_EXPORT_PREFERRED_FORMAT, NULL, NULL );
+		g_return_val_if_fail( format && strlen( format ), NULL );
+
+		if( !strcmp( format, EXPORTER_FORMAT_ASK )){
+			g_free( format );
+			format = nact_export_ask_user( clipboard->private->window, item, first );
+			g_return_val_if_fail( format && strlen( format ), NULL );
 		}
 
-		if( format != IPREFS_EXPORT_NO_EXPORT ){
+		if( strcmp( format, EXPORTER_FORMAT_NOEXPORT ) != 0 ){
 			if( dest_folder ){
-				fname = na_exporter_to_file( NA_PIVOT( updater ), NA_OBJECT_ITEM( action), dest_folder, format, &msgs );
+				fname = na_exporter_to_file( NA_PIVOT( updater ), item, dest_folder, format, &msgs );
 				g_free( fname );
 
 			} else {
-				buffer = na_exporter_to_buffer( NA_PIVOT( updater ), NA_OBJECT_ITEM( action ), format, &msgs );
+				buffer = na_exporter_to_buffer( NA_PIVOT( updater ), item, format, &msgs );
 				if( buffer && strlen( buffer )){
 					data = g_string_append( data, buffer );
 					g_free( buffer );
 				}
 			}
 		}
+
+		g_free( format );
 	}
 
 	return( g_string_free( data, FALSE ));
@@ -693,7 +698,7 @@ nact_clipboard_primary_set( NactClipboard *clipboard, GList *items, gint mode )
 
 		for( it = items ; it ; it = it->next ){
 			user_data->items =
-					g_list_prepend( user_data->items, na_object_duplicate( it->data ));
+					g_list_prepend( user_data->items, na_object_duplicate( it->data, DUPLICATE_REC ));
 		}
 		user_data->items = g_list_reverse( user_data->items );
 
@@ -738,16 +743,12 @@ nact_clipboard_primary_get( NactClipboard *clipboard, gboolean *relabel )
 		selection = gtk_clipboard_wait_for_contents( clipboard->private->primary, NACT_CLIPBOARD_NACT_ATOM );
 
 		if( selection ){
-#if GTK_CHECK_VERSION( 2, 14, 0 )
 			user_data = ( PrimaryData * ) gtk_selection_data_get_data( selection );
-#else
-			user_data = ( PrimaryData * ) selection->data;
-#endif
 			g_debug( "%s: retrieving PrimaryData=%p", thisfn, ( void * ) user_data );
 
 			if( user_data ){
 				for( it = user_data->items ; it ; it = it->next ){
-					obj = NA_OBJECT( na_object_duplicate( it->data ));
+					obj = NA_OBJECT( na_object_duplicate( it->data, DUPLICATE_REC ));
 					na_object_set_origin( obj, NULL );
 					items = g_list_prepend( items, obj );
 				}
@@ -804,11 +805,7 @@ get_from_primary_clipboard_callback( GtkClipboard *gtk_clipboard, GtkSelectionDa
 	gchar *buffer;
 	GdkAtom selection_data_target;
 
-#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_target = gtk_selection_data_get_target( selection_data );
-#else
-	selection_data_target = selection_data->target;
-#endif
 
 	g_debug( "%s: gtk_clipboard=%p, selection_data=%p, target=%s, info=%d, clipboard=%p",
 			thisfn, ( void * ) gtk_clipboard,
