@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -62,10 +61,11 @@ static BaseDialogClass *st_parent_class   = NULL;
 static GType    register_type( void );
 static void     class_init( NactConfirmLogoutClass *klass );
 static void     instance_init( GTypeInstance *instance, gpointer klass );
+static void     instance_constructed( GObject *dialog );
 static void     instance_dispose( GObject *dialog );
 static void     instance_finalize( GObject *dialog );
 
-static void     on_base_initialize_base_window( NactConfirmLogout *editor );
+static void     on_base_initialize_window( NactConfirmLogout *editor, gpointer user_data );
 static void     on_quit_without_saving_clicked( GtkButton *button, NactConfirmLogout *editor );
 static void     on_cancel_clicked( GtkButton *button, NactConfirmLogout *editor );
 static void     on_save_and_quit_clicked( GtkButton *button, NactConfirmLogout *editor );
@@ -103,7 +103,7 @@ register_type( void )
 
 	g_debug( "%s", thisfn );
 
-	type = g_type_register_static( BASE_DIALOG_TYPE, "NactConfirmLogout", &info, 0 );
+	type = g_type_register_static( BASE_TYPE_DIALOG, "NactConfirmLogout", &info, 0 );
 
 	return( type );
 }
@@ -119,6 +119,7 @@ class_init( NactConfirmLogoutClass *klass )
 	st_parent_class = g_type_class_peek_parent( klass );
 
 	object_class = G_OBJECT_CLASS( klass );
+	object_class->constructed = instance_constructed;
 	object_class->dispose = instance_dispose;
 	object_class->finalize = instance_finalize;
 
@@ -138,12 +139,36 @@ instance_init( GTypeInstance *instance, gpointer klass )
 
 	self->private = g_new0( NactConfirmLogoutPrivate, 1 );
 
-	base_window_signal_connect( BASE_WINDOW( instance ),
-			G_OBJECT( instance ), BASE_SIGNAL_INITIALIZE_WINDOW, G_CALLBACK( on_base_initialize_base_window ));
-
 	self->private->dispose_has_run = FALSE;
 }
 
+static void
+instance_constructed( GObject *dialog )
+{
+	static const gchar *thisfn = "nact_confirm_logout_instance_constructed";
+	NactConfirmLogoutPrivate *priv;
+
+	g_return_if_fail( NACT_IS_CONFIRM_LOGOUT( dialog ));
+
+	priv = NACT_CONFIRM_LOGOUT( dialog )->private;
+
+	if( !priv->dispose_has_run ){
+
+		/* chain up to the parent class */
+		if( G_OBJECT_CLASS( st_parent_class )->constructed ){
+			G_OBJECT_CLASS( st_parent_class )->constructed( dialog );
+		}
+
+		g_debug( "%s: dialog=%p (%s)", thisfn, ( void * ) dialog, G_OBJECT_TYPE_NAME( dialog ));
+
+		base_window_signal_connect(
+				BASE_WINDOW( dialog ),
+				G_OBJECT( dialog ),
+				BASE_SIGNAL_INITIALIZE_WINDOW,
+				G_CALLBACK( on_base_initialize_window ));
+	}
+}
+
 static void
 instance_dispose( GObject *dialog )
 {
@@ -201,7 +226,7 @@ nact_confirm_logout_run( NactMainWindow *parent )
 
 	g_debug( "%s: parent=%p", thisfn, ( void * ) parent );
 
-	dialog = g_object_new( NACT_CONFIRM_LOGOUT_TYPE,
+	dialog = g_object_new( NACT_TYPE_CONFIRM_LOGOUT,
 			BASE_PROP_PARENT,        parent,
 			BASE_PROP_TOPLEVEL_NAME, st_toplevel_name,
 			BASE_PROP_WSP_NAME,      st_wsp_name,
@@ -217,23 +242,33 @@ nact_confirm_logout_run( NactMainWindow *parent )
 }
 
 static void
-on_base_initialize_base_window( NactConfirmLogout *dialog )
+on_base_initialize_window( NactConfirmLogout *dialog, gpointer user_data )
 {
-	static const gchar *thisfn = "nact_confirm_logout_on_base_initialize_base_window";
+	static const gchar *thisfn = "nact_confirm_logout_on_base_initialize_window";
 
 	g_return_if_fail( NACT_IS_CONFIRM_LOGOUT( dialog ));
 
 	if( !dialog->private->dispose_has_run ){
-		g_debug( "%s: dialog=%p", thisfn, ( void * ) dialog );
 
-		base_window_signal_connect_by_name( BASE_WINDOW( dialog ),
-				"QuitNoSaveButton", "clicked", G_CALLBACK( on_quit_without_saving_clicked ));
+		g_debug( "%s: dialog=%p, user_data=%p", thisfn, ( void * ) dialog, ( void * ) user_data );
 
-		base_window_signal_connect_by_name( BASE_WINDOW( dialog ),
-				"CancelQuitButton", "clicked", G_CALLBACK( on_cancel_clicked ));
+		base_window_signal_connect_by_name(
+				BASE_WINDOW( dialog ),
+				"QuitNoSaveButton",
+				"clicked",
+				G_CALLBACK( on_quit_without_saving_clicked ));
 
-		base_window_signal_connect_by_name( BASE_WINDOW( dialog ),
-				"SaveQuitButton", "clicked", G_CALLBACK( on_save_and_quit_clicked ));
+		base_window_signal_connect_by_name(
+				BASE_WINDOW( dialog ),
+				"CancelQuitButton",
+				"clicked",
+				G_CALLBACK( on_cancel_clicked ));
+
+		base_window_signal_connect_by_name(
+				BASE_WINDOW( dialog ),
+				"SaveQuitButton",
+				"clicked",
+				G_CALLBACK( on_save_and_quit_clicked ));
 	}
 }
 
