@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -53,24 +52,36 @@ struct _NactIPropertiesTabInterfacePrivate {
 /* i18n: label of the push button when there is not yet any shortcut */
 #define NO_SHORTCUT						N_( "None" )
 
-static gboolean st_initialized = FALSE;
-static gboolean st_finalized   = FALSE;
-static gboolean st_on_selection_change = FALSE;
+/* data set against the instance
+ */
+typedef struct {
+	gboolean on_selection_change;
+}
+	IPropertiesData;
 
-static GType      register_type( void );
-static void       interface_base_init( NactIPropertiesTabInterface *klass );
-static void       interface_base_finalize( NactIPropertiesTabInterface *klass );
+#define IPROPERTIES_TAB_PROP_DATA		"nact-iproperties-tab-data"
 
-static void       on_main_selection_changed( NactIPropertiesTab *instance, GList *selected_items, gpointer user_data );
-static void       on_main_item_updated( NactIPropertiesTab *instance, NAObjectItem *item, guint data, gpointer user_data );
+static guint st_initializations = 0;	/* interface initialization count */
 
-static GtkButton *get_enabled_button( NactIPropertiesTab *instance );
-static void       on_enabled_toggled( GtkToggleButton *button, NactIPropertiesTab *instance );
-static void       on_readonly_toggled( GtkToggleButton *button, NactIPropertiesTab *instance );
-static void       on_description_changed( GtkTextBuffer *buffer, NactIPropertiesTab *instance );
-static void       on_shortcut_clicked( GtkButton *button, NactIPropertiesTab *instance );
+static GType            register_type( void );
+static void             interface_base_init( NactIPropertiesTabInterface *klass );
+static void             interface_base_finalize( NactIPropertiesTabInterface *klass );
 
-static void       display_provider_name( NactIPropertiesTab *instance, NAObjectItem *item );
+static void             on_base_initialize_window( NactIPropertiesTab *instance, gpointer user_data );
+
+static void             on_main_selection_changed( NactIPropertiesTab *instance, GList *selected_items, gpointer user_data );
+static void             on_main_item_updated( NactIPropertiesTab *instance, NAObjectItem *item, guint data, gpointer user_data );
+
+static GtkButton       *get_enabled_button( NactIPropertiesTab *instance );
+static void             on_enabled_toggled( GtkToggleButton *button, NactIPropertiesTab *instance );
+static void             on_readonly_toggled( GtkToggleButton *button, NactIPropertiesTab *instance );
+static void             on_description_changed( GtkTextBuffer *buffer, NactIPropertiesTab *instance );
+static void             on_shortcut_clicked( GtkButton *button, NactIPropertiesTab *instance );
+
+static void             display_provider_name( NactIPropertiesTab *instance, NAObjectItem *item );
+
+static IPropertiesData *get_iproperties_data( NactIPropertiesTab *instance );
+static void             on_instance_finalized( gpointer user_data, NactIPropertiesTab *instance );
 
 GType
 nact_iproperties_tab_get_type( void )
@@ -106,7 +117,7 @@ register_type( void )
 
 	type = g_type_register_static( G_TYPE_INTERFACE, "NactIPropertiesTab", &info, 0 );
 
-	g_type_interface_add_prerequisite( type, BASE_WINDOW_TYPE );
+	g_type_interface_add_prerequisite( type, BASE_TYPE_WINDOW );
 
 	return( type );
 }
@@ -116,13 +127,14 @@ interface_base_init( NactIPropertiesTabInterface *klass )
 {
 	static const gchar *thisfn = "nact_iproperties_tab_interface_base_init";
 
-	if( !st_initialized ){
+	if( !st_initializations ){
+
 		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
 		klass->private = g_new0( NactIPropertiesTabInterfacePrivate, 1 );
-
-		st_initialized = TRUE;
 	}
+
+	st_initializations += 1;
 }
 
 static void
@@ -130,92 +142,102 @@ interface_base_finalize( NactIPropertiesTabInterface *klass )
 {
 	static const gchar *thisfn = "nact_iproperties_tab_interface_base_finalize";
 
-	if( st_initialized && !st_finalized ){
-		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
+	st_initializations -= 1;
 
-		st_finalized = TRUE;
+	if( !st_initializations ){
+
+		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
 		g_free( klass->private );
 	}
 }
 
+/**
+ * nact_iproperties_tab_init:
+ * @instance: this #NactIPropertiesTab instance.
+ *
+ * Initialize the interface
+ * Connect to #BaseWindow signals
+ */
 void
-nact_iproperties_tab_initial_load_toplevel( NactIPropertiesTab *instance )
+nact_iproperties_tab_init( NactIPropertiesTab *instance )
 {
-	static const gchar *thisfn = "nact_iproperties_tab_initial_load_toplevel";
+	static const gchar *thisfn = "nact_iproperties_tab_init";
+	IPropertiesData *data;
 
 	g_return_if_fail( NACT_IS_IPROPERTIES_TAB( instance ));
 
-	if( st_initialized && !st_finalized ){
-		g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
-	}
+	g_debug( "%s: instance=%p (%s)",
+			thisfn,
+			( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
+
+	base_window_signal_connect(
+			BASE_WINDOW( instance ),
+			G_OBJECT( instance ),
+			BASE_SIGNAL_INITIALIZE_WINDOW,
+			G_CALLBACK( on_base_initialize_window ));
+
+	nact_main_tab_init( NACT_MAIN_WINDOW( instance ), TAB_PROPERTIES );
+
+	data = get_iproperties_data( instance );
+	data->on_selection_change = FALSE;
+
+	g_object_weak_ref( G_OBJECT( instance ), ( GWeakNotify ) on_instance_finalized, NULL );
 }
 
-void
-nact_iproperties_tab_runtime_init_toplevel( NactIPropertiesTab *instance )
+static void
+on_base_initialize_window( NactIPropertiesTab *instance, void *user_data )
 {
-	static const gchar *thisfn = "nact_iproperties_tab_runtime_init_toplevel";
+	static const gchar *thisfn = "nact_iproperties_tab_on_base_initialize_window";
 	GtkButton *enabled_button;
 	GtkWidget *label_widget;
 	GtkTextBuffer *buffer;
 
 	g_return_if_fail( NACT_IS_IPROPERTIES_TAB( instance ));
 
-	if( st_initialized && !st_finalized ){
-		g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
+	g_debug( "%s: instance=%p (%s), user_data=%p",
+			thisfn,
+			( void * ) instance, G_OBJECT_TYPE_NAME( instance ),
+			( void * ) user_data );
 
-		base_window_signal_connect( BASE_WINDOW( instance ),
-				G_OBJECT( instance ), MAIN_SIGNAL_SELECTION_CHANGED, G_CALLBACK( on_main_selection_changed ));
+	base_window_signal_connect(
+			BASE_WINDOW( instance ),
+			G_OBJECT( instance ),
+			MAIN_SIGNAL_SELECTION_CHANGED,
+			G_CALLBACK( on_main_selection_changed ));
 
-		base_window_signal_connect( BASE_WINDOW( instance ),
-				G_OBJECT( instance ), MAIN_SIGNAL_ITEM_UPDATED, G_CALLBACK( on_main_item_updated ));
+	base_window_signal_connect(
+			BASE_WINDOW( instance ),
+			G_OBJECT( instance ),
+			MAIN_SIGNAL_ITEM_UPDATED,
+			G_CALLBACK( on_main_item_updated ));
 
-		enabled_button = get_enabled_button( instance );
-		base_window_signal_connect( BASE_WINDOW( instance ),
-				G_OBJECT( enabled_button ), "toggled", G_CALLBACK( on_enabled_toggled ));
+	enabled_button = get_enabled_button( instance );
+	base_window_signal_connect(
+			BASE_WINDOW( instance ),
+			G_OBJECT( enabled_button ),
+			"toggled",
+			G_CALLBACK( on_enabled_toggled ));
 
-		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionDescriptionText" );
-		buffer = gtk_text_view_get_buffer( GTK_TEXT_VIEW( label_widget ));
-		base_window_signal_connect( BASE_WINDOW( instance ),
-				G_OBJECT( buffer ), "changed", G_CALLBACK( on_description_changed ));
+	label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionDescriptionText" );
+	buffer = gtk_text_view_get_buffer( GTK_TEXT_VIEW( label_widget ));
+	base_window_signal_connect(
+			BASE_WINDOW( instance ),
+			G_OBJECT( buffer ),
+			"changed",
+			G_CALLBACK( on_description_changed ));
 
-		base_window_signal_connect_by_name( BASE_WINDOW( instance ),
-				"SuggestedShortcutButton", "clicked", G_CALLBACK( on_shortcut_clicked ));
+	base_window_signal_connect_by_name(
+			BASE_WINDOW( instance ),
+			"SuggestedShortcutButton",
+			"clicked",
+			G_CALLBACK( on_shortcut_clicked ));
 
-		base_window_signal_connect_by_name( BASE_WINDOW( instance ),
-				"ActionReadonlyButton", "toggled", G_CALLBACK( on_readonly_toggled ));
-
-#if 0
-		g_signal_override_class_handler( "toggled", GTK_TYPE_TOGGLE_BUTTON, G_CALLBACK( on_readonly_toggle_cb ));
-		g_signal_add_emission_hook(
-				g_signal_lookup( "toggled", GTK_TYPE_TOGGLE_BUTTON ), ( GQuark ) 0,
-				( GSignalEmissionHook ) on_readonly_toggle_hook, instance, NULL );
-#endif
-	}
-}
-
-void
-nact_iproperties_tab_all_widgets_showed( NactIPropertiesTab *instance )
-{
-	static const gchar *thisfn = "nact_iproperties_tab_all_widgets_showed";
-
-	g_return_if_fail( NACT_IS_IPROPERTIES_TAB( instance ));
-
-	if( st_initialized && !st_finalized ){
-		g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
-	}
-}
-
-void
-nact_iproperties_tab_dispose( NactIPropertiesTab *instance )
-{
-	static const gchar *thisfn = "nact_iproperties_tab_dispose";
-
-	g_return_if_fail( NACT_IS_IPROPERTIES_TAB( instance ));
-
-	if( st_initialized && !st_finalized ){
-		g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
-	}
+	base_window_signal_connect_by_name(
+			BASE_WINDOW( instance ),
+			"ActionReadonlyButton",
+			"toggled",
+			G_CALLBACK( on_readonly_toggled ));
 }
 
 static void
@@ -234,82 +256,82 @@ on_main_selection_changed( NactIPropertiesTab *instance, GList *selected_items,
 	GtkToggleButton *readonly_button;
 	GtkTextBuffer *buffer;
 	gchar *label, *shortcut;
+	IPropertiesData *data;
 
 	g_return_if_fail( BASE_IS_WINDOW( instance ));
 	g_return_if_fail( NACT_IS_IPROPERTIES_TAB( instance ));
 
-	if( st_initialized && !st_finalized ){
-		count_selected = g_list_length( selected_items );
-		g_debug( "%s: instance=%p (%s), count_selected=%d",
-				thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), count_selected );
+	count_selected = g_list_length( selected_items );
+	g_debug( "%s: instance=%p (%s), count_selected=%d",
+			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), count_selected );
 
-		g_object_get(
-				G_OBJECT( instance ),
-				MAIN_PROP_ITEM, &item,
-				MAIN_PROP_EDITABLE, &editable,
-				NULL );
+	g_object_get(
+			G_OBJECT( instance ),
+			MAIN_PROP_ITEM, &item,
+			MAIN_PROP_EDITABLE, &editable,
+			NULL );
 
-		g_return_if_fail( !item || NA_IS_OBJECT_ITEM( item ));
+	g_return_if_fail( !item || NA_IS_OBJECT_ITEM( item ));
 
-		enable_tab = ( count_selected == 1 );
-		nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_PROPERTIES, enable_tab );
+	enable_tab = ( count_selected == 1 );
+	nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_PROPERTIES, enable_tab );
 
-		st_on_selection_change = TRUE;
+	data = get_iproperties_data( instance );
+	data->on_selection_change = TRUE;
 
-		notebook = GTK_NOTEBOOK( base_window_get_widget( BASE_WINDOW( instance ), "MainNotebook" ));
-		page = gtk_notebook_get_nth_page( notebook, TAB_ACTION );
-		title_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionPropertiesTitle" );
-		label_widget = gtk_notebook_get_tab_label( notebook, page );
+	notebook = GTK_NOTEBOOK( base_window_get_widget( BASE_WINDOW( instance ), "MainNotebook" ));
+	page = gtk_notebook_get_nth_page( notebook, TAB_ACTION );
+	title_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionPropertiesTitle" );
+	label_widget = gtk_notebook_get_tab_label( notebook, page );
 
-		if( item && NA_IS_OBJECT_MENU( item )){
-			gtk_label_set_label( GTK_LABEL( label_widget ), _( "Me_nu" ));
-			gtk_label_set_markup( GTK_LABEL( title_widget ), _( "<b>Menu editable properties</b>" ));
-		} else {
-			gtk_label_set_label( GTK_LABEL( label_widget ), _( "_Action" ));
-			gtk_label_set_markup( GTK_LABEL( title_widget ), _( "<b>Action editable properties</b>" ));
-		}
-
-		enabled_button = get_enabled_button( instance );
-		enabled_item = item ? na_object_is_enabled( NA_OBJECT_ITEM( item )) : FALSE;
-		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( enabled_button ), enabled_item );
-		base_gtk_utils_set_editable( G_OBJECT( enabled_button ), editable );
-
-		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionDescriptionText" );
-		buffer = gtk_text_view_get_buffer( GTK_TEXT_VIEW( label_widget ));
-		label = item ? na_object_get_description( item ) : g_strdup( "" );
-		gtk_text_buffer_set_text( buffer, label, -1 );
-		g_free( label );
-		base_gtk_utils_set_editable( G_OBJECT( label_widget ), editable );
-
-		shortcut_button = base_window_get_widget( BASE_WINDOW( instance ), "SuggestedShortcutButton" );
-		shortcut = item ? na_object_get_shortcut( item ) : g_strdup( "" );
-		if( !shortcut || !strlen( shortcut )){
-			g_free( shortcut );
-			shortcut = g_strdup( gettext( NO_SHORTCUT ));
-		}
-		gtk_button_set_label( GTK_BUTTON( shortcut_button ), shortcut );
-		g_free( shortcut );
-		base_gtk_utils_set_editable( G_OBJECT( shortcut_button ), editable );
-
-		/* TODO: don't know how to edit a shortcut for now */
-		gtk_widget_set_sensitive( shortcut_button, FALSE );
-
-		/* read-only toggle only indicates the intrinsic writability status of this item
-		 * _not_ the writability status of the provider
-		 */
-		readonly_button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionReadonlyButton" ));
-		gtk_toggle_button_set_active( readonly_button, item ? na_object_is_readonly( item ) : FALSE );
-		base_gtk_utils_set_editable( G_OBJECT( readonly_button ), FALSE );
-
-		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionItemID" );
-		label = item ? na_object_get_id( item ) : g_strdup( "" );
-		gtk_label_set_text( GTK_LABEL( label_widget ), label );
-		g_free( label );
-
-		display_provider_name( instance, item );
-
-		st_on_selection_change = FALSE;
+	if( item && NA_IS_OBJECT_MENU( item )){
+		gtk_label_set_label( GTK_LABEL( label_widget ), _( "Me_nu" ));
+		gtk_label_set_markup( GTK_LABEL( title_widget ), _( "<b>Menu editable properties</b>" ));
+	} else {
+		gtk_label_set_label( GTK_LABEL( label_widget ), _( "_Action" ));
+		gtk_label_set_markup( GTK_LABEL( title_widget ), _( "<b>Action editable properties</b>" ));
 	}
+
+	enabled_button = get_enabled_button( instance );
+	enabled_item = item ? na_object_is_enabled( NA_OBJECT_ITEM( item )) : FALSE;
+	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( enabled_button ), enabled_item );
+	base_gtk_utils_set_editable( G_OBJECT( enabled_button ), editable );
+
+	label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionDescriptionText" );
+	buffer = gtk_text_view_get_buffer( GTK_TEXT_VIEW( label_widget ));
+	label = item ? na_object_get_description( item ) : g_strdup( "" );
+	gtk_text_buffer_set_text( buffer, label, -1 );
+	g_free( label );
+	base_gtk_utils_set_editable( G_OBJECT( label_widget ), editable );
+
+	shortcut_button = base_window_get_widget( BASE_WINDOW( instance ), "SuggestedShortcutButton" );
+	shortcut = item ? na_object_get_shortcut( item ) : g_strdup( "" );
+	if( !shortcut || !strlen( shortcut )){
+		g_free( shortcut );
+		shortcut = g_strdup( gettext( NO_SHORTCUT ));
+	}
+	gtk_button_set_label( GTK_BUTTON( shortcut_button ), shortcut );
+	g_free( shortcut );
+	base_gtk_utils_set_editable( G_OBJECT( shortcut_button ), editable );
+
+	/* TODO: don't know how to edit a shortcut for now */
+	gtk_widget_set_sensitive( shortcut_button, FALSE );
+
+	/* read-only toggle only indicates the intrinsic writability status of this item
+	 * _not_ the writability status of the provider
+	 */
+	readonly_button = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionReadonlyButton" ));
+	gtk_toggle_button_set_active( readonly_button, item ? na_object_is_readonly( item ) : FALSE );
+	base_gtk_utils_set_editable( G_OBJECT( readonly_button ), FALSE );
+
+	label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionItemID" );
+	label = item ? na_object_get_id( item ) : g_strdup( "" );
+	gtk_label_set_text( GTK_LABEL( label_widget ), label );
+	g_free( label );
+
+	display_provider_name( instance, item );
+
+	data->on_selection_change = FALSE;
 }
 
 static void
@@ -317,12 +339,10 @@ on_main_item_updated( NactIPropertiesTab *instance, NAObjectItem *item, guint da
 {
 	static const gchar *thisfn = "nact_iproperties_tab_on_main_item_updated";
 
-	if( st_initialized && !st_finalized ){
-		if( data & MAIN_DATA_PROVIDER ){
-			g_debug( "%s: instance=%p, item=%p, data=%u, user_data=%p",
-					thisfn, ( void * ) instance, ( void * ) item, data, ( void * ) user_data );
-			display_provider_name( instance, item );
-		}
+	if( data & MAIN_DATA_PROVIDER ){
+		g_debug( "%s: instance=%p, item=%p, data=%u, user_data=%p",
+				thisfn, ( void * ) instance, ( void * ) item, data, ( void * ) user_data );
+		display_provider_name( instance, item );
 	}
 }
 
@@ -339,10 +359,13 @@ on_enabled_toggled( GtkToggleButton *button, NactIPropertiesTab *instance )
 	NAObjectItem *item;
 	gboolean enabled;
 	gboolean editable;
+	IPropertiesData *data;
 
-	if( !st_on_selection_change ){
+	data = get_iproperties_data( instance );
+
+	if( !data->on_selection_change ){
 		g_debug( "%s: button=%p, instance=%p, on_selection_change=%s",
-				thisfn, ( void * ) button, ( void * ) instance, st_on_selection_change ? "True":"False" );
+				thisfn, ( void * ) button, ( void * ) instance, data->on_selection_change ? "True":"False" );
 
 		g_object_get(
 				G_OBJECT( instance ),
@@ -386,10 +409,13 @@ on_readonly_toggled( GtkToggleButton *button, NactIPropertiesTab *instance )
 {
 	static const gchar *thisfn = "nact_iproperties_tab_on_readonly_toggled";
 	gboolean active;
+	IPropertiesData *data;
 
-	if( !st_on_selection_change ){
+	data = get_iproperties_data( instance );
+
+	if( !data->on_selection_change ){
 		g_debug( "%s: button=%p, instance=%p, on_selection_change=%s",
-				thisfn, ( void * ) button, ( void * ) instance, st_on_selection_change ? "True":"False" );
+				thisfn, ( void * ) button, ( void * ) instance, data->on_selection_change ? "True":"False" );
 
 		active = gtk_toggle_button_get_active( button );
 
@@ -503,3 +529,31 @@ display_provider_name( NactIPropertiesTab *instance, NAObjectItem *item )
 	g_free( label );
 	gtk_widget_set_sensitive( label_widget, item != NULL );
 }
+
+static IPropertiesData *
+get_iproperties_data( NactIPropertiesTab *instance )
+{
+	IPropertiesData *data;
+
+	data = ( IPropertiesData * ) g_object_get_data( G_OBJECT( instance ), IPROPERTIES_TAB_PROP_DATA );
+
+	if( !data ){
+		data = g_new0( IPropertiesData, 1 );
+		g_object_set_data( G_OBJECT( instance ), IPROPERTIES_TAB_PROP_DATA, data );
+	}
+
+	return( data );
+}
+
+static void
+on_instance_finalized( gpointer user_data, NactIPropertiesTab *instance )
+{
+	static const gchar *thisfn = "nact_iproperties_tab_on_instance_finalized";
+	IPropertiesData *data;
+
+	g_debug( "%s: instance=%p, user_data=%p", thisfn, ( void * ) instance, ( void * ) user_data );
+
+	data = get_iproperties_data( instance );
+
+	g_free( data );
+}
