@@ -50,25 +50,26 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* VOID:INT,INT,INT (nact-marshal.list:1) */
+/* VOID:BOOLEAN,INT,INT,INT (/home/pierre/data/eclipse/nautilus-actions/src/nact/nact-marshal.def:2) */
 void
-nact_marshal_VOID__INT_INT_INT (GClosure     *closure,
-                                GValue       *return_value G_GNUC_UNUSED,
-                                guint         n_param_values,
-                                const GValue *param_values,
-                                gpointer      invocation_hint G_GNUC_UNUSED,
-                                gpointer      marshal_data)
+nact_cclosure_marshal_VOID__BOOLEAN_INT_INT_INT (GClosure     *closure,
+                                                 GValue       *return_value G_GNUC_UNUSED,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint G_GNUC_UNUSED,
+                                                 gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_INT_INT) (gpointer     data1,
-                                                  gint         arg_1,
-                                                  gint         arg_2,
-                                                  gint         arg_3,
-                                                  gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT_INT callback;
+  typedef void (*GMarshalFunc_VOID__BOOLEAN_INT_INT_INT) (gpointer     data1,
+                                                          gboolean     arg_1,
+                                                          gint         arg_2,
+                                                          gint         arg_3,
+                                                          gint         arg_4,
+                                                          gpointer     data2);
+  register GMarshalFunc_VOID__BOOLEAN_INT_INT_INT callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
-  g_return_if_fail (n_param_values == 4);
+  g_return_if_fail (n_param_values == 5);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
     {
@@ -80,68 +81,30 @@ nact_marshal_VOID__INT_INT_INT (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__INT_INT_INT) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__BOOLEAN_INT_INT_INT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
-            g_marshal_value_peek_int (param_values + 1),
+            g_marshal_value_peek_boolean (param_values + 1),
             g_marshal_value_peek_int (param_values + 2),
             g_marshal_value_peek_int (param_values + 3),
+            g_marshal_value_peek_int (param_values + 4),
             data2);
 }
 
-/* VOID:POINTER,POINTER,INT (nact-marshal.list:2) */
+/* VOID:POINTER,UINT (/home/pierre/data/eclipse/nautilus-actions/src/nact/nact-marshal.def:6) */
 void
-nact_marshal_VOID__POINTER_POINTER_INT (GClosure     *closure,
-                                        GValue       *return_value G_GNUC_UNUSED,
-                                        guint         n_param_values,
-                                        const GValue *param_values,
-                                        gpointer      invocation_hint G_GNUC_UNUSED,
-                                        gpointer      marshal_data)
+nact_cclosure_marshal_VOID__POINTER_UINT (GClosure     *closure,
+                                          GValue       *return_value G_GNUC_UNUSED,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint G_GNUC_UNUSED,
+                                          gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__POINTER_POINTER_INT) (gpointer     data1,
-                                                          gpointer     arg_1,
-                                                          gpointer     arg_2,
-                                                          gint         arg_3,
-                                                          gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_POINTER_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 4);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__POINTER_POINTER_INT) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_pointer (param_values + 1),
-            g_marshal_value_peek_pointer (param_values + 2),
-            g_marshal_value_peek_int (param_values + 3),
-            data2);
-}
-
-/* VOID:POINTER,BOOLEAN (nact-marshal.list:3) */
-void
-nact_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
-                                    GValue       *return_value G_GNUC_UNUSED,
-                                    guint         n_param_values,
-                                    const GValue *param_values,
-                                    gpointer      invocation_hint G_GNUC_UNUSED,
-                                    gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__POINTER_BOOLEAN) (gpointer     data1,
-                                                      gpointer     arg_1,
-                                                      gboolean     arg_2,
-                                                      gpointer     data2);
-  register GMarshalFunc_VOID__POINTER_BOOLEAN callback;
+  typedef void (*GMarshalFunc_VOID__POINTER_UINT) (gpointer     data1,
+                                                   gpointer     arg_1,
+                                                   guint        arg_2,
+                                                   gpointer     data2);
+  register GMarshalFunc_VOID__POINTER_UINT callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
 
@@ -157,11 +120,48 @@ nact_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_VOID__POINTER_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__POINTER_UINT) (marshal_data ? marshal_data : cc->callback);
 
   callback (data1,
             g_marshal_value_peek_pointer (param_values + 1),
-            g_marshal_value_peek_boolean (param_values + 2),
+            g_marshal_value_peek_uint (param_values + 2),
+            data2);
+}
+
+/* VOID:POINTER,STRING (/home/pierre/data/eclipse/nautilus-actions/src/nact/nact-marshal.def:9) */
+void
+nact_cclosure_marshal_VOID__POINTER_STRING (GClosure     *closure,
+                                            GValue       *return_value G_GNUC_UNUSED,
+                                            guint         n_param_values,
+                                            const GValue *param_values,
+                                            gpointer      invocation_hint G_GNUC_UNUSED,
+                                            gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__POINTER_STRING) (gpointer     data1,
+                                                     gpointer     arg_1,
+                                                     gpointer     arg_2,
+                                                     gpointer     data2);
+  register GMarshalFunc_VOID__POINTER_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__POINTER_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_pointer (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
             data2);
 }
 
