@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -32,8 +31,10 @@
 #include <config.h>
 #endif
 
+#include <api/na-core-utils.h>
 #include <api/na-object-api.h>
 
+#include <core/na-factory-object.h>
 #include <core/na-updater.h>
 
 #include "base-keysyms.h"
@@ -41,6 +42,7 @@
 #include "nact-main-window.h"
 #include "nact-tree-ieditable.h"
 #include "nact-tree-model.h"
+#include "nact-tree-view.h"
 
 /* private interface data
  */
@@ -60,13 +62,13 @@ typedef struct {
 	guint          count_modified;
 	gboolean       level_zero_changed;
 	GList         *deleted;
+	guint          count_deleted;
 }
 	IEditableData;
 
 #define VIEW_DATA_IEDITABLE				"view-data-ieditable"
 
-static gboolean st_tree_ieditable_initialized = FALSE;
-static gboolean st_tree_ieditable_finalized   = FALSE;
+static guint st_initializations = 0;	/* interface initialization count */
 
 static GType          register_type( void );
 static void           interface_base_init( NactTreeIEditableInterface *klass );
@@ -84,6 +86,8 @@ static void           decrement_counters( NactTreeIEditable *view, IEditableData
 static GtkTreePath   *do_insert_before( IEditableData *ied, GList *items, GtkTreePath *insert_path );
 static GtkTreePath   *do_insert_into( IEditableData *ied, GList *items, GtkTreePath *insert_path );
 static void           increment_counters( NactTreeIEditable *view, IEditableData *ied, GList *items );
+static void           check_level_zero_status( NactTreeIEditable *instance );
+static gchar         *get_items_id_list_str( GList *items_list );
 static GtkTreePath   *get_selection_first_path( GtkTreeView *treeview );
 static gboolean       get_modification_status( IEditableData *ied );
 static IEditableData *get_instance_data( NactTreeIEditable *view );
@@ -123,6 +127,8 @@ register_type( void )
 
 	type = g_type_register_static( G_TYPE_INTERFACE, "NactTreeIEditable", &info, 0 );
 
+	g_type_interface_add_prerequisite( type, NACT_TYPE_TREE_VIEW );
+
 	return( type );
 }
 
@@ -131,13 +137,14 @@ interface_base_init( NactTreeIEditableInterface *klass )
 {
 	static const gchar *thisfn = "nact_tree_ieditable_interface_base_init";
 
-	if( !st_tree_ieditable_initialized ){
+	if( !st_initializations ){
+
 		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
 		klass->private = g_new0( NactTreeIEditableInterfacePrivate, 1 );
-
-		st_tree_ieditable_initialized = TRUE;
 	}
+
+	st_initializations += 1;
 }
 
 static void
@@ -145,10 +152,11 @@ interface_base_finalize( NactTreeIEditableInterface *klass )
 {
 	static const gchar *thisfn = "nact_tree_ieditable_interface_base_finalize";
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
+	st_initializations -= 1;
 
-		st_tree_ieditable_finalized = TRUE;
+	if( !st_initializations ){
+
+		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
 		g_free( klass->private );
 	}
@@ -171,8 +179,12 @@ nact_tree_ieditable_initialize( NactTreeIEditable *instance, GtkTreeView *treevi
 	GtkTreeViewColumn *column;
 	GList *renderers;
 
-	g_debug( "%s: instance=%p, treeview=%p, window=%p",
-			thisfn, ( void * ) instance, ( void * ) treeview, ( void * ) window );
+	g_return_if_fail( NACT_IS_TREE_IEDITABLE( instance ));
+
+	g_debug( "%s: instance=%p (%s), treeview=%p, window=%p",
+			thisfn,
+			( void * ) instance, G_OBJECT_TYPE_NAME( instance ),
+			( void * ) treeview, ( void * ) window );
 
 	ied = get_instance_data( instance );
 	ied->window = window;
@@ -183,33 +195,54 @@ nact_tree_ieditable_initialize( NactTreeIEditable *instance, GtkTreeView *treevi
 	ied->updater = nact_application_get_updater( application );
 
 	/* inline label edition with F2 */
-	base_window_signal_connect( window,
-			G_OBJECT( treeview ), "key-press-event", G_CALLBACK( on_key_pressed_event ));
+	base_window_signal_connect(
+			window,
+			G_OBJECT( treeview ),
+			"key-press-event",
+			G_CALLBACK( on_key_pressed_event ));
 
 	/* label edition: inform the corresponding tab */
 	column = gtk_tree_view_get_column( treeview, TREE_COLUMN_LABEL );
 	renderers = gtk_cell_layout_get_cells( GTK_CELL_LAYOUT( column ));
-	base_window_signal_connect( window,
-			G_OBJECT( renderers->data ), "edited", G_CALLBACK( on_label_edited ));
+	base_window_signal_connect(
+			window,
+			G_OBJECT( renderers->data ),
+			"edited",
+			G_CALLBACK( on_label_edited ));
 
 	/* monitors status changes to refresh the display */
 	na_iduplicable_register_consumer( G_OBJECT( instance ));
-	ied->modified_handler_id = base_window_signal_connect( window,
-			G_OBJECT( instance ), IDUPLICABLE_SIGNAL_MODIFIED_CHANGED, G_CALLBACK( on_object_modified_status_changed ));
-	ied->valid_handler_id = base_window_signal_connect( window,
-			G_OBJECT( instance ), IDUPLICABLE_SIGNAL_VALID_CHANGED, G_CALLBACK( on_object_valid_status_changed ));
+	ied->modified_handler_id = base_window_signal_connect(
+			window,
+			G_OBJECT( instance ),
+			IDUPLICABLE_SIGNAL_MODIFIED_CHANGED,
+			G_CALLBACK( on_object_modified_status_changed ));
+	ied->valid_handler_id = base_window_signal_connect(
+			window,
+			G_OBJECT( instance ),
+			IDUPLICABLE_SIGNAL_VALID_CHANGED,
+			G_CALLBACK( on_object_valid_status_changed ));
 
 	/* monitors the reloading of the tree */
-	base_window_signal_connect( window,
-			G_OBJECT( window ), TREE_SIGNAL_MODIFIED_STATUS_CHANGED, G_CALLBACK( on_tree_view_modified_status_changed ));
+	base_window_signal_connect(
+			window,
+			G_OBJECT( window ),
+			TREE_SIGNAL_MODIFIED_STATUS_CHANGED,
+			G_CALLBACK( on_tree_view_modified_status_changed ));
 
 	/* monitors the level zero of the tree */
-	base_window_signal_connect( window,
-			G_OBJECT( window ), TREE_SIGNAL_LEVEL_ZERO_CHANGED, G_CALLBACK( on_tree_view_level_zero_changed ));
+	base_window_signal_connect(
+			window,
+			G_OBJECT( window ),
+			TREE_SIGNAL_LEVEL_ZERO_CHANGED,
+			G_CALLBACK( on_tree_view_level_zero_changed ));
 
 	/* monitors the main selection */
-	base_window_signal_connect( window,
-			G_OBJECT( window ), MAIN_SIGNAL_SELECTION_CHANGED, G_CALLBACK( on_main_selection_changed ));
+	base_window_signal_connect(
+			window,
+			G_OBJECT( window ),
+			MAIN_SIGNAL_SELECTION_CHANGED,
+			G_CALLBACK( on_main_selection_changed ));
 }
 
 /**
@@ -224,7 +257,9 @@ nact_tree_ieditable_terminate( NactTreeIEditable *instance )
 	static const gchar *thisfn = "nact_tree_ieditable_terminate";
 	IEditableData *ied;
 
-	g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
+	g_return_if_fail( NACT_IS_TREE_IEDITABLE( instance ));
+
+	g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
 	ied = get_instance_data( instance );
 
@@ -242,12 +277,9 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, BaseWindow *window
 {
 	gboolean stop = FALSE;
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-
-		if( event->keyval == NACT_KEY_F2 ){
-			inline_edition( window );
-			stop = TRUE;
-		}
+	if( event->keyval == NACT_KEY_F2 ){
+		inline_edition( window );
+		stop = TRUE;
 	}
 
 	return( stop );
@@ -311,29 +343,27 @@ on_object_modified_status_changed( NactTreeIEditable *instance, NAObject *object
 	IEditableData *ied;
 	gboolean prev_status, status;
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-		g_debug( "%s: instance=%p, object=%p (%s), is_modified=%s, window=%p",
-				thisfn, ( void * ) instance,
-				( void * ) object, G_OBJECT_TYPE_NAME( object ), is_modified ? "True":"False",
-				( void * ) window );
+	g_debug( "%s: instance=%p, object=%p (%s), is_modified=%s, window=%p",
+			thisfn, ( void * ) instance,
+			( void * ) object, G_OBJECT_TYPE_NAME( object ), is_modified ? "True":"False",
+			( void * ) window );
 
-		ied = ( IEditableData * ) g_object_get_data( G_OBJECT( instance ), VIEW_DATA_IEDITABLE );
-		prev_status = get_modification_status( ied );
-		gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
+	ied = ( IEditableData * ) g_object_get_data( G_OBJECT( instance ), VIEW_DATA_IEDITABLE );
+	prev_status = get_modification_status( ied );
+	gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
 
-		if( NA_IS_OBJECT_ITEM( object )){
-			if( is_modified ){
-				ied->count_modified += 1;
-			} else {
-				ied->count_modified -= 1;
-			}
+	if( NA_IS_OBJECT_ITEM( object )){
+		if( is_modified ){
+			ied->count_modified += 1;
+		} else {
+			ied->count_modified -= 1;
 		}
+	}
 
-		if( nact_tree_view_are_notify_allowed( NACT_TREE_VIEW( instance ))){
-			status = get_modification_status( ied );
-			if( status != prev_status ){
-				g_signal_emit_by_name( window, TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
-			}
+	if( nact_tree_view_are_notify_allowed( NACT_TREE_VIEW( instance ))){
+		status = get_modification_status( ied );
+		if( status != prev_status ){
+			g_signal_emit_by_name( window, TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
 		}
 	}
 }
@@ -348,13 +378,11 @@ on_object_valid_status_changed( NactTreeIEditable *instance, NAObject *object, g
 	static const gchar *thisfn = "nact_tree_ieditable_on_object_valid_status_changed";
 	IEditableData *ied;
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-		g_debug( "%s: instance=%p, new_status=%s, window=%p",
-				thisfn, ( void * ) instance, new_status ? "True":"False", ( void * ) window );
+	g_debug( "%s: instance=%p, new_status=%s, window=%p",
+			thisfn, ( void * ) instance, new_status ? "True":"False", ( void * ) window );
 
-		ied = ( IEditableData * ) g_object_get_data( G_OBJECT( instance ), VIEW_DATA_IEDITABLE );
-		gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
-	}
+	ied = ( IEditableData * ) g_object_get_data( G_OBJECT( instance ), VIEW_DATA_IEDITABLE );
+	gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
 }
 
 /*
@@ -431,60 +459,58 @@ nact_tree_ieditable_delete( NactTreeIEditable *instance, GList *items, TreeIEdit
 
 	g_return_if_fail( NACT_IS_TREE_IEDITABLE( instance ));
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-		g_debug( "%s: instance=%p, items=%p (count=%d), ope=%u",
-				thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ), ope );
+	g_debug( "%s: instance=%p, items=%p (count=%d), ope=%u",
+			thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ), ope );
 
-		nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), FALSE );
-		ied = get_instance_data( instance );
-		prev_status = get_modification_status( ied );
+	nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), FALSE );
+	ied = get_instance_data( instance );
+	prev_status = get_modification_status( ied );
 
-		decrement_counters( instance, ied, items );
-		path = NULL;
-
-		for( it = items ; it ; it = it->next ){
-			if( path ){
-				gtk_tree_path_free( path );
-			}
-
-			/* check the status of the parent of the deleted object
-			 * so potentially update the modification status
-			 */
-			parent = na_object_get_parent( it->data );
-			path = nact_tree_model_delete( ied->model, NA_OBJECT( it->data ));
-			if( parent ){
-				na_object_check_status( parent );
-			} else {
-				g_signal_emit_by_name( ied->window, TREE_SIGNAL_LEVEL_ZERO_CHANGED, TRUE );
-			}
-
-			/* record the deleted item in the 'deleted' list,
-			 * incrementing the 'modified' count if the deleted item was not yet modified
-			 */
-			if( ope == TREE_OPE_DELETE ){
-				add_to_deleted_rec( ied, NA_OBJECT( it->data ));
-			}
-
-			g_debug( "%s: object=%p (%s, ref_count=%d)", thisfn,
-					( void * ) it->data, G_OBJECT_TYPE_NAME( it->data ), G_OBJECT( it->data )->ref_count );
-		}
-
-		gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
-
-		nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), TRUE );
+	decrement_counters( instance, ied, items );
+	path = NULL;
 
+	for( it = items ; it ; it = it->next ){
 		if( path ){
-			if( ope == TREE_OPE_DELETE ){
-				nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), path );
-			}
 			gtk_tree_path_free( path );
 		}
 
-		status = get_modification_status( ied );
-		if( status != prev_status ){
-			g_signal_emit_by_name( G_OBJECT( ied->window ), TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
-
+		/* check the status of the parent of the deleted object
+		 * so potentially update the modification status
+		 */
+		parent = na_object_get_parent( it->data );
+		path = nact_tree_model_delete( ied->model, NA_OBJECT( it->data ));
+		if( parent ){
+			na_object_check_status( parent );
+		} else {
+			check_level_zero_status( instance );
 		}
+
+		/* record the deleted item in the 'deleted' list,
+		 * incrementing the 'modified' count if the deleted item was not yet modified
+		 */
+		if( ope == TREE_OPE_DELETE ){
+			add_to_deleted_rec( ied, NA_OBJECT( it->data ));
+		}
+
+		g_debug( "%s: object=%p (%s, ref_count=%d)", thisfn,
+				( void * ) it->data, G_OBJECT_TYPE_NAME( it->data ), G_OBJECT( it->data )->ref_count );
+	}
+
+	gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
+
+	nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), TRUE );
+
+	if( path ){
+		if( ope == TREE_OPE_DELETE ){
+			nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), path );
+		}
+		gtk_tree_path_free( path );
+	}
+
+	status = get_modification_status( ied );
+	if( status != prev_status ){
+		g_signal_emit_by_name( G_OBJECT( ied->window ), TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
+
 	}
 }
 
@@ -496,6 +522,9 @@ nact_tree_ieditable_delete( NactTreeIEditable *instance, GList *items, TreeIEdit
  * Recursively adds to the 'deleted' list the NAObjectItem object currently being deleted.
  *
  * Increments the 'modified' count with the deleted items which were not modified.
+ *
+ * Only increments the 'deleted' count for items we may have to actually remove
+ * from the backend, i.e. those who have a non-null provider.
  */
 static void
 add_to_deleted_rec( IEditableData *ied, NAObject *object )
@@ -510,6 +539,10 @@ add_to_deleted_rec( IEditableData *ied, NAObject *object )
 			if( na_object_is_modified( object )){
 				ied->count_modified -= 1;
 			}
+
+			if( na_object_get_provider( object )){
+				ied->count_deleted += 1;
+			}
 		}
 
 		if( NA_IS_OBJECT_MENU( object )){
@@ -564,49 +597,33 @@ nact_tree_ieditable_remove_deleted( NactTreeIEditable *instance, GSList **messag
 	GList *it;
 	NAObjectItem *item;
 	GList *not_deleted;
-	guint delete_ret;
 
 	g_return_val_if_fail( NACT_IS_TREE_IEDITABLE( instance ), TRUE );
 
 	delete_ok = TRUE;
+	ied = get_instance_data( instance );
+	not_deleted = NULL;
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
+	for( it = ied->deleted ; it ; it = it->next ){
+		item = NA_OBJECT_ITEM( it->data );
+		g_debug( "%s: item=%p (%s)", thisfn, ( void * ) item, G_OBJECT_TYPE_NAME( item ));
+		na_object_dump_norec( item );
 
-		ied = get_instance_data( instance );
-		not_deleted = NULL;
-
-		for( it = ied->deleted ; it ; it = it->next ){
-			item = NA_OBJECT_ITEM( it->data );
-			g_debug( "%s: item=%p (%s)", thisfn, ( void * ) item, G_OBJECT_TYPE_NAME( item ));
-			na_object_dump_norec( item );
-
-			delete_ret = na_updater_delete_item( ied->updater, item, messages );
-			delete_ok = ( delete_ret == NA_IIO_PROVIDER_CODE_OK );
-
-			if( !delete_ok ){
-				not_deleted = g_list_prepend( not_deleted, na_object_ref( item ));
-
-#if 0
-			} else {
-				origin = ( NAObject * ) na_object_get_origin( item );
-				if( origin ){
-					na_updater_remove_item( updater, origin );
-					g_object_unref( origin );
-				}
-#endif
-			}
+		if( na_updater_delete_item( ied->updater, item, messages ) != NA_IIO_PROVIDER_CODE_OK ){
+			not_deleted = g_list_prepend( not_deleted, na_object_ref( item ));
+			delete_ok = FALSE;
 		}
+	}
 
-		ied->deleted = na_object_free_items( ied->deleted );
+	ied->deleted = na_object_free_items( ied->deleted );
 
-		/* items that we cannot delete are reinserted in the tree view
-		 * in the state they were when they were deleted
-		 * (i.e. possibly modified)
-		 */
-		if( not_deleted ){
-			nact_tree_ieditable_insert_items( instance, not_deleted, NULL );
-			na_object_free_items( not_deleted );
-		}
+	/* items that we cannot delete are reinserted in the tree view
+	 * in the state they were when they were deleted
+	 * (i.e. possibly modified)
+	 */
+	if( not_deleted ){
+		nact_tree_ieditable_insert_items( instance, not_deleted, NULL );
+		na_object_free_items( not_deleted );
 	}
 
 	return( delete_ok );
@@ -627,13 +644,8 @@ nact_tree_ieditable_get_deleted( NactTreeIEditable *instance )
 
 	g_return_val_if_fail( NACT_IS_TREE_IEDITABLE( instance ), NULL );
 
-	deleted = NULL;
-
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-
-		ied = get_instance_data( instance );
-		deleted = na_object_copyref_items( ied->deleted );
-	}
+	ied = get_instance_data( instance );
+	deleted = na_object_copyref_items( ied->deleted );
 
 	return( deleted );
 }
@@ -670,42 +682,41 @@ nact_tree_ieditable_insert_items( NactTreeIEditable *instance, GList *items, NAO
 	NAObject *object, *parent;
 
 	g_return_if_fail( NACT_IS_TREE_IEDITABLE( instance ));
+	g_return_if_fail( items );
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-		g_debug( "%s: instance=%p, items=%p (count=%d), sibling=%p",
-				thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ), ( void * ) sibling );
+	g_debug( "%s: instance=%p, items=%p (count=%d), sibling=%p",
+			thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ), ( void * ) sibling );
 
-		insert_path = NULL;
-		ied = get_instance_data( instance );
+	insert_path = NULL;
+	ied = get_instance_data( instance );
 
-		if( sibling ){
-			insert_path = nact_tree_model_object_to_path( ied->model, sibling );
+	if( sibling ){
+		insert_path = nact_tree_model_object_to_path( ied->model, sibling );
 
-		} else {
-			insert_path = get_selection_first_path( ied->treeview );
-			object = nact_tree_model_object_at_path( ied->model, insert_path );
-			g_debug( "%s: current object at insertion path is %p", thisfn, ( void * ) object );
+	} else {
+		insert_path = get_selection_first_path( ied->treeview );
+		object = nact_tree_model_object_at_path( ied->model, insert_path );
+		g_debug( "%s: current object at insertion path is %p", thisfn, ( void * ) object );
 
-			/* as a particular case, insert a new profile _into_ current action
-			 */
-			if( NA_IS_OBJECT_ACTION( object ) && NA_IS_OBJECT_PROFILE( items->data )){
-				nact_tree_ieditable_insert_into( instance, items );
-				gtk_tree_path_free( insert_path );
-				return;
-			}
-
-			/* insert a new NAObjectItem before current NAObjectItem
-			 */
-			if( NA_IS_OBJECT_PROFILE( object ) && NA_IS_OBJECT_ITEM( items->data )){
-				parent = ( NAObject * ) na_object_get_parent( object );
-				gtk_tree_path_free( insert_path );
-				insert_path = nact_tree_model_object_to_path( ied->model, parent );
-			}
+		/* as a particular case, insert a new profile _into_ current action
+		 */
+		if( NA_IS_OBJECT_ACTION( object ) && NA_IS_OBJECT_PROFILE( items->data )){
+			nact_tree_ieditable_insert_into( instance, items );
+			gtk_tree_path_free( insert_path );
+			return;
 		}
 
-		nact_tree_ieditable_insert_at_path( instance, items, insert_path );
-		gtk_tree_path_free( insert_path );
+		/* insert a new NAObjectItem before current NAObjectItem
+		 */
+		if( NA_IS_OBJECT_PROFILE( object ) && NA_IS_OBJECT_ITEM( items->data )){
+			parent = ( NAObject * ) na_object_get_parent( object );
+			gtk_tree_path_free( insert_path );
+			insert_path = nact_tree_model_object_to_path( ied->model, parent );
+		}
 	}
+
+	nact_tree_ieditable_insert_at_path( instance, items, insert_path );
+	gtk_tree_path_free( insert_path );
 }
 
 /**
@@ -731,39 +742,37 @@ nact_tree_ieditable_insert_at_path( NactTreeIEditable *instance, GList *items, G
 
 	g_return_if_fail( NACT_IS_TREE_IEDITABLE( instance ));
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-		g_debug( "%s: instance=%p, items=%p (count=%d)",
-			thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ));
+	g_debug( "%s: instance=%p, items=%p (count=%d)",
+		thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ));
 
-		nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), FALSE );
-		ied = get_instance_data( instance );
-		prev_status = get_modification_status( ied );
+	nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), FALSE );
+	ied = get_instance_data( instance );
+	prev_status = get_modification_status( ied );
 
-		actual_path = do_insert_before( ied, items, insert_path );
+	actual_path = do_insert_before( ied, items, insert_path );
 
-		parent = na_object_get_parent( items->data );
-		if( parent ){
-			na_object_check_status( parent );
-		} else {
-			for( it = items ; it ; it = it->next ){
-				na_object_check_status( it->data );
-			}
-			g_signal_emit_by_name( ied->window, TREE_SIGNAL_LEVEL_ZERO_CHANGED, TRUE );
+	parent = na_object_get_parent( items->data );
+	if( parent ){
+		na_object_check_status( parent );
+	} else {
+		for( it = items ; it ; it = it->next ){
+			na_object_check_status( it->data );
 		}
-
-		/* post insertion
-		 */
-		status = get_modification_status( ied );
-		if( prev_status != status ){
-			g_signal_emit_by_name( ied->window, TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
-		}
-		nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), TRUE );
-
-		increment_counters( instance, ied, items );
-		gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
-		nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), actual_path );
-		gtk_tree_path_free( actual_path );
+		g_signal_emit_by_name( ied->window, TREE_SIGNAL_LEVEL_ZERO_CHANGED, TRUE );
 	}
+
+	/* post insertion
+	 */
+	status = get_modification_status( ied );
+	if( prev_status != status ){
+		g_signal_emit_by_name( ied->window, TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
+	}
+	nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), TRUE );
+
+	increment_counters( instance, ied, items );
+	gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
+	nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), actual_path );
+	gtk_tree_path_free( actual_path );
 }
 
 /**
@@ -796,26 +805,24 @@ nact_tree_ieditable_insert_into( NactTreeIEditable *instance, GList *items )
 
 	g_return_if_fail( NACT_IS_TREE_IEDITABLE( instance ));
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-		g_debug( "%s: instance=%p, items=%p (count=%d)",
-			thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ));
+	g_debug( "%s: instance=%p, items=%p (count=%d)",
+		thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ));
 
-		ied = get_instance_data( instance );
-		insert_path = get_selection_first_path( ied->treeview );
+	ied = get_instance_data( instance );
+	insert_path = get_selection_first_path( ied->treeview );
 
-		new_path = do_insert_into( ied, items, insert_path );
+	new_path = do_insert_into( ied, items, insert_path );
 
-		parent = na_object_get_parent( items->data );
-		na_object_check_status( parent );
+	parent = na_object_get_parent( items->data );
+	na_object_check_status( parent );
 
-		/* post insertion
-		 */
-		increment_counters( instance, ied, items );
-		gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
-		nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), new_path );
-		gtk_tree_path_free( new_path );
-		gtk_tree_path_free( insert_path );
-	}
+	/* post insertion
+	 */
+	increment_counters( instance, ied, items );
+	gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
+	nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), new_path );
+	gtk_tree_path_free( new_path );
+	gtk_tree_path_free( insert_path );
 }
 
 /*
@@ -859,6 +866,9 @@ do_insert_before( IEditableData *ied, GList *items, GtkTreePath *asked_path )
 		}
 	}
 
+	/* an l-value here is useless, but makes gcc happy */
+	items = g_list_reverse( reversed );
+
 	return( actual_path );
 }
 
@@ -925,6 +935,82 @@ increment_counters( NactTreeIEditable *view, IEditableData *ied, GList *items )
 	g_signal_emit_by_name( G_OBJECT( ied->window ), TREE_SIGNAL_COUNT_CHANGED, FALSE, menus, actions, profiles );
 }
 
+/*
+ * nact_tree_ieditable_set_items:
+ * @instance: this #NactTreeIEditable *instance.
+ * @items: a #GList of items to be set in the tree view.
+ *
+ * The provided list of @items will override the items already in the list
+ * which have the same identifier. But:
+ * - menus keep their children
+ * - entering actions fully override existing ones.
+ *
+ * Items which would not been found are just ignored.
+ * Items which are not of the same type are ignored.
+ *
+ * This feature is typically used when importing an item whose identifier
+ * already exists, and the user have chosen to override existing item.
+ * So we should be almost sure that each item actually exists in the view.
+ */
+void
+nact_tree_ieditable_set_items( NactTreeIEditable *instance, GList *items )
+{
+	static const gchar *thisfn = "nact_tree_ieditable_set_items";
+	IEditableData *ied;
+	GList *it;
+	NAObjectItem *new_item, *old_item;
+	gchar *id;
+	GtkTreePath *path, *insert_path;
+
+	g_return_if_fail( NACT_IS_TREE_IEDITABLE( instance ));
+
+	g_debug( "%s: instance=%p, items=%p (count=%d)",
+		thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ));
+
+	ied = get_instance_data( instance );
+
+	for( it = items ; it ; it = it->next ){
+		new_item = NA_OBJECT_ITEM( it->data );
+
+		id = na_object_get_id( new_item );
+		old_item = nact_tree_view_get_item_by_id( NACT_TREE_VIEW( instance ), id );
+
+		if( !old_item ){
+			g_warning( "%s: id=%s: item not found - ignored", thisfn, id );
+
+		} else if( G_OBJECT_TYPE( old_item ) != G_OBJECT_TYPE( new_item )){
+			g_warning( "%s: id=%s: old is a %s while new is a %s - ignored", thisfn, id,
+					G_OBJECT_TYPE_NAME( old_item ), G_OBJECT_TYPE_NAME( new_item ));
+
+		} else if( NA_IS_OBJECT_MENU( old_item )){
+			/* hopefully, na_factory_object_copy only copy valuable properties
+			 * keeping dynamic variables as parent pointer, provider and provider
+			 * data, read-only status - notably children are not impacted by this
+			 * copy
+			 */
+			na_factory_object_copy( NA_IFACTORY_OBJECT( old_item ), NA_IFACTORY_OBJECT( new_item ));
+
+		} else if( NA_IS_OBJECT_ACTION( old_item )){
+			/* na_factory_object is not a deep copy, which is fine for the menu
+			 * but not for the action - it appears more easier to just substitute
+			 * the old item with the new one
+			 *
+			 * only children of the old item are its own profiles, which are to be
+			 * replaced with the profiles provided by the new item
+			 */
+			path = nact_tree_model_delete( ied->model, NA_OBJECT( old_item ));
+			insert_path = nact_tree_model_insert_before( ied->model, NA_OBJECT( new_item ), path );
+			gtk_tree_path_free( path );
+			gtk_tree_path_free( insert_path );
+
+		} else {
+			g_warning( "%s: should not come here!", thisfn );
+		}
+
+		g_free( id );
+	}
+}
+
 /**
  * nact_tree_ieditable_dump_modified:
  * @instance: this #NactTreeIEditable *instance.
@@ -939,14 +1025,11 @@ nact_tree_ieditable_dump_modified( const NactTreeIEditable *instance )
 
 	g_return_if_fail( NACT_IS_TREE_IEDITABLE( instance ));
 
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
+	ied = get_instance_data(( NactTreeIEditable * ) instance );
 
-		ied = get_instance_data(( NactTreeIEditable * ) instance );
-
-		g_debug( "%s:      count_deleted=%u", thisfn, g_list_length( ied->deleted ));
-		g_debug( "%s:     count_modified=%u", thisfn, ied->count_modified );
-		g_debug( "%s: level_zero_changed=%s", thisfn, ied->level_zero_changed ? "True":"False" );
-	}
+	g_debug( "%s:      count_deleted=%u", thisfn, g_list_length( ied->deleted ));
+	g_debug( "%s:     count_modified=%u", thisfn, ied->count_modified );
+	g_debug( "%s: level_zero_changed=%s", thisfn, ied->level_zero_changed ? "True":"False" );
 }
 
 /**
@@ -963,17 +1046,60 @@ nact_tree_ieditable_is_level_zero_modified( const NactTreeIEditable *instance )
 
 	g_return_val_if_fail( NACT_IS_TREE_IEDITABLE( instance ), FALSE );
 
-	is_modified = FALSE;
-
-	if( st_tree_ieditable_initialized && !st_tree_ieditable_finalized ){
-
-		ied = get_instance_data(( NactTreeIEditable * ) instance );
-		is_modified = ied->level_zero_changed;
-	}
+	ied = get_instance_data(( NactTreeIEditable * ) instance );
+	is_modified = ied->level_zero_changed;
 
 	return( is_modified );
 }
 
+static void
+check_level_zero_status( NactTreeIEditable *instance )
+{
+	static const gchar *thisfn = "nact_tree_ieditable_check_level_zero_status";
+	gboolean status;
+	IEditableData *ied;
+	GList *items;
+	gchar *pivot_str, *view_str;
+
+	ied = get_instance_data( instance );
+	items = na_pivot_get_items( NA_PIVOT( ied->updater ));
+	pivot_str = get_items_id_list_str( items );
+
+	items = nact_tree_view_get_items( NACT_TREE_VIEW( instance ));
+	view_str = get_items_id_list_str( items );
+	na_object_free_items( items );
+
+	status = ( g_utf8_collate( pivot_str, view_str ) != 0 );
+	g_debug( "%s: pivot_str='%s', view_str='%s', status=%s", thisfn, pivot_str, view_str, status ? "True":"False" );
+
+	g_free( pivot_str );
+	g_free( view_str );
+
+	g_signal_emit_by_name( ied->window, TREE_SIGNAL_LEVEL_ZERO_CHANGED, status );
+}
+
+static gchar *
+get_items_id_list_str( GList *items_list )
+{
+	GList *it;
+	gchar *id;
+	GSList *slist;
+	gchar *list_str;
+
+	slist = NULL;
+
+	for( it = items_list ; it ; it = it->next ){
+		id = na_object_get_id( it->data );
+		slist = g_slist_prepend( slist, id );
+	}
+
+	slist = g_slist_reverse( slist );
+	list_str = na_core_utils_slist_join_at_end( slist, ";" );
+	na_core_utils_slist_free( slist );
+
+	return( list_str );
+}
+
 static GtkTreePath *
 get_selection_first_path( GtkTreeView *treeview )
 {
@@ -1001,10 +1127,16 @@ get_selection_first_path( GtkTreeView *treeview )
 static gboolean
 get_modification_status( IEditableData *ied )
 {
+	static const gchar *thisfn = "nact_tree_ieditable_get_modification_status";
 	gboolean modified;
 
-	modified = ( ied->count_modified > 0 ) ||
-				( g_list_length( ied->deleted ) > 0 ) || ( ied->level_zero_changed );
+	modified = ( ied->count_modified > 0 ||
+				ied->count_deleted > 0 ||
+				ied->level_zero_changed );
+
+	g_debug( "%s: count_modified=%d, deleted=%d, level_zero_changed=%s, modified=%s",
+			thisfn, ied->count_modified, ied->count_deleted,
+			ied->level_zero_changed ? "True":"False", modified ? "True":"False" );
 
 	return( modified );
 }
