@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -39,7 +38,6 @@
 #include <api/na-core-utils.h>
 #include <api/na-object-api.h>
 
-#include <core/na-iprefs.h>
 #include <core/na-gnome-vfs-uri.h>
 #include <core/na-importer.h>
 
@@ -61,14 +59,19 @@
  *
  * as soon as mouse has quitted the selected area
  *   call once egg_tree_multi_dnd_stop_drag_check( treeview )
- *   call once nact_tree_model_imulti_drag_source_row_draggable: drag_source=0x92a0d70, path_list=0x9373c90
+ *   call once nact_tree_model_dnd_imulti_drag_source_row_draggable: drag_source=0x92a0d70, path_list=0x9373c90
+ *   call once nact_tree_model_dnd_on_drag_begin
+ *     nact_clipboard_dnd_clear()
  *   call once nact_clipboard_on_drag_begin( treeview, context, main_window )
  *
  * when we drop (e.g. in Nautilus)
  *   call once egg_tree_multi_dnd_on_drag_data_get( treeview, context, selection_data, info=0, time )
- *   call once nact_tree_model_imulti_drag_source_drag_data_get( drag_source, context, selection_data, path_list, atom=XdndDirectSave0 )
- *   call once nact_tree_model_idrag_dest_drag_data_received
- *   call once nact_clipboard_on_drag_end( treeview, context, main_window )
+ *   call once nact_tree_model_dnd_imulti_drag_source_drag_data_get( drag_source, context, selection_data, path_list, atom=XdndDirectSave0 )
+ *     nact_clipboard_dnd_set()
+ *   call once nact_tree_model_dnd_on_drag_end
+ *     nact_clipboard_dnd_drag_end
+ *       nact_clipboard_get_from_dnd_clipboard_callback
+ *     nact_clipboard_dnd_clear
  *
  * when we drop in Nautilus-Actions
  *   call once egg_tree_multi_dnd_on_drag_data_get( treeview, context, selection_data, info=0, time )
@@ -103,7 +106,7 @@ static GtkTargetEntry dnd_source_formats[] = {
  * - of course, the same special XdndNautilusAction format for internal move/copy
  * - a list of uris, to be imported
  * - a XML buffer, to be imported
- * - a plain text, which we are goint to try to import as a XML description
+ * - a plain text, which we are going to try to import as a XML description
  */
 GtkTargetEntry tree_model_dnd_dest_formats[] = {
 	{ "XdndNautilusActions", 0, NACT_XCHANGE_FORMAT_NACT },
@@ -136,8 +139,9 @@ static guint         target_atom_to_id( GdkAtom atom );
  * @dest:
  * @selection_data:
  *
- * Called when a drop from the outside occurs in the treeview;
- * this may be an import action, or a move/copy inside of the tree.
+ * Called when a drop occurs in the treeview;
+ * this may be an import action from the outside world, or a move/copy
+ * inside of the tree.
  *
  * Returns: %TRUE if the specified rows were successfully inserted at
  * the given dest, %FALSE else.
@@ -157,6 +161,7 @@ nact_tree_model_dnd_idrag_dest_drag_data_received( GtkTreeDragDest *drag_dest, G
 {
 	static const gchar *thisfn = "nact_tree_model_dnd_idrag_dest_drag_data_received";
 	gboolean result = FALSE;
+	NactTreeModel *model;
 	gchar *atom_name;
 	guint info;
 	gchar *path_str;
@@ -166,69 +171,59 @@ nact_tree_model_dnd_idrag_dest_drag_data_received( GtkTreeDragDest *drag_dest, G
 	gint selection_data_format;
 	gint selection_data_length;
 
-	g_debug( "%s: drag_dest=%p, dest=%p, selection_data=%p", thisfn, ( void * ) drag_dest, ( void * ) dest, ( void * ) selection_data );
-	g_return_val_if_fail( NACT_IS_TREE_MODEL( drag_dest ), FALSE );
+	g_return_val_if_fail( NACT_IS_TREE_MODEL( drag_dest ), result );
 
-/* gtk_selection_data_get_data() appears with Gtk+ 2.14.0 release on 2008-09-04
- * see http://git.gnome.org/browse/gtk+/commit/?id=9eae7a1d2e7457d67ba00bb8c35775c1523fa186
- */
-#if GTK_CHECK_VERSION( 2, 14, 0 )
-	selection_data_selection = gtk_selection_data_get_selection( selection_data );
-#else
-	selection_data_selection = selection_data->selection;
-#endif
-	atom_name = gdk_atom_name( selection_data_selection );
-	g_debug( "%s: selection=%s", thisfn, atom_name );
-	g_free( atom_name );
+	model = NACT_TREE_MODEL( drag_dest );
 
-#if GTK_CHECK_VERSION( 2, 14, 0 )
-	selection_data_target = gtk_selection_data_get_target( selection_data );
-#else
-	selection_data_target = selection_data->target;
-#endif
-	atom_name = gdk_atom_name( selection_data_target );
-	g_debug( "%s: target=%s", thisfn, atom_name );
-	g_free( atom_name );
+	if( !model->private->dispose_has_run ){
 
-#if GTK_CHECK_VERSION( 2, 14, 0 )
-	selection_data_type = gtk_selection_data_get_data_type( selection_data );
-#else
-	selection_data_type = selection_data->type;
-#endif
-	atom_name = gdk_atom_name( selection_data_type );
-	g_debug( "%s: type=%s", thisfn, atom_name );
-	g_free( atom_name );
+		g_debug( "%s: drag_dest=%p (ref_count=%d), dest=%p, selection_data=%p",
+				thisfn,
+				( void * ) drag_dest, G_OBJECT( drag_dest )->ref_count,
+				( void * ) dest,
+				( void * ) selection_data );
 
-#if GTK_CHECK_VERSION( 2, 14, 0 )
-	selection_data_format = gtk_selection_data_get_format( selection_data );
-	selection_data_length = gtk_selection_data_get_length( selection_data );
-#else
-	selection_data_format = selection_data->format;
-	selection_data_length = selection_data->length;
-#endif
-	g_debug( "%s: format=%d, length=%d", thisfn, selection_data_format, selection_data_length );
+		selection_data_selection = gtk_selection_data_get_selection( selection_data );
+		atom_name = gdk_atom_name( selection_data_selection );
+		g_debug( "%s: selection=%s", thisfn, atom_name );
+		g_free( atom_name );
 
-	info = target_atom_to_id( selection_data_type );
-	g_debug( "%s: info=%u", thisfn, info );
+		selection_data_target = gtk_selection_data_get_target( selection_data );
+		atom_name = gdk_atom_name( selection_data_target );
+		g_debug( "%s: target=%s", thisfn, atom_name );
+		g_free( atom_name );
 
-	path_str = gtk_tree_path_to_string( dest );
-	g_debug( "%s: dest_path=%s", thisfn, path_str );
-	g_free( path_str );
+		selection_data_type = gtk_selection_data_get_data_type( selection_data );
+		atom_name = gdk_atom_name( selection_data_type );
+		g_debug( "%s: type=%s", thisfn, atom_name );
+		g_free( atom_name );
 
-	switch( info ){
-		case NACT_XCHANGE_FORMAT_NACT:
-			result = drop_inside( NACT_TREE_MODEL( drag_dest ), dest, selection_data );
-			break;
+		selection_data_format = gtk_selection_data_get_format( selection_data );
+		selection_data_length = gtk_selection_data_get_length( selection_data );
+		g_debug( "%s: format=%d, length=%d", thisfn, selection_data_format, selection_data_length );
 
-		/* drop some actions from outside
-		 * most probably from the file manager as a list of uris
-		 */
-		case NACT_XCHANGE_FORMAT_URI_LIST:
-			result = drop_uri_list( NACT_TREE_MODEL( drag_dest ), dest, selection_data );
-			break;
+		info = target_atom_to_id( selection_data_type );
+		g_debug( "%s: info=%u", thisfn, info );
 
-		default:
-			break;
+		path_str = gtk_tree_path_to_string( dest );
+		g_debug( "%s: dest_path=%s", thisfn, path_str );
+		g_free( path_str );
+
+		switch( info ){
+			case NACT_XCHANGE_FORMAT_NACT:
+				result = drop_inside( model, dest, selection_data );
+				break;
+
+			/* drop some actions from outside
+			 * most probably from the file manager as a list of uris
+			 */
+			case NACT_XCHANGE_FORMAT_URI_LIST:
+				result = drop_uri_list( model, dest, selection_data );
+				break;
+
+			default:
+				break;
+		}
 	}
 
 	return( result );
@@ -307,11 +302,7 @@ nact_tree_model_dnd_imulti_drag_source_drag_data_get( EggTreeMultiDragSource *dr
 	GdkDragAction context_suggested_action;
 	GdkDragAction context_selected_action;
 
-#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_target = gtk_selection_data_get_target( selection_data );
-#else
-	selection_data_target = selection_data->target;
-#endif
 
 #if GTK_CHECK_VERSION( 2, 22, 0 )
 	context_suggested_action = gdk_drag_context_get_suggested_action( context );
@@ -322,9 +313,13 @@ nact_tree_model_dnd_imulti_drag_source_drag_data_get( EggTreeMultiDragSource *dr
 #endif
 
 	atom_name = gdk_atom_name( selection_data_target );
-	g_debug( "%s: drag_source=%p, context=%p, action=%d, selection_data=%p, rows=%p, atom=%s",
-			thisfn, ( void * ) drag_source, ( void * ) context, ( int ) context_suggested_action,
-			( void * ) selection_data, ( void * ) rows,
+	g_debug( "%s: drag_source=%p (ref_count=%d), context=%p, suggested action=%d, selection_data=%p, rows=%p (count=%d), atom=%s",
+			thisfn,
+			( void * ) drag_source, G_OBJECT( drag_source )->ref_count,
+			( void * ) context,
+			( int ) context_suggested_action,
+			( void * ) selection_data,
+			( void * ) rows, g_list_length( rows ),
 			atom_name );
 	g_free( atom_name );
 
@@ -441,8 +436,10 @@ nact_tree_model_dnd_imulti_drag_source_row_draggable( EggTreeMultiDragSource *dr
 	NAObject *object;
 	GList *it;
 
-	g_debug( "%s: drag_source=%p, rows=%p (%d items)",
-			thisfn, ( void * ) drag_source, ( void * ) rows, g_list_length( rows ));
+	g_debug( "%s: drag_source=%p (ref_count=%d), rows=%p (%d items)",
+			thisfn,
+			( void * ) drag_source, G_OBJECT( drag_source )->ref_count,
+			( void * ) rows, g_list_length( rows ));
 
 	g_return_val_if_fail( NACT_IS_TREE_MODEL( drag_source ), FALSE );
 	model = NACT_TREE_MODEL( drag_source );
@@ -486,14 +483,19 @@ nact_tree_model_dnd_on_drag_begin( GtkWidget *widget, GdkDragContext *context, B
 	NactTreeModel *model;
 	GdkWindow *context_source_window;
 
-	g_debug( "%s: widget=%p, context=%p, window=%p",
-			thisfn, ( void * ) widget, ( void * ) context, ( void * ) window );
-
-	model = NACT_TREE_MODEL( gtk_tree_view_get_model( GTK_TREE_VIEW( widget )));
+	g_return_if_fail( GTK_IS_TREE_VIEW( widget ));
+	model = ( NactTreeModel * ) gtk_tree_view_get_model( GTK_TREE_VIEW( widget ));
 	g_return_if_fail( NACT_IS_TREE_MODEL( model ));
 
 	if( !model->private->dispose_has_run ){
 
+		g_debug( "%s: widget=%p, context=%p, window=%p, model=%p (ref_count=%d)",
+				thisfn,
+				( void * ) widget,
+				( void * ) context,
+				( void * ) window,
+				( void * ) model, G_OBJECT( model )->ref_count );
+
 		model->private->drag_highlight = FALSE;
 		model->private->drag_drop = FALSE;
 
@@ -524,14 +526,19 @@ nact_tree_model_dnd_on_drag_end( GtkWidget *widget, GdkDragContext *context, Bas
 	NactTreeModel *model;
 	GdkWindow *context_source_window;
 
-	g_debug( "%s: widget=%p, context=%p, window=%p",
-			thisfn, ( void * ) widget, ( void * ) context, ( void * ) window );
-
-	model = NACT_TREE_MODEL( gtk_tree_view_get_model( GTK_TREE_VIEW( widget )));
+	g_return_if_fail( GTK_IS_TREE_VIEW( widget ));
+	model = ( NactTreeModel * ) gtk_tree_view_get_model( GTK_TREE_VIEW( widget ));
 	g_return_if_fail( NACT_IS_TREE_MODEL( model ));
 
 	if( !model->private->dispose_has_run ){
 
+		g_debug( "%s: widget=%p, context=%p, window=%p, model=%p (ref_count=%d)",
+				thisfn,
+				( void * ) widget,
+				( void * ) context,
+				( void * ) window,
+				( void * ) model, G_OBJECT( model )->ref_count );
+
 		nact_clipboard_dnd_drag_end( model->private->clipboard );
 		nact_clipboard_dnd_clear( model->private->clipboard );
 
@@ -606,7 +613,7 @@ drop_inside( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selecti
 				g_object_unref( current );
 
 				if( copy_data ){
-					inserted = ( NAObject * ) na_object_duplicate( current );
+					inserted = ( NAObject * ) na_object_duplicate( current, DUPLICATE_REC );
 					na_object_set_origin( inserted, NULL );
 					na_object_check_status( inserted );
 					relabel = na_updater_should_pasted_be_relabeled( updater, inserted );
@@ -850,13 +857,15 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 	NAUpdater *updater;
 	NactMainWindow *main_window;
 	NAImporterParms parms;
-	GList *it;
+	GList *import_results, *it;
 	guint count;
-	GString *str;
 	GSList *im;
-	GList *imported;
+	GList *imported, *overriden;
 	const gchar *selection_data_data;
 	NactTreeView *view;
+	GSList *messages;
+	gchar *dlg_message;
+	GtkWidget *dialog;
 
 	gchar *dest_str = gtk_tree_path_to_string( dest );
 	g_debug( "%s: model=%p, dest=%p (%s), selection_data=%p",
@@ -876,66 +885,64 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 	g_return_val_if_fail( NACT_IS_MAIN_WINDOW( model->private->window ), FALSE );
 	main_window = NACT_MAIN_WINDOW( model->private->window );
 
-#if GTK_CHECK_VERSION( 2, 14, 0 )
 	selection_data_data = ( const gchar * ) gtk_selection_data_get_data( selection_data );
-#else
-	selection_data_data = ( const gchar * ) selection_data->data;
-#endif
 	g_debug( "%s", selection_data_data );
 
-	parms.parent = base_window_get_gtk_toplevel( BASE_WINDOW( main_window ));
+	memset( &parms, '\0', sizeof( NAImporterParms ));
 	parms.uris = g_slist_reverse( na_core_utils_slist_from_split( selection_data_data, "\r\n" ));
-
-	parms.mode = na_iprefs_get_import_mode( NA_IPREFS_IMPORT_PREFERRED_MODE, NULL );
-
-	parms.check_fn = ( NAIImporterCheckFn ) is_dropped_already_exists;
+	parms.check_fn = ( NAImporterCheckFn ) is_dropped_already_exists;
 	parms.check_fn_data = main_window;
-	parms.results = NULL;
+	parms.preferred_mode = 0;
+	parms.parent_toplevel = base_window_get_gtk_toplevel( BASE_WINDOW( main_window ));
 
-	na_importer_import_from_list( NA_PIVOT( updater ), &parms );
+	import_results = na_importer_import_from_uris( NA_PIVOT( updater ), &parms );
 
-	/* analysing output results
-	 * - first line of first message is displayed in status bar
-	 * - simultaneously build the concatenation of all lines of messages
-	 * - simultaneously build the list of imported items
+	/* analysing output results, simultaneously building a concatenation
+	 * of all lines of messages, and the list of imported items
 	 */
-	count = 0;
-	str = g_string_new( "" );
 	imported = NULL;
+	overriden = NULL;
+	messages = NULL;
 
-	for( it = parms.results ; it ; it = it->next ){
+	for( it = import_results ; it ; it = it->next ){
 		NAImporterResult *result = ( NAImporterResult * ) it->data;
 
-		if( result->messages ){
-			if( count == 0 ){
-				nact_main_statusbar_display_with_timeout(
-						main_window,
-						TREE_MODEL_STATUSBAR_CONTEXT,
-						result->messages->data );
-			}
-			count += 1;
-			for( im = result->messages ; im ; im = im->next ){
-				g_string_append_printf( str, "%s\n", ( const gchar * ) im->data );
-			}
+		for( im = result->messages ; im ; im = im->next ){
+			messages = g_slist_prepend( messages, im->data );
 		}
-
 		if( result->imported ){
-			imported = g_list_prepend( imported, result->imported );
-			na_updater_check_item_writability_status( updater, result->imported );
+			if( !result->exist || result->mode == IMPORTER_MODE_RENUMBER ){
+				imported = g_list_prepend( imported, result->imported );
+				na_updater_check_item_writability_status( updater, result->imported );
+
+			} else if( result->mode == IMPORTER_MODE_OVERRIDE ){
+				overriden = g_list_prepend( overriden, result->imported );
+			}
 		}
 	}
 
 	/* if there is more than one message, display them in a dialog box
+	 * else in the status bar
 	 */
-	if( count > 1 ){
-		GtkMessageDialog *dialog = GTK_MESSAGE_DIALOG( gtk_message_dialog_new(
-				parms.parent,
-				GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE,
-				"%s", _( "Some messages have occurred during drop operation." )));
-		gtk_message_dialog_format_secondary_markup( dialog, "%s", str->str );
+	count = g_slist_length( messages );
+	g_debug( "%s: count=%d", thisfn, count );
+	if( count == 1 ){
+		nact_main_statusbar_display_with_timeout(
+				main_window, TREE_MODEL_STATUSBAR_CONTEXT, messages->data );
 	}
-
-	g_string_free( str, TRUE );
+	if( count > 1 ){
+		dlg_message = na_core_utils_slist_join_at_end( messages, "\n" );
+		g_debug( "%s: dlg_message='%s'", thisfn, dlg_message );
+		dialog = gtk_message_dialog_new(
+				parms.parent_toplevel,
+				GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE,
+				"%s", _( "Some messages have occurred during drop operation." ));
+		gtk_message_dialog_format_secondary_markup( GTK_MESSAGE_DIALOG( dialog ), "%s", dlg_message );
+		gtk_dialog_run( GTK_DIALOG( dialog ));
+		gtk_widget_destroy( dialog );
+		g_free( dlg_message );
+	}
+	g_slist_free( messages );
 
 	/* insert newly imported items in the list view
 	 */
@@ -945,14 +952,25 @@ drop_uri_list( NactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 		nact_tree_ieditable_insert_at_path( NACT_TREE_IEDITABLE( view ), imported, dest );
 	}
 
+	/* override items if needed
+	 * they may safely be released after having updated the store
+	 */
+	if( overriden ){
+		na_object_dump_tree( overriden );
+		view = nact_main_window_get_items_view( main_window );
+		nact_tree_ieditable_set_items( NACT_TREE_IEDITABLE( view ), overriden );
+		na_object_free_items( overriden );
+	}
+
 	drop_done = TRUE;
 	na_object_free_items( imported );
+	na_object_free_items( overriden );
 	na_core_utils_slist_free( parms.uris );
 
-	for( it = parms.results ; it ; it = it->next ){
+	for( it = import_results ; it ; it = it->next ){
 		na_importer_free_result( it->data );
 	}
-	g_list_free( parms.results );
+	g_list_free( import_results );
 
 	return( drop_done );
 }
