@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -85,15 +84,15 @@ static GList            *menu_provider_get_file_items( NautilusMenuProvider *pro
 static GList            *menu_provider_get_toolbar_items( NautilusMenuProvider *provider, GtkWidget *window, NautilusFileInfo *current_folder );
 #endif
 
-static GList            *get_menus_items( NautilusActions *plugin, guint target, GList *selection );
-static GList            *expand_tokens( GList *tree, NATokens *tokens );
-static NAObjectItem     *expand_tokens_item( NAObjectItem *item, NATokens *tokens );
+static GList            *build_nautilus_menu( NautilusActions *plugin, guint target, GList *selection );
+static GList            *build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *tokens );
+static NAObjectItem     *expand_tokens_item( const NAObjectItem *item, NATokens *tokens );
 static void              expand_tokens_context( NAIContext *context, NATokens *tokens );
-static GList            *build_nautilus_menus( NautilusActions *plugin, GList *tree, guint target, GList *files, NATokens *tokens );
-static NAObjectProfile  *get_candidate_profile( NautilusActions *plugin, NAObjectAction *action, guint target, GList *files );
+static NAObjectProfile  *get_candidate_profile( NAObjectAction *action, guint target, GList *files );
 static NautilusMenuItem *create_item_from_profile( NAObjectProfile *profile, guint target, GList *files, NATokens *tokens );
 static NautilusMenuItem *create_item_from_menu( NAObjectMenu *menu, GList *subitems, guint target );
-static NautilusMenuItem *create_menu_item( NAObjectItem *item, guint target );
+static NautilusMenuItem *create_menu_item( const NAObjectItem *item, guint target );
+static void              weak_notify_menu_item( void *user_data /* =NULL */, NautilusMenuItem *item );
 static void              attach_submenu_to_item( NautilusMenuItem *item, GList *subitems );
 static void              weak_notify_profile( NAObjectProfile *profile, NautilusMenuItem *item );
 
@@ -201,48 +200,65 @@ static void
 instance_constructed( GObject *object )
 {
 	static const gchar *thisfn = "nautilus_actions_instance_constructed";
-	NautilusActions *self;
+	NautilusActionsPrivate *priv;
 
 	g_return_if_fail( NAUTILUS_IS_ACTIONS( object ));
 
-	self = NAUTILUS_ACTIONS( object );
+	priv = NAUTILUS_ACTIONS( object )->private;
 
-	if( !self->private->dispose_has_run ){
-		g_debug( "%s: object=%p", thisfn, ( void * ) object );
-
-		self->private->pivot = na_pivot_new();
-
-		/* setup NAPivot properties before loading items
-		 */
-		na_pivot_set_loadable( self->private->pivot, !PIVOT_LOAD_DISABLED & !PIVOT_LOAD_INVALID );
-		na_pivot_load_items( self->private->pivot );
-
-		/* register against NAPivot to be notified of items changes
-		 */
-		self->private->items_changed_handler =
-				g_signal_connect( self->private->pivot,
-						PIVOT_SIGNAL_ITEMS_CHANGED, G_CALLBACK( on_pivot_items_changed_handler ), self );
-
-		/* register against NASettings to be notified of changes on
-		 *  our runtime preferences
-		 * because we only monitor here four runtime keys, we prefer the
-		 * callback way that the signal one
-		 */
-		na_settings_register_key_callback(
-				NA_IPREFS_IO_PROVIDERS_READ_STATUS, G_CALLBACK( on_settings_key_changed_handler ), self );
-		na_settings_register_key_callback(
-				NA_IPREFS_ITEMS_ADD_ABOUT_ITEM, G_CALLBACK( on_settings_key_changed_handler ), self );
-		na_settings_register_key_callback(
-				NA_IPREFS_ITEMS_CREATE_ROOT_MENU, G_CALLBACK( on_settings_key_changed_handler ), self );
-		na_settings_register_key_callback(
-				NA_IPREFS_ITEMS_LEVEL_ZERO_ORDER, G_CALLBACK( on_settings_key_changed_handler ), self );
-		na_settings_register_key_callback(
-				NA_IPREFS_ITEMS_LIST_ORDER_MODE, G_CALLBACK( on_settings_key_changed_handler ), self );
+	if( !priv->dispose_has_run ){
 
 		/* chain up to the parent class */
 		if( G_OBJECT_CLASS( st_parent_class )->constructed ){
 			G_OBJECT_CLASS( st_parent_class )->constructed( object );
 		}
+
+		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
+		priv->pivot = na_pivot_new();
+
+		/* setup NAPivot properties before loading items
+		 */
+		na_pivot_set_loadable( priv->pivot, !PIVOT_LOAD_DISABLED & !PIVOT_LOAD_INVALID );
+		na_pivot_load_items( priv->pivot );
+
+		/* register against NAPivot to be notified of items changes
+		 */
+		priv->items_changed_handler =
+				g_signal_connect( priv->pivot,
+						PIVOT_SIGNAL_ITEMS_CHANGED,
+						G_CALLBACK( on_pivot_items_changed_handler ),
+						object );
+
+		/* register against NASettings to be notified of changes on
+		 *  our runtime preferences
+		 * because we only monitor here a few runtime keys, we prefer the
+		 * callback way that the signal one
+		 */
+		na_settings_register_key_callback(
+				NA_IPREFS_IO_PROVIDERS_READ_STATUS,
+				G_CALLBACK( on_settings_key_changed_handler ),
+				object );
+
+		na_settings_register_key_callback(
+				NA_IPREFS_ITEMS_ADD_ABOUT_ITEM,
+				G_CALLBACK( on_settings_key_changed_handler ),
+				object );
+
+		na_settings_register_key_callback(
+				NA_IPREFS_ITEMS_CREATE_ROOT_MENU,
+				G_CALLBACK( on_settings_key_changed_handler ),
+				object );
+
+		na_settings_register_key_callback(
+				NA_IPREFS_ITEMS_LEVEL_ZERO_ORDER,
+				G_CALLBACK( on_settings_key_changed_handler ),
+				object );
+
+		na_settings_register_key_callback(
+				NA_IPREFS_ITEMS_LIST_ORDER_MODE,
+				G_CALLBACK( on_settings_key_changed_handler ),
+				object );
 	}
 }
 
@@ -339,10 +355,17 @@ menu_provider_get_background_items( NautilusMenuProvider *provider, GtkWidget *w
 		if( selected ){
 			uri = nautilus_file_info_get_uri( current_folder );
 			g_debug( "%s: provider=%p, window=%p, current_folder=%p (%s)",
-					thisfn, ( void * ) provider, ( void * ) window, ( void * ) current_folder, uri );
+					thisfn,
+					( void * ) provider,
+					( void * ) window,
+					( void * ) current_folder, uri );
 			g_free( uri );
 
-			nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_LOCATION, selected );
+			nautilus_menus_list = build_nautilus_menu(
+					NAUTILUS_ACTIONS( provider ),
+					ITEM_TARGET_LOCATION,
+					selected );
+
 			na_selected_info_free_list( selected );
 		}
 	}
@@ -372,22 +395,31 @@ menu_provider_get_file_items( NautilusMenuProvider *provider, GtkWidget *window,
 			return(( GList * ) NULL );
 		}
 
-#ifdef NA_MAINTAINER_MODE
-		GList *im;
-		for( im = files ; im ; im = im->next ){
-			gchar *uri = nautilus_file_info_get_uri( NAUTILUS_FILE_INFO( im->data ));
-			g_debug( "%s: uri=%s", thisfn, uri );
-			g_free( uri );
-		}
-#endif
-
 		selected = na_selected_info_get_list_from_list(( GList * ) files );
 
 		if( selected ){
 			g_debug( "%s: provider=%p, window=%p, files=%p, count=%d",
-					thisfn, ( void * ) provider, ( void * ) window, ( void * ) files, g_list_length( files ));
+					thisfn,
+					( void * ) provider,
+					( void * ) window,
+					( void * ) files, g_list_length( files ));
+
+#ifdef NA_MAINTAINER_MODE
+			GList *im;
+			for( im = files ; im ; im = im->next ){
+				gchar *uri = nautilus_file_info_get_uri( NAUTILUS_FILE_INFO( im->data ));
+				gchar *mimetype = nautilus_file_info_get_mime_type( NAUTILUS_FILE_INFO( im->data ));
+				g_debug( "%s: uri='%s', mimetype='%s'", thisfn, uri, mimetype );
+				g_free( mimetype );
+				g_free( uri );
+			}
+#endif
+
+			nautilus_menus_list = build_nautilus_menu(
+					NAUTILUS_ACTIONS( provider ),
+					ITEM_TARGET_SELECTION,
+					selected );
 
-			nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_SELECTION, selected );
 			na_selected_info_free_list( selected );
 		}
 	}
@@ -420,10 +452,17 @@ menu_provider_get_toolbar_items( NautilusMenuProvider *provider, GtkWidget *wind
 		if( selected ){
 			uri = nautilus_file_info_get_uri( current_folder );
 			g_debug( "%s: provider=%p, window=%p, current_folder=%p (%s)",
-					thisfn, ( void * ) provider, ( void * ) window, ( void * ) current_folder, uri );
+					thisfn,
+					( void * ) provider,
+					( void * ) window,
+					( void * ) current_folder, uri );
 			g_free( uri );
 
-			nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_TOOLBAR, selected );
+			nautilus_menus_list = build_nautilus_menu(
+					NAUTILUS_ACTIONS( provider ),
+					ITEM_TARGET_TOOLBAR,
+					selected );
+
 			na_selected_info_free_list( selected );
 		}
 	}
@@ -432,75 +471,167 @@ menu_provider_get_toolbar_items( NautilusMenuProvider *provider, GtkWidget *wind
 }
 #endif
 
+/*
+ * build_nautilus_menu:
+ * @target: whether the menu targets a location (a folder) or a selection
+ *  (the list of currently selected items in the file manager)
+ * @selection: a list of NASelectedInfo, with:
+ *  - only one item if a location
+ *  - one item by selected file manager item, if a selection.
+ *  Note: a NASelectedInfo is just a sort of NautilusFileInfo, with
+ *  some added APIs.
+ *
+ * Build the Nautilus menu as a list of NautilusMenuItem items
+ *
+ * Returns: the Nautilus menu
+ */
 static GList *
-get_menus_items( NautilusActions *plugin, guint target, GList *selection )
+build_nautilus_menu( NautilusActions *plugin, guint target, GList *selection )
 {
-	GList *menus_list;
+	GList *nautilus_menu;
 	NATokens *tokens;
-	GList *pivot_tree, *copy_tree;
+	GList *tree;
 	gboolean items_add_about_item;
 	gboolean items_create_root_menu;
 
 	g_return_val_if_fail( NA_IS_PIVOT( plugin->private->pivot ), NULL );
 
 	tokens = na_tokens_new_from_selection( selection );
-	pivot_tree = na_pivot_get_items( plugin->private->pivot );
-	copy_tree = expand_tokens( pivot_tree, tokens );
 
-	menus_list = build_nautilus_menus( plugin, copy_tree, target, selection, tokens );
+	tree = na_pivot_get_items( plugin->private->pivot );
 
-	na_object_free_items( copy_tree );
+	nautilus_menu = build_nautilus_menu_rec( tree, target, selection, tokens );
+
+	/* the NATokens object has been attached (and reffed) by each found
+	 * candidate profile, so it will be actually finalized only on actual
+	 * NautilusMenu finalization itself
+	 */
 	g_object_unref( tokens );
 
 	if( target != ITEM_TARGET_TOOLBAR ){
 
 		items_create_root_menu = na_settings_get_boolean( NA_IPREFS_ITEMS_CREATE_ROOT_MENU, NULL, NULL );
 		if( items_create_root_menu ){
-			menus_list = create_root_menu( plugin, menus_list );
+			nautilus_menu = create_root_menu( plugin, nautilus_menu );
 		}
 
 		items_add_about_item = na_settings_get_boolean( NA_IPREFS_ITEMS_ADD_ABOUT_ITEM, NULL, NULL );
 		if( items_add_about_item ){
-			menus_list = add_about_item( plugin, menus_list );
+			nautilus_menu = add_about_item( plugin, nautilus_menu );
 		}
 	}
 
-	return( menus_list );
+	return( nautilus_menu );
+}
+
+static GList *
+build_nautilus_menu_rec( GList *tree, guint target, GList *selection, NATokens *tokens )
+{
+	static const gchar *thisfn = "nautilus_actions_build_nautilus_menu_rec";
+	GList *nautilus_menu;
+	GList *it;
+	GList *subitems;
+	NAObjectItem *item;
+	GList *submenu;
+	NAObjectProfile *profile;
+	NautilusMenuItem *menu_item;
+	gchar *label;
+
+	nautilus_menu = NULL;
+
+	for( it = tree ; it ; it = it->next ){
+
+		g_return_val_if_fail( NA_IS_OBJECT_ITEM( it->data ), NULL );
+		label = na_object_get_label( it->data );
+		g_debug( "%s: examining %s", thisfn, label );
+
+		if( !na_icontext_is_candidate( NA_ICONTEXT( it->data ), target, selection )){
+			g_debug( "%s: is not candidate (NAIContext): %s", thisfn, label );
+			g_free( label );
+			continue;
+		}
+
+		item = expand_tokens_item( NA_OBJECT_ITEM( it->data ), tokens );
+
+		/* but we have to re-check for validity as a label may become
+		 * dynamically empty - thus the NAObjectItem invalid :(
+		 */
+		if( !na_object_is_valid( item )){
+			g_debug( "%s: item %s becomes invalid after expand_tokens_item", thisfn, label );
+			g_object_unref( item );
+			g_free( label );
+			continue;
+		}
+
+		/* recursively build sub-menus
+		 * the 'submenu' menu of nautilusMenuItem's is attached to the returned
+		 * 'item'
+		 */
+		if( NA_IS_OBJECT_MENU( item )){
+
+			subitems = na_object_get_items( item );
+			g_debug( "%s: menu has %d items", thisfn, g_list_length( subitems ));
+
+			submenu = build_nautilus_menu_rec( subitems, target, selection, tokens );
+			g_debug( "%s: submenu has %d items", thisfn, g_list_length( submenu ));
+
+			if( submenu ){
+				if( target == ITEM_TARGET_TOOLBAR ){
+					nautilus_menu = g_list_concat( nautilus_menu, submenu );
+
+				} else {
+					menu_item = create_item_from_menu( NA_OBJECT_MENU( item ), submenu, target );
+					nautilus_menu = g_list_append( nautilus_menu, menu_item );
+				}
+			}
+			g_object_unref( item );
+			g_free( label );
+			continue;
+		}
+
+		g_return_val_if_fail( NA_IS_OBJECT_ACTION( item ), NULL );
+
+		/* if we have an action, searches for a candidate profile
+		 */
+		profile = get_candidate_profile( NA_OBJECT_ACTION( item ), target, selection );
+		if( profile ){
+			menu_item = create_item_from_profile( profile, target, selection, tokens );
+			nautilus_menu = g_list_append( nautilus_menu, menu_item );
+
+		} else {
+			g_debug( "%s: %s does not have any valid candidate profile", thisfn, label );
+		}
+
+		g_object_unref( item );
+		g_free( label );
+	}
+
+	return( nautilus_menu );
 }
 
 /*
- * create a copy of the tree where almost all fields which may embed
- * parameters have been expanded
- * here, 'almost' should be read as:
- * - all displayable fields, or fields which may have an impact on the display
- *   (e.g. label, tooltip, icon name)
- * - all fields which we do not need later
+ * expand_tokens_item:
+ * @item: a NAObjectItem read from the NAPivot.
+ * @tokens: the NATokens object which holds current selection data
+ *  (uris, basenames, mimetypes, etc.)
  *
- * we keep until the last item activation the Exec key, whose first parameter
- * actualy determines the form (singular or plural) of the execution..
+ * Updates the @item, replacing parameters with the corresponding token.
+ *
+ * This function is not recursive, but works for the plain item:
+ * - the menu (itself)
+ * - the action and its profiles
+ *
+ * Returns: a duplicated object which has to be g_object_unref() by the caller.
  */
-static GList *
-expand_tokens( GList *pivot_tree, NATokens *tokens )
-{
-	GList *tree, *it;
-
-	tree = NULL;
-
-	for( it = pivot_tree ; it ; it = it->next ){
-		NAObjectItem *item = NA_OBJECT_ITEM( na_object_duplicate( it->data ));
-		tree = g_list_prepend( tree, expand_tokens_item( item, tokens ));
-	}
-
-	return( g_list_reverse( tree ));
-}
-
 static NAObjectItem *
-expand_tokens_item( NAObjectItem *item, NATokens *tokens )
+expand_tokens_item( const NAObjectItem *src, NATokens *tokens )
 {
 	gchar *old, *new;
 	GSList *subitems_slist, *its, *new_slist;
-	GList *subitems, *it, *new_list;
-	NAObjectItem *expanded_item;
+	GList *subitems, *it;
+	NAObjectItem *item;
+
+	item = NA_OBJECT_ITEM( na_object_duplicate( src, DUPLICATE_OBJECT ));
 
 	/* label, tooltip and icon name
 	 * plus the toolbar label if this is an action
@@ -554,22 +685,11 @@ expand_tokens_item( NAObjectItem *item, NATokens *tokens )
 	na_core_utils_slist_free( subitems_slist );
 	na_core_utils_slist_free( new_slist );
 
-	/* last, deal with subitems
+	/* last, deal with profiles of an action
 	 */
-	subitems = na_object_get_items( item );
+	if( NA_IS_OBJECT_ACTION( item )){
 
-	if( NA_IS_OBJECT_MENU( item )){
-		new_list = NULL;
-
-		for( it = subitems ; it ; it = it->next ){
-			expanded_item = expand_tokens_item( NA_OBJECT_ITEM( it->data ), tokens );
-			new_list = g_list_prepend( new_list, expanded_item );
-		}
-
-		na_object_set_items( item, g_list_reverse( new_list ));
-
-	} else {
-		g_return_val_if_fail( NA_IS_OBJECT_ACTION( item ), NULL );
+		subitems = na_object_get_items( item );
 
 		for( it = subitems ; it ; it = it->next ){
 
@@ -621,101 +741,11 @@ expand_tokens_context( NAIContext *context, NATokens *tokens )
 	g_free( new );
 }
 
-/*
- * @plugin: this #NautilusActions module instance.
- * @tree: a copy of the #NAPivot tree, where all fields - but
- *  displayable parameters expanded
- * @target: whether we target location or context menu, or toolbar.
- * @files: the current selection in the file-manager, as a #GList of #NASelectedInfo items
- * @tokens: a #NATokens object which embeds all possible values, regarding the
- *  current selection, for all parameters
- *
- * When building a menu for the toolbar, do not use menus hierarchy
- *
- * As menus, actions and profiles may embed parameters in their data,
- * all the hierarchy must be recursively re-parsed, and should be
- * re-checked for validity !
- */
-static GList *
-build_nautilus_menus( NautilusActions *plugin, GList *tree, guint target, GList *files, NATokens *tokens )
-{
-	static const gchar *thisfn = "nautilus_actions_build_nautilus_menus";
-	GList *menus_list = NULL;
-	GList *subitems, *submenu;
-	GList *it;
-	NAObjectProfile *profile;
-	NautilusMenuItem *item;
-
-	g_debug( "%s: plugin=%p, tree=%p, target=%d, files=%p (count=%d)",
-			thisfn, ( void * ) plugin, ( void * ) tree, target,
-			( void * ) files, g_list_length( files ));
-
-	for( it = tree ; it ; it = it->next ){
-
-		g_return_val_if_fail( NA_IS_OBJECT_ITEM( it->data ), NULL );
-
-#ifdef NA_MAINTAINER_MODE
-		/* check this here as a security though NAPivot should only have
-		 * loaded valid and enabled items
-		 */
-		if( !na_object_is_enabled( it->data )){
-			gchar *label = na_object_get_label( it->data );
-			g_warning( "%s: '%s' item: enabled=%s, valid=%s", thisfn, label,
-					na_object_is_enabled( it->data ) ? "True":"False",
-					na_object_is_valid( it->data ) ? "True":"False" );
-			g_free( label );
-			continue;
-		}
-#endif
-
-		/* but we have to re-check for validity as a label may become
-		 * dynamically empty - thus the NAObjectItem invalid :(
-		 */
-		if( !na_object_is_valid( it->data )){
-			continue;
-		}
-
-		if( !na_icontext_is_candidate( NA_ICONTEXT( it->data ), target, files )){
-			continue;
-		}
-
-		/* recursively build sub-menus
-		 */
-		if( NA_IS_OBJECT_MENU( it->data )){
-			subitems = na_object_get_items( it->data );
-			g_debug( "%s: menu has %d items", thisfn, g_list_length( subitems ));
-			submenu = build_nautilus_menus( plugin, subitems, target, files, tokens );
-			g_debug( "%s: submenu has %d items", thisfn, g_list_length( submenu ));
-
-			if( submenu ){
-				if( target == ITEM_TARGET_TOOLBAR ){
-					menus_list = g_list_concat( menus_list, submenu );
-
-				} else {
-					item = create_item_from_menu( NA_OBJECT_MENU( it->data ), submenu, target );
-					menus_list = g_list_append( menus_list, item );
-				}
-			}
-			continue;
-		}
-
-		g_return_val_if_fail( NA_IS_OBJECT_ACTION( it->data ), NULL );
-
-		profile = get_candidate_profile( plugin, NA_OBJECT_ACTION( it->data ), target, files );
-		if( profile ){
-			item = create_item_from_profile( profile, target, files, tokens );
-			menus_list = g_list_append( menus_list, item );
-		}
-	}
-
-	return( menus_list );
-}
-
 /*
  * could also be a NAObjectAction method - but this is not used elsewhere
  */
 static NAObjectProfile *
-get_candidate_profile( NautilusActions *plugin, NAObjectAction *action, guint target, GList *files )
+get_candidate_profile( NAObjectAction *action, guint target, GList *files )
 {
 	static const gchar *thisfn = "nautilus_actions_get_candidate_profile";
 	NAObjectProfile *candidate = NULL;
@@ -751,19 +781,18 @@ create_item_from_profile( NAObjectProfile *profile, guint target, GList *files,
 	NAObjectProfile *duplicate;
 
 	action = NA_OBJECT_ACTION( na_object_get_parent( profile ));
-	duplicate = NA_OBJECT_PROFILE( na_object_duplicate( profile ));
+	duplicate = NA_OBJECT_PROFILE( na_object_duplicate( profile, DUPLICATE_ONLY ));
 	na_object_set_parent( duplicate, NULL );
 
 	item = create_menu_item( NA_OBJECT_ITEM( action ), target );
 
-	/* attach a weak ref on the Nautilus menu item: our profile will be
-	 * unreffed in weak notify function
-	 */
 	g_signal_connect( item,
 				"activate",
 				G_CALLBACK( execute_action ),
 				duplicate );
 
+	/* unref the duplicated profile on menu item finalization
+	 */
 	g_object_weak_ref( G_OBJECT( item ), ( GWeakNotify ) weak_notify_profile, duplicate );
 
 	g_object_set_data_full( G_OBJECT( item ),
@@ -788,7 +817,8 @@ weak_notify_profile( NAObjectProfile *profile, NautilusMenuItem *item )
 
 /*
  * note that each appended NautilusMenuItem is ref-ed by the NautilusMenu
- * we can so safely release our own ref on subitems after this function
+ * we can so safely release our own ref on subitems after having attached
+ * the submenu
  */
 static NautilusMenuItem *
 create_item_from_menu( NAObjectMenu *menu, GList *subitems, guint target )
@@ -799,14 +829,21 @@ create_item_from_menu( NAObjectMenu *menu, GList *subitems, guint target )
 	item = create_menu_item( NA_OBJECT_ITEM( menu ), target );
 
 	attach_submenu_to_item( item, subitems );
+
 	nautilus_menu_item_list_free( subitems );
 
 	/*g_debug( "%s: returning item=%p", thisfn, ( void * ) item );*/
 	return( item );
 }
 
+/*
+ * Creates a NautilusMenuItem
+ *
+ * We attach a weak notify function to the created item in order to be able
+ * to check for instanciation/finalization cycles
+ */
 static NautilusMenuItem *
-create_menu_item( NAObjectItem *item, guint target )
+create_menu_item( const NAObjectItem *item, guint target )
 {
 	NautilusMenuItem *menu_item;
 	gchar *id, *name, *label, *tooltip, *icon;
@@ -819,6 +856,8 @@ create_menu_item( NAObjectItem *item, guint target )
 
 	menu_item = nautilus_menu_item_new( name, label, tooltip, icon );
 
+	g_object_weak_ref( G_OBJECT( menu_item ), ( GWeakNotify ) weak_notify_menu_item, NULL );
+
 	g_free( icon );
  	g_free( tooltip );
  	g_free( label );
@@ -828,6 +867,15 @@ create_menu_item( NAObjectItem *item, guint target )
 	return( menu_item );
 }
 
+/*
+ * called _after_ the NautilusMenuItem has been finalized
+ */
+static void
+weak_notify_menu_item( void *user_data /* =NULL */, NautilusMenuItem *item )
+{
+	g_debug( "nautilus_actions_weak_notify_menu_item: item=%p", ( void * ) item );
+}
+
 static void
 attach_submenu_to_item( NautilusMenuItem *item, GList *subitems )
 {
@@ -871,7 +919,6 @@ create_root_menu( NautilusActions *plugin, GList *menu )
 	static const gchar *thisfn = "nautilus_actions_create_root_menu";
 	GList *nautilus_menu;
 	NautilusMenuItem *root_item;
-	gchar *icon;
 
 	g_debug( "%s: plugin=%p, menu=%p (%d items)",
 			thisfn, ( void * ) plugin, ( void * ) menu, g_list_length( menu ));
@@ -880,16 +927,15 @@ create_root_menu( NautilusActions *plugin, GList *menu )
 		return( NULL );
 	}
 
-	icon = na_about_get_icon_name();
-	root_item = nautilus_menu_item_new( "NautilusActionsExtensions",
-				/* i18n: label of an automagic root submenu */
-				_( "Nautilus-Actions actions" ),
-				/* i18n: tooltip of an automagic root submenu */
-				_( "A submenu which embeds the currently available Nautilus-Actions actions and menus" ),
-				icon );
+	root_item = nautilus_menu_item_new(
+			"NautilusActionsExtensions",
+			/* i18n: label of an automagic root submenu */
+			_( "Nautilus-Actions actions" ),
+			/* i18n: tooltip of an automagic root submenu */
+			_( "A submenu which embeds the currently available Nautilus-Actions actions and menus" ),
+			na_about_get_icon_name());
 	attach_submenu_to_item( root_item, menu );
 	nautilus_menu = g_list_append( NULL, root_item );
-	g_free( icon );
 
 	return( nautilus_menu );
 }
@@ -907,7 +953,6 @@ add_about_item( NautilusActions *plugin, GList *menu )
 	NautilusMenuItem *root_item;
 	NautilusMenuItem *about_item;
 	NautilusMenu *first;
-	gchar *icon;
 
 	g_debug( "%s: plugin=%p, menu=%p (%d items)",
 			thisfn, ( void * ) plugin, ( void * ) menu, g_list_length( menu ));
@@ -929,23 +974,21 @@ add_about_item( NautilusActions *plugin, GList *menu )
 	}
 
 	if( have_root_menu ){
-		icon = na_about_get_icon_name();
+		about_item = nautilus_menu_item_new(
+				"AboutNautilusActions",
+				_( "About Nautilus-Actions" ),
+				_( "Display some informations about Nautilus-Actions" ),
+				na_about_get_icon_name());
 
-		about_item = nautilus_menu_item_new( "AboutNautilusActions",
-					_( "About Nautilus-Actions" ),
-					_( "Display some informations about Nautilus-Actions" ),
-					icon );
-
-		g_signal_connect_data( about_item,
-					"activate",
-					G_CALLBACK( execute_about ),
-					plugin,
-					NULL,
-					0 );
+		g_signal_connect_data(
+				about_item,
+				"activate",
+				G_CALLBACK( execute_about ),
+				plugin,
+				NULL,
+				0 );
 
 		nautilus_menu_append_item( first, about_item );
-
-		g_free( icon );
 	}
 
 	return( nautilus_menu );
