@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -94,8 +93,10 @@ interface_base_init( TestIFaceInterface *klass )
 	static const gchar *thisfn = "test_iface_iface_interface_base_init";
 	static gboolean initialized = FALSE;
 
+	g_debug( "%s: klass=%p, initialized=%s",
+			thisfn, ( void * ) klass, initialized ? "True":"False" );
+
 	if( !initialized ){
-		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
 
 		klass->private = g_new0( TestIFaceInterfacePrivate, 1 );
 
@@ -109,10 +110,12 @@ interface_base_finalize( TestIFaceInterface *klass )
 	static const gchar *thisfn = "test_iface_iface_interface_base_finalize";
 	static gboolean finalized = FALSE ;
 
-	if( !finalized ){
-		finalized = TRUE;
+	g_debug( "%s: klass=%p, finalized=%s",
+			thisfn, ( void * ) klass, finalized ? "True":"False" );
 
-		g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
+	if( !finalized ){
+
+		finalized = TRUE;
 
 		g_free( klass->private );
 	}
