@@ -3,23 +3,22 @@
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
- * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
+ * Nautilus-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General  Public  License  as
+ * published by the Free Software Foundation; either  version  2  of
  * the License, or (at your option) any later version.
  *
- * This Program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * Nautilus-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even  the  implied  warranty  of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See  the  GNU
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this Library; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public  License
+ * along with Nautilus-Actions; see the file  COPYING.  If  not,  see
+ * <http://www.gnu.org/licenses/>.
  *
  * Authors:
  *   Frederic Ruaudel <grumz@grumz.net>
@@ -250,7 +249,7 @@ get_action( const gchar *id )
 }
 
 /*
- * the DBus.Tracker.Status interface returns a list of strings
+ * the DBus.Tracker.Properties1 interface returns a list of strings
  * where each selected item brings up both its URI and its Nautilus
  * mime type.
  *
@@ -261,17 +260,69 @@ targets_from_selection( void )
 {
 	static const gchar *thisfn = "nautilus_actions_run_targets_from_selection";
 	GList *selection;
-	DBusGConnection *connection;
-	DBusGProxy *proxy;
 	GError *error;
 	gchar **paths;
 
+	g_debug( "%s", thisfn );
+
+	selection = NULL;
 	error = NULL;
-	proxy = NULL;
 	paths = NULL;
 
-	connection = dbus_g_bus_get( DBUS_BUS_SESSION, &error );
+#ifdef HAVE_GDBUS
+	GDBusObjectManager *manager;
+	gchar *name_owner;
+	GDBusObject *object;
+	GDBusInterface *iface;
 
+	manager = na_tracker_object_manager_client_new_for_bus_sync(
+			G_BUS_TYPE_SESSION,
+			G_DBUS_OBJECT_MANAGER_CLIENT_FLAGS_NONE,
+			NAUTILUS_ACTIONS_DBUS_SERVICE,
+			NAUTILUS_ACTIONS_DBUS_TRACKER_PATH,
+			NULL,
+			&error );
+
+	if( !manager ){
+		g_printerr( "%s: unable to allocate an ObjectManagerClient: %s\n", thisfn, error->message );
+		g_error_free( error );
+		return( NULL );
+	}
+
+	name_owner = g_dbus_object_manager_client_get_name_owner( G_DBUS_OBJECT_MANAGER_CLIENT( manager ));
+	g_debug( "%s: name_owner=%s", thisfn, name_owner );
+	g_free( name_owner );
+
+	object = g_dbus_object_manager_get_object( manager, NAUTILUS_ACTIONS_DBUS_TRACKER_PATH "/0" );
+	if( !object ){
+		g_printerr( "%s: unable to get object at %s path\n", thisfn, NAUTILUS_ACTIONS_DBUS_TRACKER_PATH "/0" );
+		g_object_unref( manager );
+		return( NULL );
+	}
+
+	iface = g_dbus_object_get_interface( object, NAUTILUS_ACTIONS_DBUS_TRACKER_IFACE );
+	if( !iface ){
+		g_printerr( "%s: unable to get %s interface\n", thisfn, NAUTILUS_ACTIONS_DBUS_TRACKER_IFACE );
+		g_object_unref( object );
+		g_object_unref( manager );
+		return( NULL );
+	}
+
+	/* note that @iface is really a GDBusProxy instance
+	 * and additionally also a NATrackerProperties1 instance
+	 */
+	na_tracker_properties1_call_get_selected_paths_sync(
+			NA_TRACKER_PROPERTIES1( iface ),
+			&paths,
+			NULL,
+			&error );
+
+#else
+# ifdef HAVE_DBUS_GLIB
+	DBusGConnection *connection;
+	DBusGProxy *proxy = NULL;
+
+	connection = dbus_g_bus_get( DBUS_BUS_SESSION, &error );
 	if( !connection ){
 		if( error ){
 			g_printerr( _( "Error: unable to get a connection to session DBus: %s" ), error->message );
@@ -283,8 +334,8 @@ targets_from_selection( void )
 
 	proxy = dbus_g_proxy_new_for_name( connection,
 			NAUTILUS_ACTIONS_DBUS_SERVICE,
-			NAUTILUS_ACTIONS_DBUS_TRACKER_PATH,
-			NAUTILUS_ACTIONS_DBUS_TRACKER_INTERFACE );
+			NAUTILUS_ACTIONS_DBUS_TRACKER_PATH "/0",
+			NAUTILUS_ACTIONS_DBUS_TRACKER_IFACE );
 
 	if( !proxy ){
 		g_printerr( _( "Error: unable to get a proxy on %s service" ), NAUTILUS_ACTIONS_DBUS_SERVICE );
@@ -305,13 +356,15 @@ targets_from_selection( void )
 	}
 	g_debug( "%s: function call is ok", thisfn );
 
+	/* TODO: unref proxy */
+	dbus_g_connection_unref( connection );
+# endif
+#endif
+
 	selection = get_selection_from_strv(( const gchar ** ) paths, TRUE );
 
 	g_strfreev( paths );
 
-	/* TODO: unref proxy */
-	dbus_g_connection_unref( connection );
-
 	return( selection );
 }
 
